@@ -14,6 +14,7 @@
 ################################################################################
 
 from JupyROOT.helpers import utils
+import platform
 import ROOT
 
 # Jit a wrapper for the ttabcom
@@ -69,7 +70,7 @@ class CppCompleter(object):
     ...     print(suggestion.replace("\\t"," "))
     <BLANKLINE>
     Bool_t Add(TF1* h1, Double_t c1 = 1, Option_t* option = "")
-    Bool_t Add(const TH1* h, const TH1* h2, Double_t c1 = 1, Double_t c2 = 1)  // *MENU*
+    Bool_t Add(const TH1* h, const TH1* h2, Double_t c1 = 1, Double_t c2 = 1)
     Bool_t Add(const TH1* h1, Double_t c1 = 1)
     >>> for suggestion in comp._completeImpl("TROOT::Is"):
     ...     print(suggestion)
@@ -106,8 +107,11 @@ class CppCompleter(object):
     def activate(self):
         self.active = True
         if self.firstActivation:
-            utils.declareCppCode('#include "dlfcn.h"')
-            dlOpenRint = 'dlopen("libRint.so",RTLD_NOW);'
+            if platform.system() == 'Windows':
+                dlOpenRint = 'gInterpreter->LoadFile("libRint.dll");'
+            else:
+                utils.declareCppCode('#include "dlfcn.h"')
+                dlOpenRint = 'dlopen("libRint.so",RTLD_NOW);'
             utils.processCppCode(dlOpenRint)
             utils.declareCppCode(_TTabComHookCode)
             self.hook = ROOT._TTabComHook
