@@ -3,25 +3,45 @@
 #include "cpp11features.h"
 
 
-// for std::shared_ptr<> testing
-int TestSharedPtr::s_counter = 0;
+// for std::shared/unique_ptr<> testing
+int TestSmartPtr::s_counter = 0;
 
-std::shared_ptr<TestSharedPtr> create_shared_ptr_instance() {
-    return std::shared_ptr<TestSharedPtr>(new TestSharedPtr);
+std::shared_ptr<TestSmartPtr> create_shared_ptr_instance() {
+    return std::shared_ptr<TestSmartPtr>(new TestSmartPtr);
 }
 
-int TestSharedPtr::get_value() {
+std::unique_ptr<TestSmartPtr> create_unique_ptr_instance() {
+    return std::unique_ptr<TestSmartPtr>(new TestSmartPtr);
+}
+
+int TestSmartPtr::get_value() {
     return 17;
 }
 
-int DerivedTestSharedPtr::get_value() {
+int DerivedTestSmartPtr::get_value() {
     return m_int + 76;
 }
 
-int pass_shared_ptr(std::shared_ptr<TestSharedPtr> p) {
+int pass_shared_ptr(std::shared_ptr<TestSmartPtr> p) {
     return p->get_value();
 }
 
+int move_shared_ptr(std::shared_ptr<TestSmartPtr>&& p) {
+    return p->get_value();
+}
+
+int move_unique_ptr(std::unique_ptr<TestSmartPtr>&& p) {
+    return p->get_value();
+}
+
+int move_unique_ptr_derived(std::unique_ptr<DerivedTestSmartPtr>&& p) {
+    return p->get_value();
+}
+
+TestSmartPtr create_TestSmartPtr_by_value() {
+    return TestSmartPtr{};
+}
+
 
 // for move ctors etc.
 int TestMoving1::s_move_counter = 0;
