@@ -10,15 +10,14 @@
  *************************************************************************/
 
 // Bindings
-#include "CPyCppyy.h"
+#include "CPyCppyy/API.h"
+
+#include "../../cppyy/CPyCppyy/src/CPyCppyy.h"
+#include "../../cppyy/CPyCppyy/src/CPPInstance.h"
+#include "../../cppyy/CPyCppyy/src/CustomPyTypes.h"
+
 #include "PyROOTPythonize.h"
-#include "CPPInstance.h"
-#include "ProxyWrappers.h"
-#include "Converters.h"
-#include "Utility.h"
-#include "PyzCppHelpers.hxx"
 #include "TBufferFile.h"
-#include "CustomPyTypes.h"
 
 using namespace CPyCppyy;
 
@@ -39,7 +38,7 @@ extern PyObject *gRootModule;
 PyObject *PyROOT::CPPInstanceExpand(PyObject * /*self*/, PyObject *args)
 {
    PyObject *pybuf = 0, *pyname = 0;
-   if (!PyArg_ParseTuple(args, const_cast<char *>("O!O!:__expand__"), &PyBytes_Type, &pybuf, &PyBytes_Type, &pyname))
+   if (!PyArg_ParseTuple(args, "O!O!:__expand__", &PyBytes_Type, &pybuf, &PyBytes_Type, &pyname))
       return 0;
    const char *clname = PyBytes_AS_STRING(pyname);
    // TBuffer and its derived classes can't write themselves, but can be created
@@ -55,12 +54,7 @@ PyObject *PyROOT::CPPInstanceExpand(PyObject * /*self*/, PyObject *args)
       TBufferFile buf(TBuffer::kRead, PyBytes_GET_SIZE(pybuf), PyBytes_AS_STRING(pybuf), kFALSE);
       newObj = buf.ReadObjectAny(0);
    }
-   PyObject *result = BindCppObject(newObj, Cppyy::GetScope(clname));
-   if (result) {
-      // this object is to be owned by the Python interpreter, assuming that the call
-      // originated from there
-      ((CPPInstance *)result)->PythonOwns();
-   }
+   PyObject *result = CPyCppyy::Instance_FromVoidPtr(newObj, clname, /*python_owns=*/true);
    return result;
 }
 
@@ -68,26 +62,27 @@ PyObject *PyROOT::CPPInstanceExpand(PyObject * /*self*/, PyObject *args)
 /// Turn the object proxy instance into a character stream and return for
 /// pickle, together with the callable object that can restore the stream
 /// into the object proxy instance.
-PyObject *op_reduce(CPPInstance *self, PyObject * /*args*/)
+PyObject *op_reduce(PyObject *self, PyObject * /*args*/)
 {
    // keep a borrowed reference around to the callable function for expanding;
    // because it is borrowed, it means that there can be no pickling during the
    // shutdown of the libPyROOT module
-   static PyObject *s_expand =
-      PyDict_GetItemString(PyModule_GetDict(PyROOT::gRootModule), const_cast<char *>("_CPPInstance__expand__"));
+   static PyObject *s_expand = PyDict_GetItemString(PyModule_GetDict(PyROOT::gRootModule), "_CPPInstance__expand__");
 
    // TBuffer and its derived classes can't write themselves, but can be created
    // directly from the buffer, so handle them in a special case
    static Cppyy::TCppType_t s_bfClass = Cppyy::GetScope("TBufferFile");
    TBufferFile *buff = 0;
-   if (s_bfClass == self->ObjectIsA()) {
-      buff = (TBufferFile *)self->GetObject();
+   Cppyy::TCppType_t selfClass = ((CPPInstance *)self)->ObjectIsA();
+   if (selfClass == s_bfClass) {
+      buff = (TBufferFile *)CPyCppyy::Instance_AsVoidPtr(self);
    } else {
-      auto className = Cppyy::GetScopedFinalName(self->ObjectIsA());
+      auto className = Cppyy::GetScopedFinalName(selfClass);
       if (className.find("__cppyy_internal::Dispatcher") == 0) {
-         PyErr_Format(PyExc_IOError, "generic streaming of Python objects whose class derives from a C++ class is not supported. "
-                                     "Please refer to the Python pickle documentation for instructions on how to define "
-                                     "a custom __reduce__ method for the derived Python class");
+         PyErr_Format(PyExc_IOError,
+                      "generic streaming of Python objects whose class derives from a C++ class is not supported. "
+                      "Please refer to the Python pickle documentation for instructions on how to define "
+                      "a custom __reduce__ method for the derived Python class");
          return 0;
       }
       // no cast is needed, but WriteObject taking a TClass argument is protected,
@@ -95,10 +90,9 @@ PyObject *op_reduce(CPPInstance *self, PyObject * /*args*/)
       static TBufferFile s_buff(TBuffer::kWrite);
       s_buff.Reset();
       // to delete
-      if (s_buff.WriteObjectAny(self->GetObject(),
-                                TClass::GetClass(className.c_str())) != 1) {
+      if (s_buff.WriteObjectAny(CPyCppyy::Instance_AsVoidPtr(self), TClass::GetClass(className.c_str())) != 1) {
          PyErr_Format(PyExc_IOError, "could not stream object of type %s",
-                      Cppyy::GetScopedFinalName(self->ObjectIsA()).c_str());
+                      Cppyy::GetScopedFinalName(selfClass).c_str());
          return 0;
       }
       buff = &s_buff;
@@ -108,7 +102,7 @@ PyObject *op_reduce(CPPInstance *self, PyObject * /*args*/)
    // on reading back in (see CPPInstanceExpand defined above)
    PyObject *res2 = PyTuple_New(2);
    PyTuple_SET_ITEM(res2, 0, PyBytes_FromStringAndSize(buff->Buffer(), buff->Length()));
-   PyTuple_SET_ITEM(res2, 1, PyBytes_FromString(Cppyy::GetScopedFinalName(self->ObjectIsA()).c_str()));
+   PyTuple_SET_ITEM(res2, 1, PyBytes_FromString(Cppyy::GetScopedFinalName(selfClass).c_str()));
 
    PyObject *result = PyTuple_New(2);
    Py_INCREF(s_expand);
@@ -145,7 +139,7 @@ PyObject *PyROOT::AddCPPInstancePickling(PyObject * /*self*/, PyObject *args)
    // attribute assignment using PyObject_SetAttr
    // for more info refer to:
    // https://bitbucket.org/wlav/cppyy/issues/110/user-defined-classes-in-c-dont-seem-to-be
-   PyObject_GenericSetAttr(pyclass, CPyCppyy_PyText_FromString(attr), method);
+   PyObject_GenericSetAttr(pyclass, PyUnicode_FromString(attr), method);
    Py_DECREF(method);
    Py_DECREF(func);
 
