@@ -11,7 +11,6 @@
 
 // Bindings
 #include "PyROOTPythonize.h"
-#include "PyROOTWrapper.h"
 #include "RPyROOTApplication.h"
 
 // Cppyy
@@ -20,11 +19,13 @@
 #include "../../cppyy/CPyCppyy/src/ProxyWrappers.h"
 
 // ROOT
+#include "TInterpreter.h"
 #include "TROOT.h"
 #include "TSystem.h"
 #include "RConfigure.h"
 
 // Standard
+#include <any>
 #include <string>
 #include <sstream>
 #include <utility>
@@ -60,6 +61,67 @@ PyObject *RegisterExecutorAlias(PyObject * /*self*/, PyObject *args)
    Py_RETURN_NONE;
 }
 
+/// \brief A PyObject wrapper to track reference counting of external objects
+///
+/// This wrapper can be useful in shared ownership scenarios when a C++ object
+/// is created on the Python side and there is no easy way to track its ownership
+/// on the C++ side. If multiple instances of this class are given the same
+/// Python proxy, they will increase/decrease its reference counting following
+/// Python rules and ensure proper destruction of the underlying C++ object when
+/// no other Python objects are referencing it.
+class PyObjRefCounter final {
+   PyObject *fObject{nullptr};
+
+   void Reset(PyObject *object)
+   {
+      if (fObject) {
+         Py_DECREF(fObject);
+         fObject = nullptr;
+      }
+      if (object) {
+         Py_INCREF(object);
+         fObject = object;
+      }
+   }
+
+public:
+   PyObjRefCounter(PyObject *object) { Reset(object); }
+
+   ~PyObjRefCounter() { Reset(nullptr); }
+
+   PyObjRefCounter(const PyObjRefCounter &other) { Reset(other.fObject); }
+
+   PyObjRefCounter &operator=(const PyObjRefCounter &other)
+   {
+      Reset(other.fObject);
+      return *this;
+   }
+
+   PyObjRefCounter(PyObjRefCounter &&other)
+   {
+      fObject = other.fObject;
+      other.fObject = nullptr;
+   }
+
+   PyObjRefCounter &operator=(PyObjRefCounter &&other)
+   {
+      fObject = other.fObject;
+      other.fObject = nullptr;
+      return *this;
+   }
+};
+
+PyObject *PyObjRefCounterAsStdAny(PyObject * /*self*/, PyObject *args)
+{
+   PyObject *object = nullptr;
+
+   PyArg_ParseTuple(args, "O:PyObjRefCounterAsStdAny", &object);
+
+   // The std::any is managed by Python
+   return CPyCppyy::Instance_FromVoidPtr(new std::any{std::in_place_type<PyObjRefCounter>, object}, "std::any",
+                                         /*python_owns=*/true);
+}
+
 } // namespace PyROOT
 
 // Methods offered by the interface
@@ -82,8 +144,6 @@ static PyMethodDef gPyROOTMethods[] = {
     (char *)"Install an input hook to process GUI events"},
    {(char *)"_CPPInstance__expand__", (PyCFunction)PyROOT::CPPInstanceExpand, METH_VARARGS,
     (char *)"Deserialize a pickled object"},
-   {(char *)"ClearProxiedObjects", (PyCFunction)PyROOT::ClearProxiedObjects, METH_NOARGS,
-    (char *)"Clear proxied objects regulated by PyROOT"},
    {(char *)"JupyROOTExecutor", (PyCFunction)JupyROOTExecutor, METH_VARARGS, (char *)"Create JupyROOTExecutor"},
    {(char *)"JupyROOTDeclarer", (PyCFunction)JupyROOTDeclarer, METH_VARARGS, (char *)"Create JupyROOTDeclarer"},
    {(char *)"JupyROOTExecutorHandler_Clear", (PyCFunction)JupyROOTExecutorHandler_Clear, METH_NOARGS,
@@ -106,6 +166,8 @@ static PyMethodDef gPyROOTMethods[] = {
     (char *)"Register a custom converter that is a reference to an existing converter"},
    {(char *)"CPyCppyyRegisterExecutorAlias", (PyCFunction)PyROOT::RegisterExecutorAlias, METH_VARARGS,
     (char *)"Register a custom executor that is a reference to an existing executor"},
+   {(char *)"PyObjRefCounterAsStdAny", (PyCFunction)PyROOT::PyObjRefCounterAsStdAny, METH_VARARGS,
+    (char *)"Wrap a reference count to any Python object in a std::any for resource management in C++"},
    {NULL, NULL, 0, NULL}};
 
 struct module_state {
@@ -146,8 +208,13 @@ extern "C" PyObject *PyInit_libROOTPythonizations()
    // keep gRootModule, but do not increase its reference count even as it is borrowed,
    // or a self-referencing cycle would be created
 
-   // setup PyROOT
-   PyROOT::Init();
+   // Initialize and acquire the GIL to allow for threading in ROOT
+#if PY_VERSION_HEX < 0x03090000
+   PyEval_InitThreads();
+#endif
+
+   // Make sure the interpreter is initialized once gROOT has been initialized
+   TInterpreter::Instance();
 
    // signal policy: don't abort interpreter in interactive mode
    CallContext::SetGlobalSignalPolicy(!gROOT->IsBatch());
