@@ -1,8 +1,9 @@
-import unittest
-import ROOT
-import numpy as np
-import sys
 import gc
+import sys
+import unittest
+
+import numpy as np
+import ROOT
 
 
 class DataFrameFromNumpy(unittest.TestCase):
@@ -11,9 +12,7 @@ class DataFrameFromNumpy(unittest.TestCase):
     with RDataFrame.
     """
 
-    dtypes = [
-        "int32", "int64", "uint32", "uint64", "float32", "float64"
-    ]
+    dtypes = ["int32", "int64", "uint32", "uint64", "float32", "float64"]
 
     def test_dtypes(self):
         """
@@ -24,6 +23,39 @@ class DataFrameFromNumpy(unittest.TestCase):
             df = ROOT.RDF.FromNumpy(data)
             self.assertEqual(df.Mean("x").GetValue(), 2)
 
+    def test_object_dtype_strings(self):
+        """
+        Test reading numpy arrays with dtype=object containing strings
+        """
+        data = {"x": np.array(["test_string_1", "test_string_2"], dtype=object)}
+        df = ROOT.RDF.FromNumpy(data)
+        colnames = df.GetColumnNames()
+
+        self.assertIn("x", colnames)
+
+        entries = df.AsNumpy()["x"]
+        self.assertTrue(np.array_equal(entries, np.array(["test_string_1", "test_string_2"], dtype=object)))
+
+    def test_empty_arrays(self):
+        """
+        Test creating an RDataFrame from an empty numpy array with different data types
+        """
+        for dtype in self.dtypes:
+            data = {"x": np.array([], dtype=dtype)}
+            df = ROOT.RDF.FromNumpy(data)
+            colnames = df.GetColumnNames()
+            self.assertIn("x", colnames)
+            self.assertEqual(df.Count().GetValue(), 0)
+
+        data_obj = {"x": np.array([], dtype="object")}
+        with self.assertRaises(RuntimeError) as context:
+            df = ROOT.RDF.FromNumpy(data_obj)
+
+        self.assertIn(
+            "Failure in creating column 'x' for RDataFrame: the input column type is 'object', which is not supported. Make sure your column type is supported",
+            str(context.exception),
+        )
+
     def test_multiple_columns(self):
         """
         Test reading multiple columns
@@ -146,14 +178,14 @@ class DataFrameFromNumpy(unittest.TestCase):
         """
         Test correct reading of a sliced numpy array (#13690)
         """
-        table = np.array([[1,2], [3,4]], dtype="int64")
-        columns = {'x': table[:,0], 'y': table[:,1]}
+        table = np.array([[1, 2], [3, 4]], dtype="int64")
+        columns = {"x": table[:, 0], "y": table[:, 1]}
         df = ROOT.RDF.FromNumpy(columns)
-        x_col = df.Take['Long64_t']("x")
-        y_col = df.Take['Long64_t']("y")
-        self.assertEqual(list(x_col.GetValue()), [1,3])
-        self.assertEqual(list(y_col.GetValue()), [2,4])
+        x_col = df.Take["Long64_t"]("x")
+        y_col = df.Take["Long64_t"]("y")
+        self.assertEqual(list(x_col.GetValue()), [1, 3])
+        self.assertEqual(list(y_col.GetValue()), [2, 4])
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
