@@ -45,7 +45,7 @@ void TPyArg::CallConstructor(PyObject *&pyself, PyObject *pyclass, const std::ve
    for (int i = 0; i < nArgs; ++i)
       PyTuple_SET_ITEM(pyargs, i, (PyObject *)args[i]);
    pyself = PyObject_Call(pyclass, pyargs, NULL);
-   Py_DECREF(pyargs);
+   Py_DecRef(pyargs);
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -55,7 +55,7 @@ void CallConstructor(PyObject *&pyself, PyObject *pyclass)
 
    PyObject *pyargs = PyTuple_New(0);
    pyself = PyObject_Call(pyclass, pyargs, NULL);
-   Py_DECREF(pyargs);
+   Py_DecRef(pyargs);
 }
 
 //- generic dispatcher -------------------------------------------------------
@@ -68,7 +68,7 @@ PyObject *TPyArg::CallMethod(PyObject *pymeth, const std::vector<TPyArg> &args)
    for (int i = 0; i < nArgs; ++i)
       PyTuple_SET_ITEM(pyargs, i, (PyObject *)args[i]);
    PyObject *result = PyObject_Call(pymeth, pyargs, NULL);
-   Py_DECREF(pyargs);
+   Py_DecRef(pyargs);
    return result;
 }
 
@@ -77,7 +77,7 @@ void TPyArg::CallDestructor(PyObject *&pyself, PyObject *, const std::vector<TPy
 {
    PyGILRAII gilRaii;
 
-   Py_XDECREF(pyself); // calls actual dtor if ref-count down to 0
+   Py_DecRef(pyself); // calls actual dtor if ref-count down to 0
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -85,7 +85,7 @@ void TPyArg::CallDestructor(PyObject *&pyself)
 {
    PyGILRAII gilRaii;
 
-   Py_XDECREF(pyself);
+   Py_DecRef(pyself);
 }
 
 //- constructors/destructor --------------------------------------------------
@@ -94,7 +94,7 @@ TPyArg::TPyArg(PyObject *pyobject)
    PyGILRAII gilRaii;
 
    // Construct a TPyArg from a python object.
-   Py_XINCREF(pyobject);
+   Py_IncRef(pyobject);
    fPyObject = pyobject;
 }
 
@@ -145,7 +145,7 @@ TPyArg::TPyArg(const TPyArg &s)
 {
    PyGILRAII gilRaii;
 
-   Py_XINCREF(s.fPyObject);
+   Py_IncRef(s.fPyObject);
    fPyObject = s.fPyObject;
 }
 
@@ -157,7 +157,7 @@ TPyArg &TPyArg::operator=(const TPyArg &s)
    PyGILRAII gilRaii;
 
    if (&s != this) {
-      Py_XINCREF(s.fPyObject);
+      Py_IncRef(s.fPyObject);
       fPyObject = s.fPyObject;
    }
    return *this;
@@ -170,7 +170,7 @@ TPyArg::~TPyArg()
 {
    PyGILRAII gilRaii;
 
-   Py_XDECREF(fPyObject);
+   Py_DecRef(fPyObject);
    fPyObject = NULL;
 }
 
@@ -180,6 +180,6 @@ TPyArg::operator PyObject *() const
    PyGILRAII gilRaii;
 
    // Extract the python object.
-   Py_XINCREF(fPyObject);
+   Py_IncRef(fPyObject);
    return fPyObject;
 }
