@@ -89,17 +89,21 @@ void ROOT::Internal::RStl::GenerateTClassFor(const clang::QualType &type, const
       }
    }
 
-   fList.insert( ROOT::TMetaUtils::AnnotatedRecordDecl(++fgCount,
-                                                       thisType.getTypePtr(),
-                                                       stlclass,
-                                                       "",
-                                                       false /* for backward compatibility rather than 'true' .. neither really make a difference */,
-                                                       false,
-                                                       false,
-                                                       false,
-                                                       -1,
-                                                       interp,
-                                                       normCtxt) );
+   // clang-format off
+   fList.insert(ROOT::TMetaUtils::AnnotatedRecordDecl(++fgCount,
+                                                      thisType.getTypePtr(),
+                                                      stlclass,
+                                                      "",
+                                                      false, /* for backward compatibility rather than 'true' ..
+                                                                neither really make a difference */
+                                                      false,
+                                                      false,
+                                                      false,
+                                                      -1,
+                                                      0,
+                                                      interp,
+                                                      normCtxt));
+   // clang-format on
 
    // fprintf(stderr,"Registered the STL class %s as needing a dictionary\n",R__GetQualifiedName(*stlclass).c_str());
 
@@ -149,7 +153,19 @@ void ROOT::Internal::RStl::GenerateTClassFor(const char *requestedName, const cl
       }
    }
 
-   fList.insert( ROOT::TMetaUtils::AnnotatedRecordDecl(++fgCount,stlclass,requestedName,true,false,false,false,-1, interp,normCtxt) );
+   // clang-format off
+   fList.insert(ROOT::TMetaUtils::AnnotatedRecordDecl(++fgCount,
+                                                      stlclass,
+                                                      requestedName,
+                                                      true,
+                                                      false,
+                                                      false,
+                                                      false,
+                                                      -1,
+                                                      0,
+                                                      interp,
+                                                      normCtxt));
+   // clang-format on
 
    TClassEdit::TSplitType splitType( requestedName, (TClassEdit::EModType)(TClassEdit::kLong64 | TClassEdit::kDropStd) );
    for(unsigned int i=0; i <  templateCl->getTemplateArgs().size(); ++i) {
