@@ -36,7 +36,7 @@ Begin_Macro
    gGeoManager->SetNsegments(80);
    top->Draw();
    TView *view = gPad->GetView();
-   view->ShowAxis();
+   if (view) view->ShowAxis();
 }
 End_Macro
 */
@@ -139,7 +139,7 @@ void TGeoTrd1::ComputeBBox()
 ////////////////////////////////////////////////////////////////////////////////
 /// Compute normal to closest surface from POINT.
 
-void TGeoTrd1::ComputeNormal(const Double_t *point, const Double_t *dir, Double_t *norm)
+void TGeoTrd1::ComputeNormal(const Double_t *point, const Double_t *dir, Double_t *norm) const
 {
    Double_t safe, safemin;
    //--- Compute safety first
