@@ -24,7 +24,7 @@ ClassImp(TEvePlot3D);
 
 TEvePlot3D::TEvePlot3D(const char* n, const char* t) :
    TEveElementList(n, t),
-   fPlot(0),
+   fPlot(nullptr),
    fLogX(kFALSE), fLogY(kFALSE), fLogZ(kFALSE)
 {
    InitMainTrans();
