@@ -41,13 +41,11 @@ public:
       });
    }
 
-   virtual ~RBrowserTreeWidget() = default;
+   ~RBrowserTreeWidget() override = default;
 
    std::string GetKind() const override { return "tree"s; }
    std::string GetTitle() override { return fTitle; }
-   std::string GetUrl() override { return fViewer.GetWindowUrl(false); }
-
-   void Show(const std::string &arg) override { fViewer.Show(arg); }
+   std::shared_ptr<RWebWindow> GetWindow() override { return fViewer.GetWindow(); }
 
    bool DrawElement(std::shared_ptr<Browsable::RElement> &elem, const std::string & = "") override
    {
@@ -115,5 +113,5 @@ protected:
    }
 public:
    RBrowserTreeProvider() : RBrowserWidgetProvider("tree") {}
-   ~RBrowserTreeProvider() = default;
+   ~RBrowserTreeProvider() override = default;
 } sRBrowserTreeProvider;
