@@ -731,19 +731,14 @@ void TRootBrowser::HandleMenu(Int_t id)
                   // Handle Help menu items...
       case kHelpAbout:
          {
-#ifdef R__UNIX
-            TString rootx = TROOT::GetBinDir() + "/root -a &";
-            gSystem->Exec(rootx);
-#else
 #ifdef WIN32
             new TWin32SplashThread(kTRUE);
 #else
             char str[32];
-            sprintf(str, "About ROOT %s...", gROOT->GetVersion());
+            snprintf(str, 32, "About ROOT %s...", gROOT->GetVersion());
             hd = new TRootHelpDialog(this, str, 600, 400);
             hd->SetText(gHelpAbout);
             hd->Popup();
-#endif
 #endif
          }
          break;
