@@ -49,6 +49,8 @@ RWebWindow::WebConn::~WebConn()
 }
 
 
+std::string RWebWindow::gJSROOTsettings = "";
+
 
 /** \class ROOT::RWebWindow
 \ingroup webdisplay
@@ -185,7 +187,7 @@ THttpServer *RWebWindow::GetServer()
 
 //////////////////////////////////////////////////////////////////////////////////////////
 /// Show window in specified location
-/// \see ROOT::RWebWindowsManager::Show for more info
+/// \see ROOT::RWebWindowsManager::Show
 /// \return (future) connection id (or 0 when fails)
 
 unsigned RWebWindow::Show(const RWebDisplayArgs &args)
@@ -196,8 +198,8 @@ unsigned RWebWindow::Show(const RWebDisplayArgs &args)
 //////////////////////////////////////////////////////////////////////////////////////////
 /// Start headless browser for specified window
 /// Normally only single instance is used, but many can be created
-/// See ROOT::RWebWindowsManager::Show() docu for more info
-/// returns (future) connection id (or 0 when fails)
+/// \see ROOT::RWebWindowsManager::Show
+/// \return (future) connection id (or 0 when fails)
 
 unsigned RWebWindow::MakeHeadless(bool create_new)
 {
@@ -273,12 +275,30 @@ std::shared_ptr<RWebWindow::WebConn> RWebWindow::FindConnection(unsigned wsid)
    return nullptr;
 }
 
+//////////////////////////////////////////////////////////////////////////////////////////
+/// Signal that connection is closing
+
+void RWebWindow::ClearConnection(std::shared_ptr<WebConn> &conn, bool provide_signal)
+{
+   if (!conn)
+      return;
+
+   if (provide_signal)
+      ProvideQueueEntry(conn->fConnId, kind_Disconnect, ""s);
+   for (auto &elem: conn->fEmbed) {
+      if (provide_signal)
+         elem.second->ProvideQueueEntry(conn->fConnId, kind_Disconnect, ""s);
+      elem.second->RemoveMasterConnection(conn->fConnId);
+   }
+
+   conn->fEmbed.clear();
+}
+
 //////////////////////////////////////////////////////////////////////////////////////////
 /// Remove connection with given websocket id
 
-std::shared_ptr<RWebWindow::WebConn> RWebWindow::RemoveConnection(unsigned wsid)
+std::shared_ptr<RWebWindow::WebConn> RWebWindow::RemoveConnection(unsigned wsid, bool provide_signal)
 {
-
    std::shared_ptr<WebConn> res;
 
    {
@@ -289,20 +309,16 @@ std::shared_ptr<RWebWindow::WebConn> RWebWindow::RemoveConnection(unsigned wsid)
             res = std::move(fConn[n]);
             fConn.erase(fConn.begin() + n);
             res->fActive = false;
+            res->fWasFirst = (n == 0);
             break;
          }
    }
 
-   if (res) {
-      for (auto &elem: res->fEmbed)
-         elem.second->RemoveMasterConnection(res->fConnId);
-      res->fEmbed.clear();
-   }
+   ClearConnection(res, provide_signal);
 
    return res;
 }
 
-
 //////////////////////////////////////////////////////////////////////////////////////////
 /// Add new master connection
 /// If there are many connections - only same master is allowed
@@ -503,11 +519,12 @@ unsigned RWebWindow::AddDisplayHandle(bool headless_mode, const std::string &key
 
 //////////////////////////////////////////////////////////////////////////////////////////
 /// Check if provided hash, ntry parameters from the connection request could be accepted
-/// \param hash - provided hash value which should match with HMAC hash for generated before connection key
-/// \param ntry - connection attempt number provided together with request, must come in increasing order
-/// \param remote - boolean flag indicating if request comming from remote (via real http),
+/// \param conn shared pointer to the web connection
+/// \param hash provided hash value which should match with HMAC hash for generated before connection key
+/// \param ntry connection attempt number provided together with request, must come in increasing order
+/// \param remote boolean flag indicating if request comming from remote (via real http),
 ///                 for local displays like Qt5 or CEF simpler connection rules are applied
-/// \param test_first_time - true if hash/ntry tested for the first time, false appears only with
+/// \param test_first_time true if hash/ntry tested for the first time, false appears only with
 ///                          websocket when connection accepted by server
 
 bool RWebWindow::_CanTrustIn(std::shared_ptr<WebConn> &conn, const std::string &hash, const std::string &ntry, bool remote, bool test_first_time)
@@ -600,8 +617,7 @@ void RWebWindow::RemoveKey(const std::string &key)
    }
 
    for (auto &conn : lst)
-      if (conn->fActive)
-         ProvideQueueEntry(conn->fConnId, kind_Disconnect, ""s);
+      ClearConnection(conn, conn->fActive);
 }
 
 
@@ -610,9 +626,9 @@ void RWebWindow::RemoveKey(const std::string &key)
 
 std::string RWebWindow::GenerateKey() const
 {
-   auto key = RWebWindowsManager::GenerateKey(32);
+   auto key = RWebWindowsManager::GenerateKey(IsRequireAuthKey() ? 32 : 4);
 
-   R__ASSERT((!HasKey(key) && (key != fMgr->fSessionKey)) && "Fail to generate window connection key");
+   R__ASSERT((!IsRequireAuthKey() || (!HasKey(key) && (key != fMgr->fSessionKey))) && "Fail to generate window connection key");
 
    return key;
 }
@@ -681,20 +697,25 @@ void RWebWindow::CheckInactiveConnections()
    }
 
    for (auto &entry : clr)
-      ProvideQueueEntry(entry->fConnId, kind_Disconnect, ""s);
-
+      ClearConnection(entry, true);
 }
 
 /////////////////////////////////////////////////////////////////////////
 /// Configure maximal number of allowed connections - 0 is unlimited
 /// Will not affect already existing connections
 /// Default is 1 - the only client is allowed
+/// Because of security reasons setting number of allowed connections is not sufficient now.
+/// To enable multi-connection mode, one also has to call
+/// `ROOT::RWebWindowsManager::SetSingleConnMode(false);`
+/// before creating of the RWebWindow instance
 
 void RWebWindow::SetConnLimit(unsigned lmt)
 {
+   bool single_conn_mode = RWebWindowWSHandler::GetBoolEnv("WebGui.SingleConnMode", 1) == 1;
+
    std::lock_guard<std::mutex> grd(fConnMutex);
 
-   fConnLimit = lmt;
+   fConnLimit = single_conn_mode ? 1 : lmt;
 }
 
 /////////////////////////////////////////////////////////////////////////
@@ -746,12 +767,37 @@ bool RWebWindow::ProcessWS(THttpCallArg &arg)
       return false;
 
    if (arg.IsMethod("WS_CONNECT")) {
-
       TUrl url;
       url.SetOptions(arg.GetQuery());
+      std::string key, ntry;
+      if(url.HasOption("key"))
+         key = url.GetValueFromOptions("key");
+      if(url.HasOption("ntry"))
+         ntry = url.GetValueFromOptions("ntry");
 
       std::lock_guard<std::mutex> grd(fConnMutex);
 
+      if (is_longpoll && !is_remote  && ntry == "1"s) {
+         // special workaround for local displays like qt6/cef
+         // they are not disconnected regularly when page reload is invoked
+         // therefore try to detect if new key is applied
+         for (unsigned indx = 0; indx < fConn.size(); indx++) {
+            if (!fConn[indx]->fNewKey.empty() && (key == HMAC(fConn[indx]->fNewKey, ""s, "attempt_1", 9))) {
+               auto conn = std::move(fConn[indx]);
+               fConn.erase(fConn.begin() + indx);
+               conn->fKeyUsed = 0;
+               conn->fKey = conn->fNewKey;
+               conn->fNewKey.clear();
+               conn->fConnId = ++fConnCnt; // change connection id to avoid confusion
+               conn->fWasFirst = indx == 0;
+               conn->ResetData();
+               conn->ResetStamps(); // reset stamps, after timeout connection wll be removed
+               fPendingConn.emplace_back(conn);
+               break;
+            }
+         }
+      }
+
       // refuse connection when number of connections exceed limit
       if (fConnLimit && (fConn.size() >= fConnLimit))
          return false;
@@ -767,20 +813,14 @@ bool RWebWindow::ProcessWS(THttpCallArg &arg)
       if (!IsRequireAuthKey())
          return true;
 
-      if(!url.HasOption("key")) {
+      if(key.empty()) {
          R__LOG_DEBUG(0, WebGUILog()) << "key parameter not provided in url";
          return false;
       }
 
-      std::string key, ntry;
-      if (url.HasOption("key"))
-         key = url.GetValueFromOptions("key");
-      if(url.HasOption("ntry"))
-         ntry = url.GetValueFromOptions("ntry");
-
       for (auto &conn : fPendingConn)
          if (_CanTrustIn(conn, key, ntry, is_remote, true /* test_first_time */))
-             return true;
+            return true;
 
       return false;
    }
@@ -820,7 +860,13 @@ bool RWebWindow::ProcessWS(THttpCallArg &arg)
          // preserve key for longpoll or when with session key used for HMAC hash of messages
          // conn->fKey.clear();
          conn->ResetStamps();
-         fConn.emplace_back(conn);
+         // remove files which are required for startup
+         if (conn->fDisplayHandle)
+            conn->fDisplayHandle->RemoveStartupFiles();
+         if (conn->fWasFirst)
+            fConn.emplace(fConn.begin(), conn);
+         else
+            fConn.emplace_back(conn);
          return true;
       } else if (!IsRequireAuthKey() && (!fConnLimit || (fConn.size() < fConnLimit))) {
          fConn.emplace_back(std::make_shared<WebConn>(++fConnCnt, arg.GetWSId()));
@@ -831,7 +877,7 @@ bool RWebWindow::ProcessWS(THttpCallArg &arg)
       return false;
    }
 
-   // special sequrity check for the longpoll requests
+   // special security check for the longpoll requests
    if(is_longpoll) {
       auto conn = FindConnection(arg.GetWSId());
       if (!conn)
@@ -853,10 +899,9 @@ bool RWebWindow::ProcessWS(THttpCallArg &arg)
    if (arg.IsMethod("WS_CLOSE")) {
       // connection is closed, one can remove handle, associated window will be closed
 
-      auto conn = RemoveConnection(arg.GetWSId());
+      auto conn = RemoveConnection(arg.GetWSId(), true);
 
       if (conn) {
-         ProvideQueueEntry(conn->fConnId, kind_Disconnect, ""s);
          bool do_clear_on_close = false;
          if (!conn->fNewKey.empty()) {
             // case when same handle want to be reused by client with new key
@@ -1014,6 +1059,11 @@ bool RWebWindow::ProcessWS(THttpCallArg &arg)
       if ((cdata.compare(0, 6, "READY=") == 0) && !conn->fReady) {
 
          std::string key = cdata.substr(6);
+         bool new_key = false;
+         if (key.find("generate_key;") == 0) {
+            new_key = true;
+            key = key.substr(13);
+         }
 
          if (key.empty() && IsNativeOnlyConn()) {
             RemoveConnection(conn->fWSId);
@@ -1034,6 +1084,11 @@ bool RWebWindow::ProcessWS(THttpCallArg &arg)
             ProvideQueueEntry(conn->fConnId, kind_Connect, ""s);
             conn->fReady = 10;
          }
+         if (new_key && !fMaster) {
+            conn->fNewKey = GenerateKey();
+            if(!conn->fNewKey.empty())
+               SubmitData(conn->fConnId, true, "NEW_KEY="s + conn->fNewKey, 0);
+         }
       } else if (cdata.compare(0, 8, "CLOSECH=") == 0) {
          int channel = std::stoi(cdata.substr(8));
          auto iter = conn->fEmbed.find(channel);
@@ -1064,8 +1119,7 @@ bool RWebWindow::ProcessWS(THttpCallArg &arg)
          ProvideQueueEntry(conn->fConnId, kind_Connect, ""s);
          conn->fReady = 10;
       } else {
-         ProvideQueueEntry(conn->fConnId, kind_Disconnect, ""s);
-         RemoveConnection(conn->fWSId);
+         RemoveConnection(conn->fWSId, true);
       }
    } else if (nchannel == 1) {
       ProvideQueueEntry(conn->fConnId, kind_Data, std::move(cdata));
@@ -1253,17 +1307,26 @@ std::string RWebWindow::GetAddr() const
 }
 
 ///////////////////////////////////////////////////////////////////////////////////
+/// DEPRECATED. Use GetUrl method instead while more arguments are required to connect with the widget
 /// Returns relative URL address for the specified window
 /// Address can be required if one needs to access data from one window into another window
 /// Used for instance when inserting panel into canvas
 
 std::string RWebWindow::GetRelativeAddr(const std::shared_ptr<RWebWindow> &win) const
 {
-   return GetRelativeAddr(*win);
+   if (fMgr != win->fMgr) {
+      R__LOG_ERROR(WebGUILog()) << "Same web window manager should be used";
+      return "";
+   }
+
+   std::string res("../");
+   res.append(win->GetAddr());
+   res.append("/");
+   return res;
 }
 
 ///////////////////////////////////////////////////////////////////////////////////
-/// Returns relative URL address for the specified window
+/// DEPRECATED. Use GetUrl method instead while more arguments are required to connect with the widget
 /// Address can be required if one needs to access data from one window into another window
 /// Used for instance when inserting panel into canvas
 
@@ -1412,6 +1475,14 @@ std::vector<unsigned> RWebWindow::GetConnections(unsigned excludeid) const
 
 bool RWebWindow::HasConnection(unsigned connid, bool only_active) const
 {
+   if (fMaster) {
+      auto lst = GetMasterConnections(connid);
+      for (auto & entry : lst)
+         if (fMaster->HasConnection(entry.connid, only_active))
+            return true;
+      return false;
+   }
+
    std::lock_guard<std::mutex> grd(fConnMutex);
 
    for (auto &conn : fConn) {
@@ -1483,19 +1554,27 @@ RWebWindow::ConnectionsList_t RWebWindow::GetWindowConnections(unsigned connid,
 
 bool RWebWindow::CanSend(unsigned connid, bool direct) const
 {
-   auto arr = GetWindowConnections(connid, direct); // for direct sending connection has to be active
+   if (fMaster) {
+      auto lst = GetMasterConnections(connid);
+      for (auto &entry : lst) {
+         if (!fMaster->CanSend(entry.connid, direct))
+            return false;
+      }
+   } else {
+      auto arr = GetWindowConnections(connid, direct); // for direct sending connection has to be active
 
-   auto maxqlen = GetMaxQueueLength();
+      auto maxqlen = GetMaxQueueLength();
 
-   for (auto &conn : arr) {
+      for (auto &conn : arr) {
 
-      std::lock_guard<std::mutex> grd(conn->fMutex);
+         std::lock_guard<std::mutex> grd(conn->fMutex);
 
-      if (direct && (!conn->fQueue.empty() || (conn->fSendCredits == 0) || conn->fDoingSend))
-         return false;
+         if (direct && (!conn->fQueue.empty() || (conn->fSendCredits == 0) || conn->fDoingSend))
+            return false;
 
-      if (conn->fQueue.size() >= maxqlen)
-         return false;
+         if (conn->fQueue.size() >= maxqlen)
+            return false;
+      }
    }
 
    return true;
@@ -1510,10 +1589,21 @@ int RWebWindow::GetSendQueueLength(unsigned connid) const
 {
    int maxq = -1;
 
-   for (auto &conn : GetWindowConnections(connid)) {
-      std::lock_guard<std::mutex> grd(conn->fMutex);
-      int len = conn->fQueue.size();
-      if (len > maxq) maxq = len;
+   if (fMaster) {
+      auto lst = GetMasterConnections(connid);
+      for (auto &entry : lst) {
+         int len = fMaster->GetSendQueueLength(entry.connid);
+         if (len > maxq)
+            maxq = len;
+      }
+   } else {
+      auto lst = GetWindowConnections(connid);
+      for (auto &conn : lst) {
+         std::lock_guard<std::mutex> grd(conn->fMutex);
+         int len = conn->fQueue.size();
+         if (len > maxq)
+            maxq = len;
+      }
    }
 
    return maxq;
@@ -1554,7 +1644,7 @@ void RWebWindow::SubmitData(unsigned connid, bool txt, std::string &&data, int c
 
    for (auto &conn : arr) {
 
-      if (fProtocolCnt >= 0)
+      if ((fProtocolCnt >= 0) && (chid > 0))
          if (!fProtocolConnId || (conn->fConnId == fProtocolConnId)) {
             fProtocolConnId = conn->fConnId; // remember connection
             std::string fname = fProtocolPrefix;
@@ -1778,6 +1868,22 @@ void RWebWindow::SetCallBacks(WebWindowConnectCallback_t conn, WebWindowDataCall
    fDisconnCallback = disconn;
 }
 
+/////////////////////////////////////////////////////////////////////////////////
+/// Reset window call-backs and close connections
+/// Should be invoked in widget destructor to simplify cleanup process
+
+void RWebWindow::Reset()
+{
+   CloseConnections();
+
+   fConnCallback = nullptr;
+   fDataCallback = nullptr;
+   fDisconnCallback = nullptr;
+
+   if (fWSHandler)
+      fWSHandler->SetDisabled();
+}
+
 /////////////////////////////////////////////////////////////////////////////////
 /// Waits until provided check function or lambdas returns non-zero value
 /// Check function has following signature: int func(double spent_tm)
@@ -1862,7 +1968,7 @@ unsigned RWebWindow::AddEmbedWindow(std::shared_ptr<RWebWindow> window, unsigned
 }
 
 /////////////////////////////////////////////////////////////////////////////////
-/// Remove RWebWindow associated with the channelfEmbed
+/// Remove RWebWindow associated with the channel
 
 void RWebWindow::RemoveEmbedWindow(unsigned connid, int channel)
 {
@@ -1918,21 +2024,25 @@ unsigned RWebWindow::ShowWindow(std::shared_ptr<RWebWindow> window, const RWebDi
       return 0;
 
    if (args.GetBrowserKind() == RWebDisplayArgs::kEmbedded) {
-      if (args.fMaster && window->fMaster && window->fMaster != args.fMaster) {
+      auto master = args.fMaster;
+      while (master && master->fMaster)
+         master = master->fMaster;
+
+      if (master && window->fMaster && window->fMaster != master) {
          R__LOG_ERROR(WebGUILog()) << "Cannot use different master for same RWebWindow";
          return 0;
       }
 
-      unsigned connid = args.fMaster ? args.fMaster->AddEmbedWindow(window, args.fMasterConnection, args.fMasterChannel) : 0;
+      unsigned connid = master ? master->AddEmbedWindow(window, args.fMasterConnection, args.fMasterChannel) : 0;
 
       if (connid > 0) {
 
          window->RemoveMasterConnection(connid);
 
-         window->AddMasterConnection(args.fMaster, connid, args.fMasterChannel);
+         window->AddMasterConnection(master, connid, args.fMasterChannel);
 
          // inform client that connection is established and window initialized
-         args.fMaster->SubmitData(connid, true, "EMBED_DONE"s, args.fMasterChannel);
+         master->SubmitData(connid, true, "EMBED_DONE"s, args.fMasterChannel);
 
          // provide call back for window itself that connection is ready
          window->ProvideQueueEntry(connid, kind_Connect, ""s);
@@ -1987,7 +2097,7 @@ bool RWebWindow::EmbedFileDialog(const std::shared_ptr<RWebWindow> &window, unsi
 
 /////////////////////////////////////////////////////////////////////////////////////
 /// Calculate HMAC checksum for provided key and message
-/// Key combained from connection key and session key
+/// Key combined from connection key and session key
 
 std::string RWebWindow::HMAC(const std::string &key, const std::string &sessionKey, const char *msg, int msglen)
 {
@@ -2043,3 +2153,16 @@ std::string RWebWindow::HMAC(const std::string &key, const std::string &sessionK
 
    return get_digest(hash3, true);
 }
+
+/////////////////////////////////////////////////////////////////////////////////////
+/// Set JSROOT settings as json string
+/// Will be applied for any web window at the connection time
+/// Can be used to chang `settings` object of JSROOT like:
+/// ~~~ {.cpp}
+/// ROOT::RWebWindow::SetJSROOTSettings("{ ToolBar: false, CanEnlarge: false }");
+/// ~~~
+
+void RWebWindow::SetJSROOTSettings(const std::string &json)
+{
+   gJSROOTsettings = json;
+}
