@@ -116,7 +116,7 @@ End_Macro
 ////////////////////////////////////////////////////////////////////////////////
 /// Palette default constructor.
 
-TPaletteAxis::TPaletteAxis(): TPave()
+TPaletteAxis::TPaletteAxis()
 {
    fH = nullptr;
    SetName("");
@@ -477,9 +477,23 @@ void TPaletteAxis::Paint(Option_t *)
    ndivz = TMath::Abs(ndivz);
    Int_t theColor, color;
    // import Attributes already here since we might need them for CJUST
-   if (fH && fH->GetDimension() == 2) fAxis.ImportAxisAttributes(fH->GetZaxis());
-   // for 3D histograms there is no palette's title
-   if (fH && fH->GetDimension() >  2) fAxis.SetTitle("");
+   if (fH && fH->GetDimension() == 2) {
+      fAxis.ImportAxisAttributes(fH->GetZaxis());
+      TString ztit = fAxis.GetTitle();
+      if (ztit.Index(";")>0) {
+         ztit.Remove(ztit.Index(";"),ztit.Length());
+         fAxis.SetTitle(ztit.Data());
+      }
+   }
+   // the 3D histogram's title is stored in Zaxis
+   if (fH && fH->GetDimension() >  2) {
+      TString ztit = fH->GetZaxis()->GetTitle();
+      fAxis.SetTitle("");
+      if (ztit.Index(";")>0) {
+         ztit.Remove(0,ztit.Index(";")+1);
+         fAxis.SetTitle(ztit.Data());
+      }
+   }
    // case option "CJUST": put labels directly at color boundaries
    TLatex *label = nullptr;
    TLine *line = nullptr;
@@ -608,52 +622,37 @@ void TPaletteAxis::Paint(Option_t *)
 
 void TPaletteAxis::SavePrimitive(std::ostream &out, Option_t * /*= ""*/)
 {
-   if (!fH) return;
+   if (!fH)
+      return;
 
-   char quote = '"';
-
-   out << "   " << std::endl;
-   if (gROOT->ClassSaved(TPaletteAxis::Class())) {
-      out << "   ";
-   } else {
-      out << "   " << ClassName() << " *";
-   }
-   if (fOption.Contains("NDC")) {
-      out << "palette = new " << ClassName() << "(" << fX1NDC << "," << fY1NDC << "," << fX2NDC << "," << fY2NDC
-          << "," << fH->GetName() << ");" << std::endl;
-   } else {
-      out << "palette = new " << ClassName() << "(" << fX1 << "," << fY1 << "," << fX2 << "," << fY2
-          << "," << fH->GetName() << ");" << std::endl;
-   }
-   out << "   palette->SetNdivisions(" << fH->GetZaxis()->GetNdivisions() << ");" << std::endl;
-   out << "   palette->SetAxisColor(" << fH->GetZaxis()->GetAxisColor() << ");" << std::endl;
-   out << "   palette->SetLabelColor(" << fH->GetZaxis()->GetLabelColor() << ");" << std::endl;
-   out << "   palette->SetLabelFont(" << fH->GetZaxis()->GetLabelFont() << ");" << std::endl;
-   out << "   palette->SetLabelOffset(" << fH->GetZaxis()->GetLabelOffset() << ");" << std::endl;
-   out << "   palette->SetLabelSize(" << fH->GetZaxis()->GetLabelSize() << ");" << std::endl;
-   out << "   palette->SetMaxDigits(" << fH->GetZaxis()->GetMaxDigits() << ");" << std::endl;
-   out << "   palette->SetTickLength(" << fH->GetZaxis()->GetTickLength() << ");" << std::endl;
-   out << "   palette->SetTitleOffset(" << fH->GetZaxis()->GetTitleOffset() << ");" << std::endl;
-   out << "   palette->SetTitleSize(" << fH->GetZaxis()->GetTitleSize() << ");" << std::endl;
-   out << "   palette->SetTitleColor(" << fH->GetZaxis()->GetTitleColor() << ");" << std::endl;
-   out << "   palette->SetTitleFont(" << fH->GetZaxis()->GetTitleFont() << ");" << std::endl;
-   out << "   palette->SetTitle(" << quote << fH->GetZaxis()->GetTitle() << quote << ");" << std::endl;
+   SavePrimitiveConstructor(out, Class(), "palette", GetSavePaveArgs(fH->GetName(), kFALSE));
+   out << "   palette->SetNdivisions(" << fH->GetZaxis()->GetNdivisions() << ");\n";
+   out << "   palette->SetAxisColor(" << TColor::SavePrimitiveColor(fH->GetZaxis()->GetAxisColor()) << ");\n";
+   out << "   palette->SetLabelColor(" << TColor::SavePrimitiveColor(fH->GetZaxis()->GetLabelColor()) << ");\n";
+   out << "   palette->SetLabelFont(" << fH->GetZaxis()->GetLabelFont() << ");\n";
+   out << "   palette->SetLabelOffset(" << fH->GetZaxis()->GetLabelOffset() << ");\n";
+   out << "   palette->SetLabelSize(" << fH->GetZaxis()->GetLabelSize() << ");\n";
+   out << "   palette->SetMaxDigits(" << fH->GetZaxis()->GetMaxDigits() << ");\n";
+   out << "   palette->SetTickLength(" << fH->GetZaxis()->GetTickLength() << ");\n";
+   out << "   palette->SetTitleOffset(" << fH->GetZaxis()->GetTitleOffset() << ");\n";
+   out << "   palette->SetTitleSize(" << fH->GetZaxis()->GetTitleSize() << ");\n";
+   out << "   palette->SetTitleColor(" << TColor::SavePrimitiveColor(fH->GetZaxis()->GetTitleColor()) << ");\n";
+   out << "   palette->SetTitleFont(" << fH->GetZaxis()->GetTitleFont() << ");\n";
+   out << "   palette->SetTitle(\"" << TString(fH->GetZaxis()->GetTitle()).ReplaceSpecialCppChars() << "\");\n";
    SaveFillAttributes(out, "palette", -1, -1);
    SaveLineAttributes(out, "palette", 1, 1, 1);
 }
 
-
 ////////////////////////////////////////////////////////////////////////////////
 /// Unzoom the palette
 
 void TPaletteAxis::UnZoom()
 {
-   if (!fH) return;
-   TView *view = gPad ? gPad->GetView() : nullptr;
-   if (view) {
-      delete view;
+   if (!fH)
+      return;
+   // if view exists - it will be deleted
+   if (gPad)
       gPad->SetView(nullptr);
-   }
    fH->GetZaxis()->SetRange(0, 0);
    if (fH->GetDimension() == 2) {
       fH->SetMinimum();
