@@ -16,6 +16,7 @@
 #include "llvm/ADT/StringSet.h"
 #include "llvm/BinaryFormat/Magic.h"
 #include "llvm/Support/DynamicLibrary.h"
+#include "llvm/Support/FileSystem.h"
 #include "llvm/Support/Path.h"
 
 #include <fstream>
@@ -68,11 +69,11 @@ namespace cling {
   /// Example: substFront("@rpath/abc", "@rpath/", "/tmp") -> "/tmp/abc"
   static std::string substFront(llvm::StringRef original, llvm::StringRef pattern,
                                 llvm::StringRef replacement) {
-    if (!original.startswith_lower(pattern))
+    if (!original.starts_with_insensitive(pattern))
       return original.str();
     llvm::SmallString<512> result(replacement);
     result.append(original.drop_front(pattern.size()));
-    return result.str();
+    return result.str().str();
   }
 
   ///\returns substitution of all known linker variables in \c original
@@ -167,7 +168,7 @@ namespace cling {
         if (DEBUG > 7) {
           cling::errs() << " ... Found (in RPATH)!\n";
         }
-        return ThisPath.str();
+        return ThisPath.str().str();
       }
     }
     // m_SearchPaths
@@ -182,7 +183,7 @@ namespace cling {
         if (DEBUG > 7) {
           cling::errs() << " ... Found (in SearchPaths)!\n";
         }
-        return ThisPath.str();
+        return ThisPath.str().str();
       }
     }
     // RUNPATH
@@ -197,7 +198,7 @@ namespace cling {
         if (DEBUG > 7) {
           cling::errs() << " ... Found (in RUNPATH)!\n";
         }
-        return ThisPath.str();
+        return ThisPath.str().str();
       }
     }
 
@@ -306,7 +307,7 @@ namespace cling {
     // Subst all known linker variables ($origin, @rpath, etc.)
 #ifdef __APPLE__
     // On MacOS @rpath is preplaced by all paths in RPATH one by one.
-    if (libStem.startswith_lower("@rpath")) {
+    if (libStem.starts_with_insensitive("@rpath")) {
       for (auto& P : RPath) {
         std::string result = substFront(libStem, "@rpath", P);
         if (isSharedLibrary(result))
@@ -327,7 +328,7 @@ namespace cling {
       foundName = lookupLibMaybeAddExt(libStem, RPath, RunPath, libLoader);
       if (foundName.empty()) {
         llvm::StringRef libStemName = llvm::sys::path::filename(libStem);
-        if (!libStemName.startswith("lib")) {
+        if (!libStemName.starts_with("lib")) {
           // try with "lib" prefix:
           foundName = lookupLibMaybeAddExt(
              libStem.str().insert(libStem.size()-libStemName.size(), "lib"),
@@ -356,11 +357,12 @@ namespace cling {
         (resolved ? "resolved" : "not-resolved") << "\n";
     }
 
-    std::string lResolved;
-    const std::string& canonicalLoadedLib = resolved ? libStem.str() : lResolved;
-    if (!resolved) {
-      lResolved = lookupLibrary(libStem);
-      if (lResolved.empty())
+    std::string canonicalLoadedLib;
+    if (resolved) {
+      canonicalLoadedLib = libStem.str();
+    } else {
+      canonicalLoadedLib = lookupLibrary(libStem);
+      if (canonicalLoadedLib.empty())
         return kLoadLibNotFound;
     }
 
@@ -399,7 +401,7 @@ namespace cling {
     if (!isLibraryLoaded(canonicalLoadedLib))
       return;
 
-    DyLibHandle dyLibHandle = 0;
+    DyLibHandle dyLibHandle = nullptr;
     for (DyLibs::const_iterator I = m_DyLibs.begin(), E = m_DyLibs.end();
          I != E; ++I) {
       if (I->second == canonicalLoadedLib) {
@@ -442,10 +444,6 @@ namespace cling {
     }
   }
 
-  void DynamicLibraryManager::ExposeHiddenSharedLibrarySymbols(void* handle) {
-    llvm::sys::DynamicLibrary::addPermanentLibrary(const_cast<void*>(handle));
-  }
-
   bool DynamicLibraryManager::isSharedLibrary(llvm::StringRef libFullPath,
                                               bool* exists /*=0*/) {
     using namespace llvm;
