@@ -540,19 +540,9 @@ CodeGenModule::EmitCXXGlobalVarDeclInitFunc(const VarDecl *D,
     getCXXABI().getMangleContext().mangleDynamicInitializer(D, Out);
   }
 
-  // Use the module name to make the initializer unique accross modules.
-  SmallString<128> moduleName(TheModule.getName());
-  for (size_t i = 0; i < moduleName.size(); ++i) {
-    // Replace everything that's not [a-zA-Z0-9._] with a _. This set happens
-    // to be the set of C preprocessing numbers.
-    if (!isPreprocessingNumberBody(moduleName[i]))
-      moduleName[i] = '_';
-  }
-
   // Create a variable initialization function.
   llvm::Function *Fn = CreateGlobalInitOrCleanUpFunction(
-      FTy, llvm::Twine(FnName)+moduleName.str() + "_",
-      getTypes().arrangeNullaryFunction(), D->getLocation());
+      FTy, FnName.str(), getTypes().arrangeNullaryFunction(), D->getLocation());
 
   auto *ISA = D->getAttr<InitSegAttr>();
   CodeGenFunction(*this).GenerateCXXGlobalVarDeclInitFunc(Fn, D, Addr,
