@@ -185,7 +185,9 @@ THttpServer::THttpServer(const char *engine) : TNamed("http", "ROOT http server"
 
    AddLocation("jsrootsys/", fJSROOTSYS.Data());
 
-   if (!basic_sniffer) {
+   if (basic_sniffer) {
+      AddLocation("rootsys_fonts/", TString::Format("%s/fonts", TROOT::GetDataDir().Data()));
+   } else {
       AddLocation("currentdir/", ".");
       AddLocation("rootsys/", TROOT::GetRootSys());
    }
@@ -194,12 +196,18 @@ THttpServer::THttpServer(const char *engine) : TNamed("http", "ROOT http server"
    fDrawPage = fJSROOTSYS + "/files/draw.htm";
 
    TRootSniffer *sniff = nullptr;
-   if (basic_sniffer) {
-      sniff = new TRootSniffer("sniff");
+   if (!basic_sniffer) {
+      static const TClass *snifferClass = TClass::GetClass("TRootSnifferFull");
+      if (snifferClass && snifferClass->IsLoaded())
+         sniff = (TRootSniffer *)snifferClass->New();
+      else
+         ::Warning("THttpServer::THttpServer", "Fail to load TRootSnifferFull class, use basic functionality");
+   }
+
+   if (!sniff) {
+      sniff = new TRootSniffer();
       sniff->SetScanGlobalDir(kFALSE);
       sniff->CreateOwnTopFolder(); // use dedicated folder
-   } else {
-      sniff = (TRootSniffer *)gROOT->ProcessLineSync("new TRootSnifferFull(\"sniff\");");
    }
 
    SetSniffer(sniff);
@@ -322,7 +330,7 @@ void THttpServer::SetWSOnly(Bool_t on)
 ///
 /// One could map some system folder to the server like
 ///
-///     serv->AddLocation("mydir/","/home/user/specials");
+///     serv->AddLocation("mydir/", "/home/user/specials");
 ///
 /// Than files from this directory could be addressed via server like `http://localhost:8080/mydir/myfile.root`
 
@@ -342,8 +350,8 @@ void THttpServer::AddLocation(const char *prefix, const char *path)
 ///
 /// One could specify address like:
 ///
-/// * https://root.cern.ch/js/7.1.0/
-/// * http://jsroot.gsi.de/7.1.0/
+/// * https://root.cern/js/7.9.0/
+/// * https://jsroot.gsi.de/7.9.0/
 ///
 /// This allows to get new JSROOT features with old server,
 /// reduce load on THttpServer instance, also startup time can be improved
@@ -563,7 +571,7 @@ Bool_t THttpServer::VerifyFilePath(const char *fname)
 
    Int_t level = 0;
 
-   while (*fname != 0) {
+   while (*fname) {
 
       // find next slash or backslash
       const char *next = strpbrk(fname, "/\\");
@@ -686,8 +694,6 @@ Bool_t THttpServer::SubmitHttp(std::shared_ptr<THttpCallArg> arg, Bool_t can_run
       return kTRUE;
    }
 
-   printf("Calling SubmitHttp\n");
-
    // add call arg to the list
    std::unique_lock<std::mutex> lk(fMutex);
    fArgs.push(arg);
@@ -819,7 +825,7 @@ std::string THttpServer::BuildWSEntryPage()
          if (arr.length() > 1)
             arr.append(", ");
 
-         arr.append(Form("{ name: \"%s\", title: \"%s\" }", ws->GetName(), ws->GetTitle()));
+         arr.append(TString::Format("{ name: \"%s\", title: \"%s\" }", ws->GetName(), ws->GetTitle()).Data());
       }
    }
 
@@ -837,43 +843,131 @@ std::string THttpServer::BuildWSEntryPage()
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-/// Replaces all references like "jsrootsys/..."
+/// Replaces all references like "jsrootsys/..." or other pre-configured pathes
 ///
 /// Either using pre-configured JSROOT installation from web or
 /// redirect to jsrootsys from the main server path to benefit from browser caching
+/// Creates appropriate importmap instead of <!--jsroot_importmap--> placeholder
 
-void THttpServer::ReplaceJSROOTLinks(std::shared_ptr<THttpCallArg> &arg)
+void THttpServer::ReplaceJSROOTLinks(std::shared_ptr<THttpCallArg> &arg, const std::string &version)
 {
-   std::string repl;
+   const std::string place_holder = "<!--jsroot_importmap-->";
 
-   if (fJSROOT.Length() > 0) {
-      repl = "=\"";
-      repl.append(fJSROOT.Data());
-      if (repl.back() != '/')
-         repl.append("/");
-   } else {
-      Int_t cnt = 0;
-      if (arg->fPathName.Length() > 0) cnt++;
-      for (Int_t n = 1; n < arg->fPathName.Length()-1; ++n)
-         if (arg->fPathName[n] == '/') {
-            if (arg->fPathName[n-1] != '/') {
-               cnt++; // normal slash in the middle, count it
-            } else {
-               cnt = 0; // double slash, do not touch such path
-               break;
-            }
+   auto p = arg->fContent.find(place_holder);
+
+   bool old_format = (p == std::string::npos);
+
+   // count slashes to handler relative paths to jsroot
+   Int_t slash_cnt = 0;
+   if (arg->fPathName.Length() > 0)
+      slash_cnt++;
+   for (Int_t n = 1; n < arg->fPathName.Length()-1; ++n)
+      if (arg->fPathName[n] == '/') {
+         if (arg->fPathName[n-1] != '/') {
+            slash_cnt++; // normal slash in the middle, count it
+         } else {
+            slash_cnt = 0; // double slash, do not touch such path
+            break;
          }
-
-      if (cnt > 0) {
-         repl = "=\"";
-         while (cnt-- >0) repl.append("../");
-         repl.append("jsrootsys/");
       }
-   }
 
-   if (!repl.empty()) {
-      arg->ReplaceAllinContent("=\"jsrootsys/", repl);
-      arg->ReplaceAllinContent("from './jsrootsys/", TString::Format("from '%s", repl.substr(2).c_str()).Data());
+
+   if (old_format) {
+      // old functionality
+
+      if (!version.empty()) {
+         // replace link to JSROOT modules in import statements emulating new version for browser
+         std::string search = "from './jsrootsys/";
+         std::string replace = "from './" + version + "/jsrootsys/";
+         arg->ReplaceAllinContent(search, replace);
+         // replace link to ROOT ui5 modules in import statements emulating new version for browser
+         search = "from './rootui5sys/";
+         replace = "from './" + version + "/rootui5sys/";
+         arg->ReplaceAllinContent(search, replace);
+         // replace link on old JSRoot.core.js script - if still appears
+         search = "jsrootsys/scripts/JSRoot.core.";
+         replace = version + "/jsrootsys/scripts/JSRoot.core.";
+         arg->ReplaceAllinContent(search, replace, true);
+         arg->AddNoCacheHeader();
+      }
+
+      std::string repl;
+
+      if (fJSROOT.Length() > 0) {
+         repl = "=\"";
+         repl.append(fJSROOT.Data());
+         if (repl.back() != '/')
+            repl.append("/");
+      } else {
+         if (slash_cnt > 0) {
+            repl = "=\"";
+            while (slash_cnt-- > 0) repl.append("../");
+            repl.append("jsrootsys/");
+         }
+      }
+
+      if (!repl.empty()) {
+         arg->ReplaceAllinContent("=\"jsrootsys/", repl);
+         arg->ReplaceAllinContent("from './jsrootsys/", TString::Format("from '%s", repl.substr(2).c_str()).Data());
+      }
+   } else {
+      // new functionality creating importmap
+
+      std::string path_prefix, jsroot_prefix;
+      if (slash_cnt > 0) {
+         path_prefix = "";
+         while (slash_cnt-- > 0)
+            path_prefix.append("../");
+      } else {
+         path_prefix = "./";
+      }
+
+      if (!version.empty())
+         path_prefix.append(version + "/");
+
+      if (fJSROOT.Length() > 0) {
+         jsroot_prefix = fJSROOT.Data();
+         if (jsroot_prefix.back() != '/')
+            jsroot_prefix.append("/");
+      } else {
+         jsroot_prefix = path_prefix + "jsrootsys/";
+      }
+
+      static std::map<std::string, std::string> modules = {
+         {"jsroot", "main.mjs"}, {"jsroot/core", "core.mjs"},
+         {"jsroot/io", "io.mjs"}, {"jsroot/tree", "tree.mjs"},
+         {"jsroot/draw", "draw.mjs"}, {"jsroot/gui", "gui.mjs"},
+         {"jsroot/d3", "d3.mjs"}, {"jsroot/three", "three.mjs"}, {"jsroot/three_addons", "three_addons.mjs"},
+         {"jsroot/geom", "geom/TGeoPainter.mjs"}, {"jsroot/hpainter", "gui/HierarchyPainter.mjs"},
+         {"jsroot/webwindow", "webwindow.mjs"}
+      };
+
+      TString space_prefix;
+      auto pspace = p;
+      while ((--pspace > 0) && (arg->fContent[pspace] == ' ') && (space_prefix.Length() < 20))
+         space_prefix.Append(" ");
+
+      bool first = true;
+      TString importmap = "<script type=\"importmap\">\n";
+      importmap += space_prefix + "{\n";
+      importmap += space_prefix + "  \"imports\": ";
+      for (auto &entry : modules) {
+         importmap.Append(TString::Format("%s\n%s    \"%s\": \"%smodules/%s\"", first ? "{" : ",", space_prefix.Data(), entry.first.c_str(), jsroot_prefix.c_str(), entry.second.c_str()));
+         first = false;
+      }
+      importmap.Append(TString::Format(",\n%s    \"jsrootsys/\": \"%s\"", space_prefix.Data(), jsroot_prefix.c_str()));
+
+      for (auto &entry : fLocations)
+         if (entry.first != "jsrootsys/")
+            importmap.Append(TString::Format(",\n%s    \"%s\": \"%s%s\"", space_prefix.Data(), entry.first.c_str(), path_prefix.c_str(), entry.first.c_str()));
+      importmap.Append("\n");
+      importmap.Append(space_prefix + "  }\n");
+      importmap.Append(space_prefix + "}\n");
+      importmap.Append(space_prefix + "</script>\n");
+
+      arg->fContent.erase(p, place_holder.length());
+
+      arg->fContent.insert(p, importmap.Data());
    }
 }
 
@@ -897,6 +991,8 @@ void THttpServer::ProcessRequest(std::shared_ptr<THttpCallArg> arg)
 
    if (arg->fFileName.IsNull() || (arg->fFileName == "index.htm") || (arg->fFileName == "default.htm")) {
 
+      std::string version;
+
       if (arg->fFileName == "default.htm") {
 
          if (!IsWSOnly())
@@ -921,12 +1017,18 @@ void THttpServer::ProcessRequest(std::shared_ptr<THttpCallArg> arg)
                arg->fContent = ReadFileContent(resolve.Data());
             }
 
+            version = handler->GetCodeVersion();
+
             handler->VerifyDefaultPageContent(arg);
          }
       }
 
       if (arg->fContent.empty() && arg->fFileName.IsNull() && arg->fPathName.IsNull() && IsWSOnly()) {
-         arg->SetContent("refused"); //  BuildWSEntryPage();
+         // Creating page with list of available widgets is disabled now for security reasons
+         // Later one can provide functionality back only if explicitly desired by the user
+         //  BuildWSEntryPage();
+
+         arg->SetContent("refused");
          arg->Set404();
       }
 
@@ -943,7 +1045,7 @@ void THttpServer::ProcessRequest(std::shared_ptr<THttpCallArg> arg)
          arg->Set404();
       } else if (!arg->Is404()) {
 
-         ReplaceJSROOTLinks(arg);
+         ReplaceJSROOTLinks(arg, version);
 
          const char *hjsontag = "\"$$$h.json$$$\"";
 
@@ -1122,7 +1224,7 @@ void THttpServer::ProcessRequest(std::shared_ptr<THttpCallArg> arg)
       // only for binary data master version is important
       // it allows to detect if streamer info was modified
       const char *parname = fSniffer->IsStreamerInfoItem(arg->fPathName.Data()) ? "BVersion" : "MVersion";
-      arg->AddHeader(parname, Form("%u", (unsigned)fSniffer->GetStreamerInfoHash()));
+      arg->AddHeader(parname, TString::Format("%u", (unsigned)fSniffer->GetStreamerInfoHash()).Data());
    }
 
    // try to avoid caching on the browser
