@@ -54,7 +54,6 @@
 #include <stdexcept>
 #include <iostream>
 
-ClassImp(ParamHistFunc);
 
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -318,10 +317,8 @@ RooArgList ParamHistFunc::createParamSet(RooWorkspace& w, const std::string& Pre
       gamma.setConstant( false );
 
       w.import( gamma, RooFit::RecycleConflictNodes() );
-      RooRealVar* gamma_wspace = (RooRealVar*) w.var( VarName );
-
-      paramSet.add( *gamma_wspace );
 
+      paramSet.add(*w.arg(VarName));
     }
   }
 
@@ -352,10 +349,8 @@ RooArgList ParamHistFunc::createParamSet(RooWorkspace& w, const std::string& Pre
         gamma.setConstant( false );
 
         w.import( gamma, RooFit::RecycleConflictNodes() );
-        RooRealVar* gamma_wspace = (RooRealVar*) w.var( VarName );
-
-        paramSet.add( *gamma_wspace );
 
+        paramSet.add(*w.arg(VarName));
       }
     }
   }
@@ -389,10 +384,8 @@ RooArgList ParamHistFunc::createParamSet(RooWorkspace& w, const std::string& Pre
           gamma.setConstant( false );
 
           w.import( gamma, RooFit::RecycleConflictNodes() );
-          RooRealVar* gamma_wspace = (RooRealVar*) w.var( VarName );
-
-          paramSet.add( *gamma_wspace );
 
+          paramSet.add(*w.arg(VarName));
         }
       }
     }
@@ -432,10 +425,12 @@ RooArgList ParamHistFunc::createParamSet(RooWorkspace& w, const std::string& Pre
   RooArgList params = ParamHistFunc::createParamSet( w, Prefix, vars );
 
   for (auto comp : params) {
-    auto var = static_cast<RooRealVar*>(comp);
-
-    var->setMin( gamma_min );
-    var->setMax( gamma_max );
+    // If the gamma is subject to a preprocess function, it is a RooAbsReal and
+    // we don't need to set the range.
+    if(auto var = dynamic_cast<RooRealVar*>(comp)) {
+      var->setMin( gamma_min );
+      var->setMax( gamma_max );
+    }
   }
 
   return params;
@@ -560,26 +555,10 @@ double ParamHistFunc::evaluate() const
   return getParameter().getVal();
 }
 
-void ParamHistFunc::translate(RooFit::Detail::CodeSquashContext &ctx) const
-{
-   auto const &n = _numBinsPerDim;
-
-   // check if _numBins needs to be filled
-   if (n.x == 0) {
-      _numBinsPerDim = getNumBinsPerDim(_dataVars);
-   }
-
-   std::string const &idx = _dataSet.calculateTreeIndexForCodeSquash(this, ctx, _dataVars, true);
-   std::string const &paramNames = ctx.buildArg(_paramSet);
-
-   ctx.addResult(this, paramNames + "[" + idx + "]");
-}
-
 ////////////////////////////////////////////////////////////////////////////////
-/// Find all bins corresponding to the values of the observables in `evalData`, and evaluate
-/// the associated parameters.
-/// \param[in,out] evalData Input/output data for evaluating the ParamHistFunc.
-/// \param[in] normSet Normalisation set passed on to objects that are serving values to us.
+/// Find all bins corresponding to the values of the observables in `ctx`,
+// and evaluate the associated parameters.
+/// \param[in,out] ctx Input/output data for evaluating the ParamHistFunc.
 void ParamHistFunc::doEval(RooFit::EvalContext & ctx) const
 {
   std::span<double> output = ctx.output();
