@@ -58,9 +58,6 @@
 #include <cmath>
 #include <algorithm>
 
-using std::endl, std::cout;
-
-ClassImp(PiecewiseInterpolation);
 
 ////////////////////////////////////////////////////////////////////////////////
 
@@ -94,14 +91,14 @@ PiecewiseInterpolation::PiecewiseInterpolation(const char *name, const char *tit
 {
   // KC: check both sizes
   if (lowSet.size() != highSet.size()) {
-    coutE(InputArguments) << "PiecewiseInterpolation::ctor(" << GetName() << ") ERROR: input lists should be of equal length" << endl ;
+    coutE(InputArguments) << "PiecewiseInterpolation::ctor(" << GetName() << ") ERROR: input lists should be of equal length" << std::endl ;
     RooErrorHandler::softAbort() ;
   }
 
   for (auto *comp : lowSet) {
     if (!dynamic_cast<RooAbsReal*>(comp)) {
       coutE(InputArguments) << "PiecewiseInterpolation::ctor(" << GetName() << ") ERROR: component " << comp->GetName()
-             << " in first list is not of type RooAbsReal" << endl ;
+             << " in first list is not of type RooAbsReal" << std::endl ;
       RooErrorHandler::softAbort() ;
     }
     _lowSet.add(*comp) ;
@@ -111,7 +108,7 @@ PiecewiseInterpolation::PiecewiseInterpolation(const char *name, const char *tit
   for (auto *comp : highSet) {
     if (!dynamic_cast<RooAbsReal*>(comp)) {
       coutE(InputArguments) << "PiecewiseInterpolation::ctor(" << GetName() << ") ERROR: component " << comp->GetName()
-             << " in first list is not of type RooAbsReal" << endl ;
+             << " in first list is not of type RooAbsReal" << std::endl ;
       RooErrorHandler::softAbort() ;
     }
     _highSet.add(*comp) ;
@@ -121,7 +118,7 @@ PiecewiseInterpolation::PiecewiseInterpolation(const char *name, const char *tit
   for (auto *comp : paramSet) {
     if (!dynamic_cast<RooAbsReal*>(comp)) {
       coutE(InputArguments) << "PiecewiseInterpolation::ctor(" << GetName() << ") ERROR: component " << comp->GetName()
-             << " in first list is not of type RooAbsReal" << endl ;
+             << " in first list is not of type RooAbsReal" << std::endl ;
       RooErrorHandler::softAbort() ;
     }
     _paramSet.add(*comp) ;
@@ -185,79 +182,17 @@ double PiecewiseInterpolation::evaluate() const
 
   if(_positiveDefinite && (sum<0)){
     sum = 0;
-    //     cout <<"sum < 0 forcing  positive definite"<<endl;
+    //     std::cout <<"sum < 0 forcing  positive definite"<< std::endl;
     //     int code = 1;
     //     RooArgSet* myset = new RooArgSet();
-    //     cout << "integral = " << analyticalIntegralWN(code, myset) << endl;
+    //     std::cout << "integral = " << analyticalIntegralWN(code, myset) << std::endl;
   } else if(sum<0){
-    cxcoutD(Tracing) <<"PiecewiseInterpolation::evaluate -  sum < 0, not forcing positive definite"<<endl;
+    cxcoutD(Tracing) <<"PiecewiseInterpolation::evaluate -  sum < 0, not forcing positive definite"<< std::endl;
   }
   return sum;
 
 }
 
-void PiecewiseInterpolation::translate(RooFit::Detail::CodeSquashContext &ctx) const
-{
-   std::size_t n = _interpCode.size();
-
-   std::string resName = "total_" + ctx.getTmpVarName();
-   for (std::size_t i = 0; i < n; ++i) {
-      if (_interpCode[i] != _interpCode[0]) {
-         coutE(InputArguments) << "FlexibleInterpVar::evaluate ERROR:  Code Squashing AD does not yet support having "
-                                  "different interpolation codes for the same class object "
-                               << endl;
-      }
-   }
-
-   // The PiecewiseInterpolation class is used in the context of HistFactory
-   // models, where is is always used the same way: all RooAbsReals in _lowSet,
-   // _histSet, and also nominal are 1D RooHistFuncs with with same structure.
-   //
-   // Therefore, we can make a big optimization: we get the bin index only once
-   // here in the generated code for PiecewiseInterpolation. Then, we also
-   // rearrange the histogram data in such a way that we can always pass the
-   // same arrays to the free function that implements the interpolation, just
-   // with a dynamic offset calculated from the bin index.
-   RooDataHist const &nomHist = dynamic_cast<RooHistFunc const &>(*_nominal).dataHist();
-   int nBins = nomHist.numEntries();
-   std::vector<double> valsNominal;
-   std::vector<double> valsLow;
-   std::vector<double> valsHigh;
-   for (int i = 0; i < nBins; ++i) {
-      valsNominal.push_back(nomHist.weight(i));
-   }
-   for (int i = 0; i < nBins; ++i) {
-      for (std::size_t iParam = 0; iParam < n; ++iParam) {
-         valsLow.push_back(dynamic_cast<RooHistFunc const &>(_lowSet[iParam]).dataHist().weight(i));
-         valsHigh.push_back(dynamic_cast<RooHistFunc const &>(_highSet[iParam]).dataHist().weight(i));
-      }
-   }
-   std::string idxName = ctx.getTmpVarName();
-   std::string valsNominalStr = ctx.buildArg(valsNominal);
-   std::string valsLowStr = ctx.buildArg(valsLow);
-   std::string valsHighStr = ctx.buildArg(valsHigh);
-   std::string nStr = std::to_string(n);
-   std::string code;
-
-   std::string lowName = ctx.getTmpVarName();
-   std::string highName = ctx.getTmpVarName();
-   std::string nominalName = ctx.getTmpVarName();
-   code += "unsigned int " + idxName + " = " + nomHist.calculateTreeIndexForCodeSquash(ctx, dynamic_cast<RooHistFunc const &>(*_nominal).variables()) + ";\n";
-   code += "double const* " + lowName + " = " + valsLowStr + " + " + nStr + " * " + idxName + ";\n";
-   code += "double const* " + highName + " = " + valsHighStr + " + " + nStr + " * " + idxName + ";\n";
-   code += "double " + nominalName + " = *(" + valsNominalStr + " + " + idxName + ");\n";
-
-   std::string funcCall = ctx.buildCall("RooFit::Detail::MathFuncs::flexibleInterp", _interpCode[0], _paramSet, n,
-                                        lowName, highName, 1.0, nominalName, 0.0);
-   code += "double " + resName + " = " + funcCall + ";\n";
-
-   if (_positiveDefinite)
-      code += resName + " = " + resName + " < 0 ? 0 : " + resName + ";\n";
-
-   ctx.addToCodeBody(this, code);
-   ctx.addResult(this, resName);
-}
-
 namespace {
 
 inline double broadcast(std::span<const double> const &s, std::size_t i)
@@ -269,8 +204,7 @@ inline double broadcast(std::span<const double> const &s, std::size_t i)
 
 ////////////////////////////////////////////////////////////////////////////////
 /// Interpolate between input distributions for all values of the observable in `evalData`.
-/// \param[in,out] evalData Struct holding spans pointing to input data. The results of this function will be stored here.
-/// \param[in] normSet Arguments to normalise over.
+/// \param[in,out] ctx Struct holding spans pointing to input data. The results of this function will be stored here.
 void PiecewiseInterpolation::doEval(RooFit::EvalContext &ctx) const
 {
    std::span<double> sum = ctx.output();
@@ -312,7 +246,7 @@ bool PiecewiseInterpolation::setBinIntegrator(RooArgSet& allVars)
     temp->specialIntegratorConfig(true)->getConfigSection("RooBinIntegrator").setRealValue("numBins",nbins);
     return true;
   }else{
-    cout << "Currently BinIntegrator only knows how to deal with 1-d "<<endl;
+    std::cout << "Currently BinIntegrator only knows how to deal with 1-d "<< std::endl;
     return false;
   }
   return false;
@@ -325,12 +259,12 @@ Int_t PiecewiseInterpolation::getAnalyticalIntegralWN(RooArgSet& allVars, RooArg
                         const RooArgSet* normSet, const char* /*rangeName*/) const
 {
   /*
-  cout << "---------------------------\nin PiecewiseInterpolation get analytic integral " <<endl;
-  cout << "all vars = "<<endl;
+  std::cout << "---------------------------\nin PiecewiseInterpolation get analytic integral " << std::endl;
+  std::cout << "all vars = "<< std::endl;
   allVars.Print("v");
-  cout << "anal vars = "<<endl;
+  std::cout << "anal vars = "<< std::endl;
   analVars.Print("v");
-  cout << "normset vars = "<<endl;
+  std::cout << "normset vars = "<< std::endl;
   if(normSet2)
     normSet2->Print("v");
   */
@@ -350,7 +284,7 @@ Int_t PiecewiseInterpolation::getAnalyticalIntegralWN(RooArgSet& allVars, RooArg
   for (auto it = _paramSet.begin(); it != _paramSet.end(); ++it) {
     if (!_interpCode.empty() && _interpCode[it - _paramSet.begin()] != 0) {
         // can't factorize integral
-        cout << "can't factorize integral" << endl;
+        std::cout << "can't factorize integral" << std::endl;
         return 0;
      }
   }
@@ -398,7 +332,7 @@ Int_t PiecewiseInterpolation::getAnalyticalIntegralWN(RooArgSet& allVars, RooArg
 double PiecewiseInterpolation::analyticalIntegralWN(Int_t code, const RooArgSet* /*normSet2*/,const char* /*rangeName*/) const
 {
   /*
-  cout <<"Enter analytic Integral"<<endl;
+  std::cout <<"Enter analytic Integral"<< std::endl;
   printDirty(true);
   //  _nominal.arg().setDirtyInhibit(true) ;
   _nominal.arg().setShapeDirty() ;
@@ -418,7 +352,7 @@ double PiecewiseInterpolation::analyticalIntegralWN(Int_t code, const RooArgSet*
   /*
   RooAbsArg::setDirtyInhibit(true);
   printDirty(true);
-  cout <<"done setting dirty inhibit = true"<<endl;
+  std::cout <<"done setting dirty inhibit = true"<< std::endl;
 
   // old integral, only works for linear and not positive definite
   CacheElem* cache = (CacheElem*) _normIntMgr.getObjByIndex(code-1) ;
@@ -426,7 +360,7 @@ double PiecewiseInterpolation::analyticalIntegralWN(Int_t code, const RooArgSet*
 
  std::unique_ptr<RooArgSet> vars2( getParameters(RooArgSet()) );
  std::unique_ptr<RooArgSet> iset(  _normIntMgr.nameSet2ByIndex(code-1)->select(*vars2) );
- cout <<"iset = "<<endl;
+ std::cout <<"iset = "<< std::endl;
  iset->Print("v");
 
   double sum = 0;
@@ -439,10 +373,10 @@ double PiecewiseInterpolation::analyticalIntegralWN(Int_t code, const RooArgSet*
     for(int i=0; i<obs->numBins(); ++i){
       obs->setVal( obs->getMin() + (.5+i)*(obs->getMax()-obs->getMin())/obs->numBins());
       sum+=evaluate()*(obs->getMax()-obs->getMin())/obs->numBins();
-      cout << "obs = " << obs->getVal() << " sum = " << sum << endl;
+      std::cout << "obs = " << obs->getVal() << " sum = " << sum << std::endl;
     }
   } else{
-    cout <<"only know how to deal with 1 observable right now"<<endl;
+    std::cout <<"only know how to deal with 1 observable right now"<< std::endl;
   }
   */
 
@@ -461,8 +395,8 @@ double PiecewiseInterpolation::analyticalIntegralWN(Int_t code, const RooArgSet*
   /*
   RooAbsArg::setDirtyInhibit(false);
   printDirty(true);
-  cout <<"done"<<endl;
-  cout << "sum = " <<sum<<endl;
+  std::cout <<"done"<< std::endl;
+  std::cout << "sum = " <<sum<< std::endl;
   //return sum;
   */
 
@@ -487,7 +421,7 @@ double PiecewiseInterpolation::analyticalIntegralWN(Int_t code, const RooArgSet*
     nominal = value;
     i++;
   }
-  if(i==0 || i>1) { cout << "problem, wrong number of nominal functions"<<endl; }
+  if(i==0 || i>1) { std::cout << "problem, wrong number of nominal functions"<< std::endl; }
 
   // now get low/high variations
   // KC: old interp code with new iterator
@@ -563,13 +497,13 @@ double PiecewiseInterpolation::analyticalIntegralWN(Int_t code, const RooArgSet*
 
     } else {
       coutE(InputArguments) << "PiecewiseInterpolation::analyticalIntegralWN ERROR:  " << param->GetName()
-             << " with unknown interpolation code" << endl ;
+             << " with unknown interpolation code" << std::endl ;
     }
     ++i;
   }
   */
 
-  //  cout << "value = " << value <<endl;
+  //  std::cout << "value = " << value << std::endl;
   return value;
 }
 
@@ -616,7 +550,7 @@ void PiecewiseInterpolation::setInterpCodeForParam(int iParam, int code)
 
 void PiecewiseInterpolation::printAllInterpCodes(){
   for(unsigned int i=0; i<_interpCode.size(); ++i){
-    coutI(InputArguments) <<"interp code for " << _paramSet.at(i)->GetName() << " = " << _interpCode.at(i) <<endl;
+    coutI(InputArguments) <<"interp code for " << _paramSet.at(i)->GetName() << " = " << _interpCode.at(i) << std::endl;
   }
 }
 
