@@ -35,7 +35,7 @@ TEST(RooParamHistFunc, Integration)
    }
 
    RooDataHist dh("dh", "dh", x, &h1);
-   RooParamHistFunc phf("phf", "", x, dh);
+   RooParamHistFunc phf("phf", "", dh, x);
    x.setRange("R1", 0, xMax * 0.5);
 
    std::unique_ptr<RooAbsReal> integral{phf.createIntegral(x, x)};
@@ -87,7 +87,7 @@ TEST(RooParamHistFunc, IntegrationAndCloning)
    h1.FillRandom("f1", 50);
    RooDataHist dh1("dh1", "dh1", x, &h1);
 
-   RooParamHistFunc ph("ph", "", x, dh1);
+   RooParamHistFunc ph("ph", "", dh1, x);
 
    // Combine the RooParamHistFunc with something else in a RooRealSumPdf.
    // This is do make the test more similar to the Barlow-Beeston test,
