@@ -51,7 +51,6 @@ likelihood.
 
 #include <sstream>
 
-ClassImp(RooStats::ModelConfig);
 
 namespace {
 
@@ -67,7 +66,7 @@ void removeConstantParameters(RooAbsCollection &coll)
 
 } // namespace
 
-using std::cout, std::endl, std::ostream;
+using std::ostream;
 
 namespace RooStats {
 
@@ -84,17 +83,17 @@ namespace RooStats {
 /// We use nullptr to mean not set, so we don't want to fill
 /// with empty RooArgSets.
 
-void ModelConfig::GuessObsAndNuisance(const RooAbsData &data, bool printModelConfig)
+void ModelConfig::GuessObsAndNuisance(const RooArgSet &obsSet, bool printModelConfig)
 {
 
    // observables
    if (!GetObservables()) {
-      SetObservables(*std::unique_ptr<RooArgSet>{GetPdf()->getObservables(data)});
+      SetObservables(*std::unique_ptr<RooArgSet>{GetPdf()->getObservables(obsSet)});
    }
    // global observables
    if (!GetGlobalObservables()) {
       RooArgSet co(*GetObservables());
-      co.remove(*std::unique_ptr<RooArgSet>{GetPdf()->getObservables(data)});
+      co.remove(*std::unique_ptr<RooArgSet>{GetPdf()->getObservables(obsSet)});
       removeConstantParameters(co);
       if (!co.empty())
          SetGlobalObservables(co);
@@ -113,7 +112,7 @@ void ModelConfig::GuessObsAndNuisance(const RooAbsData &data, bool printModelCon
    //   }
    if (!GetNuisanceParameters()) {
       RooArgSet params;
-      GetPdf()->getParameters(data.get(), params);
+      GetPdf()->getParameters(&obsSet, params);
       RooArgSet p(params);
       p.remove(*GetParametersOfInterest());
       removeConstantParameters(p);
@@ -138,7 +137,7 @@ void ModelConfig::Print(Option_t *) const
 {
    ostream &os = RooPrintable::defaultPrintStream();
 
-   os << endl << "=== Using the following for " << GetName() << " ===" << endl;
+   os << std::endl << "=== Using the following for " << GetName() << " ===" << std::endl;
 
    // args
    if (GetObservables()) {
@@ -183,12 +182,12 @@ void ModelConfig::Print(Option_t *) const
    // snapshot
    const RooArgSet *snapshot = GetSnapshot();
    if (snapshot) {
-      os << "Snapshot:                " << endl;
+      os << "Snapshot:                " << std::endl;
       snapshot->Print("v");
       delete snapshot;
    }
 
-   os << endl;
+   os << std::endl;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -215,7 +214,7 @@ RooWorkspace *ModelConfig::GetWS() const
 {
    RooWorkspace *ws = dynamic_cast<RooWorkspace *>(fRefWS.GetObject());
    if (!ws) {
-      coutE(ObjectHandling) << "workspace not set" << endl;
+      coutE(ObjectHandling) << "workspace not set" << std::endl;
       return nullptr;
    }
    return ws;
@@ -353,7 +352,7 @@ bool ModelConfig::SetHasOnlyParameters(const RooArgSet &set, const char *errorMs
    }
 
    if (errorMsgPrefix && !nonparams.empty()) {
-      cout << errorMsgPrefix << " ERROR: specified set contains non-parameters: " << nonparams << endl;
+      std::cout << errorMsgPrefix << " ERROR: specified set contains non-parameters: " << nonparams << std::endl;
    }
    return (nonparams.empty());
 }
@@ -458,7 +457,7 @@ std::unique_ptr<RooAbsReal> ModelConfig::createNLLImpl(RooAbsData &data, const R
  *
  * See ModelConfig::createNLL() for more information.
  */
-std::unique_ptr<RooFitResult> ModelConfig::fitToImpl(RooAbsData &data, const RooLinkedList &cmdList)
+std::unique_ptr<RooFitResult> ModelConfig::fitToImpl(RooAbsData &data, const RooLinkedList &cmdList) const
 {
    std::vector<RooCmdArg> cmdArgs;
    auto finalCmdList = finalizeCmdList(*this, cmdList, cmdArgs);
