@@ -19,7 +19,7 @@
 \class RooAICRegistry
 \ingroup Roofitcore
 
-RooAICRegistry is a utility class for operator p.d.f
+Utility class for operator p.d.f
 classes that keeps track of analytical integration codes and
 associated normalization and integration sets.
 **/
@@ -31,10 +31,6 @@ associated normalization and integration sets.
 #include "Riostream.h"
 
 
-using namespace std;
-
-ClassImp(RooAICRegistry);
-
 namespace {
 
 RooArgSet * makeSnapshot(RooArgSet const* set) {
@@ -97,6 +93,14 @@ RooAICRegistry::~RooAICRegistry()
   }
 }
 
+////////////////////////////////////////////////////////////////////////////////
+/// Get size of _clArr vector
+
+size_t RooAICRegistry::size() const
+{
+  return _clArr.size();
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 /// Store given arrays of integer codes, and up to four RooArgSets in
 /// the registry (each setX pointer may be null). The registry
