@@ -50,7 +50,6 @@ implemented using the container denoted by RooAbsCollection::Storage_t.
 #include <fstream>
 #include <memory>
 
-ClassImp(RooAbsCollection);
 
 namespace RooFit {
 namespace Detail {
@@ -930,6 +929,7 @@ RooAbsArg * RooAbsCollection::find(const char *name) const
 
   if (_hashAssistedFind || _list.size() >= _sizeThresholdForMapSearch) {
     if (!_hashAssistedFind || !_hashAssistedFind->isValid()) {
+       delete _hashAssistedFind;
       _hashAssistedFind = new HashAssistedFind{_list.begin(), _list.end()};
     }
 
@@ -950,6 +950,7 @@ RooAbsArg * RooAbsCollection::find(const RooAbsArg& arg) const
 
   if (_hashAssistedFind || _list.size() >= _sizeThresholdForMapSearch) {
     if (!_hashAssistedFind || !_hashAssistedFind->isValid()) {
+       delete _hashAssistedFind;
       _hashAssistedFind = new HashAssistedFind{_list.begin(), _list.end()};
     }
 
@@ -1153,7 +1154,9 @@ std::string RooAbsCollection::contentsString() const
     retVal += ",";
   }
 
-  retVal.erase(retVal.end()-1);
+  if (!retVal.empty()) {
+    retVal.erase(retVal.end()-1);
+  }
 
   return retVal;
 }
@@ -1456,9 +1459,9 @@ void RooAbsCollection::printLatex(std::ostream& ofs, Int_t ncol, const char* opt
    RooRealVar* par = static_cast<RooRealVar*>((static_cast<RooArgList*>(listListRRV.At(k)))->at(i+j*nrow)) ;
    if (par) {
      if (option) {
-       ofs << *std::unique_ptr<TString>{par->format(sigDigit,(k==0)?option:sibOption.Data())};
+       ofs << par->format(sigDigit,(k==0)?option:sibOption.Data());
      } else {
-       ofs << *std::unique_ptr<TString>{par->format((k==0)?*formatCmd:sibFormatCmd)};
+       ofs << par->format((k==0)?*formatCmd:sibFormatCmd);
      }
    }
    if (!(j==ncol-1 && k==nlist-1)) {
