@@ -19,30 +19,31 @@
 \class RooBinning
 \ingroup Roofitcore
 
-Class RooBinning is an implements RooAbsBinning in terms
+Implements a RooAbsBinning in terms
 of an array of boundary values, posing no constraints on the choice
 of binning, thus allowing variable bin sizes. Various methods allow
 the user to add single bin boundaries, mirrored pairs, or sets of
 uniformly spaced boundaries.
 **/
 
-#include "Riostream.h"
-#include "RooBinning.h"
-#include "RooDouble.h"
-#include "RooAbsPdf.h"
-#include "RooRealVar.h"
-#include "RooNumber.h"
-#include "RooMsgService.h"
-#include "TBuffer.h"
-#include "TList.h"
+#include <Riostream.h>
+#include <RooAbsPdf.h>
+#include <RooBinning.h>
+#include <RooDouble.h>
+#include <RooFit/CodegenContext.h>
+#include <RooFit/Detail/MathFuncs.h>
+#include <RooMsgService.h>
+#include <RooNumber.h>
+#include <RooRealVar.h>
+
+#include <TBuffer.h>
+#include <TList.h>
 
 #include <algorithm>
 #include <cmath>
 
-using namespace std;
+using std::endl;
 
-ClassImp(RooBinning);
-;
 
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -102,8 +103,7 @@ RooBinning::~RooBinning()
 
 bool RooBinning::addBoundary(double boundary)
 {
-  std::vector<double>::iterator it =
-      std::lower_bound(_boundaries.begin(), _boundaries.end(), boundary);
+  auto it = std::lower_bound(_boundaries.begin(), _boundaries.end(), boundary);
   if (_boundaries.end() != it && *it == boundary) {
     // If boundary previously existed as range delimiter,
     //                    convert to regular boundary now
@@ -131,8 +131,7 @@ void RooBinning::addBoundaryPair(double boundary, double mirrorPoint)
 
 bool RooBinning::removeBoundary(double boundary)
 {
-  std::vector<double>::iterator it = std::lower_bound(_boundaries.begin(),
-      _boundaries.end(), boundary);
+  auto it = std::lower_bound(_boundaries.begin(), _boundaries.end(), boundary);
   if  (_boundaries.end() != it && *it == boundary) {
     _boundaries.erase(it);
     // if some moron deletes the boundaries corresponding to the current
@@ -157,21 +156,9 @@ bool RooBinning::removeBoundary(double boundary)
 void RooBinning::addUniform(Int_t nbins, double xlo, double xhi)
 {
   _boundaries.reserve(_boundaries.size() + nbins + 1);
-  for (Int_t i = 0; i <= nbins; ++i)
-    addBoundary((double(nbins - i) / double(nbins)) * xlo +
-   (double(i) / double(nbins)) * xhi);
-}
-
-namespace {
-
-inline int rawBinNumberImpl(double x, std::vector<double> const& boundaries) {
-  auto it = std::lower_bound(boundaries.begin(), boundaries.end(), x);
-  // always return valid bin number
-  while (boundaries.begin() != it &&
-     (boundaries.end() == it || boundaries.end() == it + 1 || x < *it)) --it;
-  return it - boundaries.begin();
-}
-
+  for (Int_t i = 0; i <= nbins; ++i) {
+    addBoundary((double(nbins - i) / double(nbins)) * xlo + (double(i) / double(nbins)) * xhi);
+  }
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -179,11 +166,11 @@ inline int rawBinNumberImpl(double x, std::vector<double> const& boundaries) {
 /// zero is the first bin with an upper boundary above the lower bound
 /// of the range
 
-void RooBinning::binNumbers(double const * x, int * bins, std::size_t n, int coef) const
+void RooBinning::binNumbers(double const *x, int *bins, std::size_t n, int coef) const
 {
-  for(std::size_t i = 0; i < n; ++i) {
-    bins[i] += coef * (std::max(0, std::min(_nbins, rawBinNumberImpl(x[i], _boundaries) - _blo)));
-  }
+   for (std::size_t i = 0; i < n; ++i) {
+      bins[i] += RooFit::Detail::MathFuncs::binNumber(x[i], coef, _boundaries.data(), _boundaries.size(), _nbins, _blo);
+   }
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -191,7 +178,8 @@ void RooBinning::binNumbers(double const * x, int * bins, std::size_t n, int coe
 
 double RooBinning::nearestBoundary(double x) const
 {
-  double xl, xh;
+  double xl;
+  double xh;
   if (binEdges(binNumber(x), xl, xh)) return 0;
   return (std::abs(xl - x) < std::abs(xh - x)) ? xl : xh;
 }
@@ -216,7 +204,7 @@ double* RooBinning::array() const
 void RooBinning::setRange(double xlo, double xhi)
 {
   if (xlo > xhi) {
-    coutE(InputArguments) << "RooBinning::setRange: ERROR low bound > high bound" << endl;
+    coutE(InputArguments) << "RooBinning::setRange: ERROR low bound > high bound" << std::endl;
     return;
   }
   // Remove previous boundaries
@@ -239,9 +227,8 @@ void RooBinning::updateBinCount()
       _nbins = -1;
       return;
   }
-  _blo = rawBinNumberImpl(_xlo, _boundaries);
-  std::vector<double>::const_iterator it = std::lower_bound(
-      _boundaries.begin(), _boundaries.end(), _xhi);
+  _blo = RooFit::Detail::MathFuncs::rawBinNumber(_xlo, _boundaries.data(), _boundaries.size());
+  auto it = std::lower_bound(_boundaries.begin(), _boundaries.end(), _xhi);
   if (_boundaries.begin() != it && (_boundaries.end() == it || _xhi < *it)) --it;
   const Int_t bhi = it - _boundaries.begin();
   _nbins = bhi - _blo;
@@ -254,7 +241,7 @@ void RooBinning::updateBinCount()
 bool RooBinning::binEdges(Int_t bin, double& xlo, double& xhi) const
 {
   if (0 > bin || bin >= _nbins) {
-    coutE(InputArguments) << "RooBinning::binEdges ERROR: bin number must be in range (0," << _nbins << ")" << endl;
+    coutE(InputArguments) << "RooBinning::binEdges ERROR: bin number must be in range (0," << _nbins << ")" << std::endl;
     return true;
   }
   xlo = _boundaries[bin + _blo], xhi = _boundaries[bin + _blo + 1];
@@ -266,7 +253,8 @@ bool RooBinning::binEdges(Int_t bin, double& xlo, double& xhi) const
 
 double RooBinning::binCenter(Int_t bin) const
 {
-  double xlo, xhi;
+  double xlo;
+  double xhi;
   if (binEdges(bin, xlo, xhi)) return 0;
   return 0.5 * (xlo + xhi);
 }
@@ -276,7 +264,8 @@ double RooBinning::binCenter(Int_t bin) const
 
 double RooBinning::binWidth(Int_t bin) const
 {
-  double xlo, xhi;
+  double xlo;
+  double xhi;
   if (binEdges(bin, xlo, xhi)) return 0;
   return (xhi - xlo);
 }
@@ -286,7 +275,8 @@ double RooBinning::binWidth(Int_t bin) const
 
 double RooBinning::binLow(Int_t bin) const
 {
-  double xlo, xhi;
+  double xlo;
+  double xhi;
   if (binEdges(bin, xlo, xhi)) return 0;
   return xlo;
 }
@@ -296,7 +286,8 @@ double RooBinning::binLow(Int_t bin) const
 
 double RooBinning::binHigh(Int_t bin) const
 {
-  double xlo, xhi;
+  double xlo;
+  double xhi;
   if (binEdges(bin, xlo, xhi)) return  0;
   return xhi;
 }
@@ -308,8 +299,10 @@ void RooBinning::Streamer(TBuffer &R__b)
 {
    if (R__b.IsReading()) {
 
-     UInt_t R__s, R__c;
-     Version_t R__v = R__b.ReadVersion(&R__s, &R__c); if (R__v) { }
+    UInt_t R__s;
+    UInt_t R__c;
+    Version_t R__v = R__b.ReadVersion(&R__s, &R__c);
+    if (R__v) { }
      switch (R__v) {
        case 3:
     // current version - fallthrough intended
@@ -351,3 +344,8 @@ void RooBinning::Streamer(TBuffer &R__b)
      R__b.WriteClassBuffer(RooBinning::Class(),this);
    }
 }
+
+std::string RooBinning::translateBinNumber(RooFit::Experimental::CodegenContext &ctx, RooAbsArg const &var, int coef) const
+{
+   return ctx.buildCall("RooFit::Detail::MathFuncs::binNumber", var, coef, _boundaries, _boundaries.size(), _nbins, _blo);
+}
