@@ -15,10 +15,10 @@
 #ifndef RooFit_BatchModeDataHelpers_h
 #define RooFit_BatchModeDataHelpers_h
 
-#include <RooFit/Detail/DataMap.h>
+#include <RooFit/EvalContext.h>
 
 #include <ROOT/RSpan.hxx>
-#include <ROOT/RStringView.hxx>
+#include <string_view>
 
 #include <functional>
 #include <map>
@@ -40,8 +40,7 @@ getDataSpans(RooAbsData const &data, std::string const &rangeName, RooSimultaneo
              bool takeGlobalObservablesFromData, std::stack<std::vector<double>> &buffers);
 
 std::map<RooFit::Detail::DataKey, std::size_t>
-determineOutputSizes(RooAbsArg const &topNode,
-                     std::function<std::size_t(RooFit::Detail::DataKey)> const &inputSizeFunc);
+determineOutputSizes(RooAbsArg const &topNode, std::function<int(RooFit::Detail::DataKey)> const &inputSizeFunc);
 
 } // namespace BatchModeDataHelpers
 } // namespace RooFit
