@@ -39,7 +39,6 @@ discrete dimensions and may have negative values.
 #include <stdexcept>
 
 
-ClassImp(RooHistFunc);
 
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -190,11 +189,6 @@ double RooHistFunc::evaluate() const
   return ret ;
 }
 
-void RooHistFunc::translate(RooFit::Detail::CodeSquashContext &ctx) const
-{
-   RooHistPdf::rooHistTranslateImpl(this, ctx, _intOrder, _dataHist, _depList, false, _cdfBoundaries);
-}
-
 void RooHistFunc::doEval(RooFit::EvalContext & ctx) const
 {
   std::span<double> output = ctx.output();
@@ -322,12 +316,6 @@ bool RooHistFunc::forceAnalyticalInt(const RooAbsArg& dep) const
    return RooHistPdf::forceAnalyticalInt(_depList, dep);
 }
 
-std::string RooHistFunc::buildCallToAnalyticIntegral(int code, const char * /* rangeName */,
-                                                     RooFit::Detail::CodeSquashContext & /* ctx */) const
-{
-   return RooHistPdf::rooHistIntegralTranslateImpl(code, this, _dataHist, _depList, true);
-}
-
 ////////////////////////////////////////////////////////////////////////////////
 /// Return sampling hint for making curves of (projections) of this function
 /// as the recursive division strategy of RooCurve cannot deal efficiently
@@ -361,8 +349,8 @@ std::list<double>* RooHistFunc::binBoundaries(RooAbsRealLValue& obs, double xlo,
     }
   }
 
-  // cout << "RooHistFunc::bb(" << GetName() << ") histObs = " << _histObsList << std::endl ;
-  // cout << "RooHistFunc::bb(" << GetName() << ") pdfObs = " << _depList << std::endl ;
+  // std::cout << "RooHistFunc::bb(" << GetName() << ") histObs = " << _histObsList << std::endl ;
+  // std::cout << "RooHistFunc::bb(" << GetName() << ") pdfObs = " << _depList << std::endl ;
 
   RooAbsRealLValue* transform = nullptr;
   if (!hobs) {
@@ -390,8 +378,8 @@ std::list<double>* RooHistFunc::binBoundaries(RooAbsRealLValue& obs, double xlo,
   }
 
 
-  // cout << "hobs = " << hobs->GetName() << std::endl ;
-  // cout << "transform = " << (transform?transform->GetName():"<none>") << std::endl ;
+  // std::cout << "hobs = " << hobs->GetName() << std::endl ;
+  // std::cout << "transform = " << (transform?transform->GetName():"<none>") << std::endl ;
 
   // Check that observable is in dataset, if not no hint is generated
   RooAbsArg* xtmp = _dataHist->get()->find(hobs->GetName()) ;
