@@ -87,9 +87,6 @@ credible interval from the given function.
 
 #include "RConfigure.h"
 
-ClassImp(RooStats::BayesianCalculator);
-
-using namespace std;
 
 namespace RooStats {
 
@@ -108,7 +105,8 @@ namespace RooStats {
 struct  LikelihoodFunction {
    LikelihoodFunction(RooFunctor & f, RooFunctor * prior = nullptr, double offset = 0) :
       fFunc(f), fPrior(prior),
-      fOffset(offset), fMaxL(0) {
+      fOffset(offset)
+   {
       fFunc.binding().resetNumCall();
    }
 
@@ -153,7 +151,7 @@ struct  LikelihoodFunction {
    RooFunctor & fFunc;     // functor representing the nll function
    RooFunctor * fPrior;     // functor representing the prior function
    double fOffset;         //  offset used to bring the nll in a reasonable range for computing the exponent
-   mutable double fMaxL;
+   mutable double fMaxL = 0;
 };
 
 
@@ -170,25 +168,22 @@ public:
       fPriorFunc(nullptr),
       fLikelihood(fFunctor, nullptr, nllMinimum),         // integral of exp(-nll) function
       fIntegrator(ROOT::Math::IntegratorMultiDim::GetType(integType) ),  // integrator
-      fXmin(bindParams.getSize() ),               // vector of parameters (min values)
-      fXmax(bindParams.getSize() ),               // vector of parameter (max values)
-      fNorm(1.0), fNormErr(0.0), fOffset(0), fMaxPOI(0),
-      fHasNorm(false),  fUseOldValues(true), fError(false)
+      fXmin(bindParams.size()),               // vector of parameters (min values)
+      fXmax(bindParams.size())
    {
-
       if (prior) {
          fPriorFunc = std::make_shared<RooFunctor>(*prior, bindParams, RooArgList());
          fLikelihood.SetPrior(fPriorFunc.get() );
       }
 
-      fIntegrator.SetFunction(fLikelihood, bindParams.getSize() );
+      fIntegrator.SetFunction(fLikelihood, bindParams.size() );
 
       ooccoutD(nullptr,NumIntegration) << "PosteriorCdfFunction::Compute integral of posterior in nuisance and poi. "
                                            << " nllMinimum is " << nllMinimum << std::endl;
 
-      std::vector<double> par(bindParams.getSize());
+      std::vector<double> par(bindParams.size());
       for (unsigned int i = 0; i < fXmin.size(); ++i) {
-         RooRealVar & var = (RooRealVar &) bindParams[i];
+         RooRealVar & var = static_cast<RooRealVar &>( bindParams[i]);
          fXmin[i] = var.getMin();
          fXmax[i] = var.getMax();
          par[i] = var.getVal();
@@ -297,9 +292,11 @@ private:
          fError = true;
       }
 
-      if (cdf != 0 && error/cdf > 0.2 )
-         oocoutW(nullptr,NumIntegration) << "PosteriorCdfFunction: integration error  is larger than 20 %   x0 = " << fXmin[0]
-                                              << " x = " << x << " cdf(x) = " << cdf << " +/- " << error << std::endl;
+      if (cdf != 0 && error / cdf > 0.2) {
+         oocoutW(nullptr, NumIntegration)
+            << "PosteriorCdfFunction: integration error  is larger than 20 %   x0 = " << fXmin[0] << " x = " << x
+            << " cdf(x) = " << cdf << " +/- " << error << std::endl;
+      }
 
       if (!fHasNorm) {
          oocoutI(nullptr,NumIntegration) << "PosteriorCdfFunction - integral of posterior = "
@@ -330,13 +327,13 @@ private:
    mutable ROOT::Math::IntegratorMultiDim  fIntegrator; // integrator  (mutable because Integral() is not const
    mutable std::vector<double> fXmin;    // min value of parameters (poi+nuis) -
    mutable std::vector<double> fXmax;   // max value of parameters (poi+nuis) - max poi changes so it is mutable
-   double fNorm;      // normalization value (computed in ctor)
-   mutable double fNormErr;    // normalization error value (computed in ctor)
-   double fOffset;   // offset for computing the root
-   double fMaxPOI;  // maximum value of POI
-   bool fHasNorm; // flag to control first call to the function
-   bool fUseOldValues;  // use old cdf values
-   mutable bool fError;     // flag to indicate if a numerical evaluation error occurred
+   double fNorm = 1.0;                  // normalization value (computed in constructor)
+   mutable double fNormErr = 0.0;       // normalization error value (computed in constructor)
+   double fOffset = 0;                  // offset for computing the root
+   double fMaxPOI = 0;                  // maximum value of POI
+   bool fHasNorm = false;               // flag to control first call to the function
+   bool fUseOldValues = true;           // use old cdf values
+   mutable bool fError = false;         // flag to indicate if a numerical evaluation error occurred
    mutable std::map<double,double> fNormCdfValues;
 };
 
@@ -356,10 +353,9 @@ public:
       fPriorFunc(nullptr),
       fLikelihood(fFunctor, nullptr, nllOffset),
       fPoi(&poi),
-      fXmin(nuisParams.getSize() ),
-      fXmax(nuisParams.getSize() ),
-      fNorm(norm),
-      fError(0)
+      fXmin(nuisParams.size()),
+      fXmax(nuisParams.size()),
+      fNorm(norm)
    {
 
       if (prior) {
@@ -369,7 +365,7 @@ public:
 
       ooccoutD(nullptr,NumIntegration) << "PosteriorFunction::Evaluate the posterior function by integrating the nuisances: " << std::endl;
       for (unsigned int i = 0; i < fXmin.size(); ++i) {
-         RooRealVar & var = (RooRealVar &) nuisParams[i];
+         RooRealVar & var = static_cast<RooRealVar &>( nuisParams[i]);
          fXmin[i] = var.getMin();
          fXmax[i] = var.getMax();
          ooccoutD(nullptr,NumIntegration) << "PosteriorFunction::Integrate " << var.GetName()
@@ -434,13 +430,11 @@ private:
                                            << "  norm-f(x) = " << f/fNorm
                                            << " ncalls = " << fFunctor.binding().numCall() << std::endl;
 
-
-
-
-      if (f != 0 && error/f > 0.2 )
-         ooccoutW(nullptr,NumIntegration) << "PosteriorFunction::DoEval - Error from integration in "
-                                              << fXmin.size() <<  " Dim is larger than 20 % "
-                                              << "x = " << x << " p(x) = " << f << " +/- " << error << std::endl;
+      if (f != 0 && error / f > 0.2) {
+         ooccoutW(nullptr, NumIntegration)
+            << "PosteriorFunction::DoEval - Error from integration in " << fXmin.size() << " Dim is larger than 20 % "
+            << "x = " << x << " p(x) = " << f << " +/- " << error << std::endl;
+      }
 
       fError = error / fNorm;
       return f / fNorm;
@@ -455,7 +449,7 @@ private:
    std::vector<double> fXmin;
    std::vector<double> fXmax;
    double fNorm;
-   mutable double fError;
+   mutable double fError = 0;
 };
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -464,19 +458,17 @@ private:
 class PosteriorFunctionFromToyMC : public ROOT::Math::IGenFunction {
 
 public:
+   PosteriorFunctionFromToyMC(RooAbsReal &nll, RooAbsPdf &pdf, RooRealVar &poi, RooArgList &nuisParams,
+                              RooAbsReal *prior = nullptr, double nllOffset = 0, int niter = 0, bool redoToys = true)
+      : fFunctor(nll, nuisParams, RooArgList()),
+        fPriorFunc(nullptr),
+        fLikelihood(fFunctor, nullptr, nllOffset),
+        fPdf(&pdf),
+        fPoi(&poi),
+        fNuisParams(nuisParams),
+        fNumIterations(niter),
 
-
-   PosteriorFunctionFromToyMC(RooAbsReal & nll, RooAbsPdf & pdf, RooRealVar & poi, RooArgList & nuisParams, RooAbsReal * prior = nullptr, double
-                              nllOffset = 0, int niter = 0, bool redoToys = true ) :
-      fFunctor(nll, nuisParams, RooArgList() ),
-      fPriorFunc(nullptr),
-      fLikelihood(fFunctor, nullptr, nllOffset),
-      fPdf(&pdf),
-      fPoi(&poi),
-      fNuisParams(nuisParams),
-      fNumIterations(niter),
-      fError(-1),
-      fRedoToys(redoToys)
+        fRedoToys(redoToys)
    {
       if (niter == 0) fNumIterations = 100; // default value
 
@@ -490,7 +482,7 @@ public:
       ooccoutI(nullptr,InputArguments) << "PosteriorFunctionFromToyMC::Pdf used for randomizing the nuisance is " << fPdf->GetName() << std::endl;
       // check that pdf contains  the nuisance
       std::unique_ptr<RooArgSet> vars{fPdf->getVariables()};
-      for (int i = 0; i < fNuisParams.getSize(); ++i) {
+      for (std::size_t i = 0; i < fNuisParams.size(); ++i) {
          if (!vars->find( fNuisParams[i].GetName() ) ) {
             ooccoutW(nullptr,InputArguments) << "Nuisance parameter " << fNuisParams[i].GetName()
                                                  << " is not part of sampling pdf. "
@@ -526,7 +518,7 @@ private:
    // evaluate the posterior at the poi value x
    double DoEval( double x) const override {
 
-      int npar = fNuisParams.getSize();
+      int npar = fNuisParams.size();
       assert (npar > 0);
 
 
@@ -552,7 +544,7 @@ private:
             RooRealVar * var = dynamic_cast<RooRealVar*>(arg);
             assert(var != nullptr);
             p[i] = var->getVal();
-            ((RooRealVar &) fNuisParams[i]).setVal(p[i]);
+            (static_cast<RooRealVar &>( fNuisParams[i])).setVal(p[i]);
          }
 
          // evaluate now the likelihood function
@@ -624,7 +616,7 @@ private:
    RooArgList fNuisParams;
    mutable std::unique_ptr<RooDataSet> fGenParams;
    int fNumIterations;
-   mutable double fError;
+   mutable double fError = -1;
    bool fRedoToys;                    // do toys every iteration
 
 };
@@ -788,7 +780,7 @@ RooAbsReal* BayesianCalculator::GetPosteriorFunction() const
       coutE(InputArguments) << "BayesianCalculator::GetPosteriorPdf - missing parameter of interest" << std::endl;
       return nullptr;
    }
-   if (fPOI.getSize() > 1) {
+   if (fPOI.size() > 1) {
       coutE(InputArguments) << "BayesianCalculator::GetPosteriorPdf - current implementation works only on 1D intervals" << std::endl;
       return nullptr;
    }
@@ -819,7 +811,7 @@ RooAbsReal* BayesianCalculator::GetPosteriorFunction() const
                   << " Negative log likelihood evaluates to infinity " << std::endl
                   << " Non-const Parameter values : ";
       RooArgList p(*constrainedParams);
-      for (int i = 0; i < p.getSize(); ++i) {
+      for (std::size_t i = 0; i < p.size(); ++i) {
          RooRealVar * v = dynamic_cast<RooRealVar *>(&p[i] );
          if (v!=nullptr) ccoutE(Eval) << v->GetName() << " = " << v->getVal() << "   ";
       }
@@ -838,7 +830,7 @@ RooAbsReal* BayesianCalculator::GetPosteriorFunction() const
    RooFunctor * nllFunc = fLogLike->functor(fPOI);
    assert(nllFunc);
    ROOT::Math::Functor1D wnllFunc(*nllFunc);
-   RooRealVar* poi = dynamic_cast<RooRealVar*>( fPOI.first() );
+   RooRealVar* poi = dynamic_cast<RooRealVar*>(fPOI.first() );
    assert(poi);
 
    // try to reduce some error messages
@@ -907,11 +899,11 @@ RooAbsReal* BayesianCalculator::GetPosteriorFunction() const
       if (fNuisanceParameters.empty()) {
          fIntegratedLikelihood = fLikelihood;
          fLikelihood = nullptr;
-      }
-      else
+      } else {
          // case of using RooFit for the integration
-         fIntegratedLikelihood = std::unique_ptr<RooAbsReal>{fLikelihood->createIntegral(fNuisanceParameters)}.release();
-
+         fIntegratedLikelihood =
+            std::unique_ptr<RooAbsReal>{fLikelihood->createIntegral(fNuisanceParameters)}.release();
+      }
 
    }
 
@@ -955,10 +947,10 @@ RooAbsReal* BayesianCalculator::GetPosteriorFunction() const
 
    }
 
-
-   if (RooAbsReal::numEvalErrors() > 0)
-      coutW(Eval) << "BayesianCalculator::GetPosteriorFunction : " << RooAbsReal::numEvalErrors() << " errors reported in evaluating log-likelihood function "
-                   << std::endl;
+   if (RooAbsReal::numEvalErrors() > 0) {
+      coutW(Eval) << "BayesianCalculator::GetPosteriorFunction : " << RooAbsReal::numEvalErrors()
+                  << " errors reported in evaluating log-likelihood function " << std::endl;
+   }
    RooAbsReal::clearEvalErrorLog();
    RooAbsReal::setEvalErrorLoggingMode(RooAbsReal::PrintErrors);
 
@@ -1025,7 +1017,7 @@ RooPlot* BayesianCalculator::GetPosteriorPlot(bool norm, double precision ) cons
 
    if (!fValidInterval) GetInterval();
 
-   RooAbsRealLValue* poi = dynamic_cast<RooAbsRealLValue*>( fPOI.first() );
+   RooAbsRealLValue* poi = dynamic_cast<RooAbsRealLValue*>(fPOI.first() );
    assert(poi);
 
 
@@ -1105,7 +1097,7 @@ SimpleInterval* BayesianCalculator::GetInterval() const
    if (fValidInterval)
       coutW(Eval) << "BayesianCalculator::GetInterval - recomputing interval for the same CL and same model" << std::endl;
 
-   RooRealVar* poi = dynamic_cast<RooRealVar*>( fPOI.first() );
+   RooRealVar* poi = dynamic_cast<RooRealVar*>(fPOI.first() );
    if (!poi) {
       coutE(Eval) << "BayesianCalculator::GetInterval - no parameter of interest is set " << std::endl;
       return nullptr;
@@ -1136,7 +1128,7 @@ SimpleInterval* BayesianCalculator::GetInterval() const
 
       else {
          // use integration method if there are nuisance parameters
-         if (fNuisanceParameters.getSize() > 0) {
+         if (!fNuisanceParameters.empty()) {
             ComputeIntervalFromCdf(lowerCutOff, upperCutOff);
          }
          else {
@@ -1155,9 +1147,10 @@ SimpleInterval* BayesianCalculator::GetInterval() const
 
 
    // reset the counts and default mode
-   if (RooAbsReal::numEvalErrors() > 0)
-      coutW(Eval) << "BayesianCalculator::GetInterval : " << RooAbsReal::numEvalErrors() << " errors reported in evaluating log-likelihood function "
-                   << std::endl;
+   if (RooAbsReal::numEvalErrors() > 0) {
+      coutW(Eval) << "BayesianCalculator::GetInterval : " << RooAbsReal::numEvalErrors()
+                  << " errors reported in evaluating log-likelihood function " << std::endl;
+   }
 
    RooAbsReal::clearEvalErrorLog();
    RooAbsReal::setEvalErrorLoggingMode(RooAbsReal::PrintErrors);
@@ -1201,7 +1194,7 @@ void BayesianCalculator::ComputeIntervalUsingRooFit(double lowerCutOff, double u
 
    coutI(Eval) <<  "BayesianCalculator: Compute interval using RooFit:  posteriorPdf + createCdf + RooBrentRootFinder " << std::endl;
 
-   RooRealVar* poi = dynamic_cast<RooRealVar*>( fPOI.first() );
+   RooRealVar* poi = dynamic_cast<RooRealVar*>(fPOI.first() );
    assert(poi);
 
    fValidInterval = false;
@@ -1233,12 +1226,12 @@ void BayesianCalculator::ComputeIntervalUsingRooFit(double lowerCutOff, double u
    }
    else
       fUpper = poi->getMax();
-   if (!ret)  coutE(Eval) << "BayesianCalculator::GetInterval "
-                           << "Error returned from Root finder, estimated interval is not fully correct"
-                           << std::endl;
-   else
+   if (!ret) {
+      coutE(Eval) << "BayesianCalculator::GetInterval "
+                  << "Error returned from Root finder, estimated interval is not fully correct" << std::endl;
+   } else {
       fValidInterval = true;
-
+   }
 
    poi->setVal(tmpVal); // patch: restore the original value of poi
 }
@@ -1252,7 +1245,7 @@ void BayesianCalculator::ComputeIntervalFromCdf(double lowerCutOff, double upper
 
    coutI(InputArguments) <<  "BayesianCalculator:GetInterval Compute the interval from the posterior cdf " << std::endl;
 
-   RooRealVar* poi = dynamic_cast<RooRealVar*>( fPOI.first() );
+   RooRealVar* poi = dynamic_cast<RooRealVar*>(fPOI.first() );
    assert(poi);
    if (GetPosteriorFunction() == nullptr) {
       coutE(InputArguments) <<  "BayesianCalculator::GetInterval() cannot make posterior Function " << std::endl;
@@ -1344,7 +1337,7 @@ void BayesianCalculator::ApproximatePosterior() const {
 
    coutI(Eval) << "BayesianCalculator - scan posterior function in nbins = " << tmp->GetNpx() << std::endl;
 
-   fApproxPosterior = (TF1*) tmp->Clone();
+   fApproxPosterior = static_cast<TF1*>(tmp->Clone());
    // save this function for future reuse
    // I can delete now original posterior and use this approximated copy
    delete tmp;
@@ -1437,12 +1430,11 @@ void BayesianCalculator::ComputeShortestInterval( ) const {
       fLower = lower;
       fUpper = upper;
 
-
-
-      if ( std::abs(actualCL-(1.-fSize)) > 0.1*(1.-fSize) )
-         coutW(Eval) << "BayesianCalculator::ComputeShortestInterval - actual interval CL = "
-                     << actualCL << " differs more than 10% from desired CL value - must increase nbins "
-                     << n << " to an higher value " << std::endl;
+      if (std::abs(actualCL - (1. - fSize)) > 0.1 * (1. - fSize)) {
+         coutW(Eval) << "BayesianCalculator::ComputeShortestInterval - actual interval CL = " << actualCL
+                     << " differs more than 10% from desired CL value - must increase nbins " << n
+                     << " to an higher value " << std::endl;
+      }
    }
    else
       coutE(Eval) << "BayesianCalculator::ComputeShortestInterval " << n << " bins are not sufficient " << std::endl;
