@@ -23,10 +23,6 @@ at each call to nextPoint(...).
 ToyMCSampler is an implementation of the TestStatSampler interface.
 It generates Toy Monte Carlo for a given parameter point and evaluates a
 TestStatistic.
-
-For parallel runs, ToyMCSampler can be given an instance of ProofConfig
-and then run in parallel using proof or proof-lite. Internally, it uses
-ToyMCStudy with the RooStudyManager.
 */
 
 #include "RooStats/ToyMCSampler.h"
@@ -42,7 +38,6 @@ ToyMCStudy with the RooStudyManager.
 #include "RooRandom.h"
 
 #include "RooStudyManager.h"
-#include "RooStats/ToyMCStudy.h"
 #include "RooStats/DetailedOutputAggregator.h"
 #include "RooStats/RooStatsUtils.h"
 #include "RooSimultaneous.h"
@@ -55,7 +50,6 @@ using namespace RooFit;
 using std::endl;
 
 
-ClassImp(RooStats::ToyMCSampler);
 
 namespace RooStats {
 
@@ -78,7 +72,7 @@ void NuisanceParametersSampler::NextPoint(RooArgSet& nuisPoint, double& weight)
 
    // check whether result will have any influence
    if(fPoints->weight() == 0.0) {
-      oocoutI(nullptr,Generation) << "Weight 0 encountered. Skipping." << endl;
+      oocoutI(nullptr,Generation) << "Weight 0 encountered. Skipping." << std::endl;
       NextPoint(nuisPoint, weight);
    }
 }
@@ -95,7 +89,7 @@ void NuisanceParametersSampler::Refresh() {
 
    if (fExpected) {
       // UNDER CONSTRUCTION
-      oocoutI(nullptr,InputArguments) << "Using expected nuisance parameters." << endl;
+      oocoutI(nullptr,InputArguments) << "Using expected nuisance parameters." << std::endl;
 
       int nBins = fNToys;
 
@@ -115,7 +109,7 @@ void NuisanceParametersSampler::Refresh() {
       if(fPoints->numEntries() != fNToys) {
          fNToys = fPoints->numEntries();
          oocoutI(nullptr,InputArguments) <<
-            "Adjusted number of toys to number of bins of nuisance parameters: " << fNToys << endl;
+            "Adjusted number of toys to number of bins of nuisance parameters: " << fNToys << std::endl;
       }
 
 /*
@@ -126,12 +120,12 @@ void NuisanceParametersSampler::Refresh() {
       p->Draw();
       for(int x=0; x < fPoints->numEntries(); x++) {
          fPoints->get(x)->Print("v");
-         cout << fPoints->weight() << endl;
+         std::cout << fPoints->weight() << std::endl;
       }
 */
 
    }else{
-      oocoutI(nullptr,InputArguments) << "Using randomized nuisance parameters." << endl;
+      oocoutI(nullptr,InputArguments) << "Using randomized nuisance parameters." << std::endl;
 
       fPoints = std::unique_ptr<RooDataSet>{fPrior->generate(*fParams, fNToys)};
    }
@@ -143,20 +137,6 @@ bool ToyMCSampler::fgAlwaysUseMultiGen = false ;
 
 void ToyMCSampler::SetAlwaysUseMultiGen(bool flag) { fgAlwaysUseMultiGen = flag ; }
 
-////////////////////////////////////////////////////////////////////////////////
-/// Proof constructor. Do not use.
-
-ToyMCSampler::ToyMCSampler()
-   : fSamplingDistName("SD"),
-     fNToys(1),
-     fMaxToys(RooNumber::infinity()),
-     fAdaptiveLowLimit(-RooNumber::infinity()),
-     fAdaptiveHighLimit(RooNumber::infinity())
-{
-   //suppress messages for num integration of Roofit
-   RooMsgService::instance().getStream(1).removeTopic(RooFit::NumIntegration);
-}
-
 ////////////////////////////////////////////////////////////////////////////////
 
 ToyMCSampler::ToyMCSampler(TestStatistic &ts, Int_t ntoys)
@@ -188,10 +168,10 @@ ToyMCSampler::~ToyMCSampler() {
 bool ToyMCSampler::CheckConfig(void) {
    bool goodConfig = true;
 
-   if(fTestStatistics.empty() || fTestStatistics[0] == nullptr) { ooccoutE(nullptr,InputArguments) << "Test statistic not set." << endl; goodConfig = false; }
-   if(!fObservables) { ooccoutE(nullptr,InputArguments) << "Observables not set." << endl; goodConfig = false; }
-   if(!fParametersForTestStat) { ooccoutE(nullptr,InputArguments) << "Parameter values used to evaluate the test statistic are not set." << endl; goodConfig = false; }
-   if(!fPdf) { ooccoutE(nullptr,InputArguments) << "Pdf not set." << endl; goodConfig = false; }
+   if(fTestStatistics.empty() || fTestStatistics[0] == nullptr) { ooccoutE(nullptr,InputArguments) << "Test statistic not set." << std::endl; goodConfig = false; }
+   if(!fObservables) { ooccoutE(nullptr,InputArguments) << "Observables not set." << std::endl; goodConfig = false; }
+   if(!fParametersForTestStat) { ooccoutE(nullptr,InputArguments) << "Parameter values used to evaluate the test statistic are not set." << std::endl; goodConfig = false; }
+   if(!fPdf) { ooccoutE(nullptr,InputArguments) << "Pdf not set." << std::endl; goodConfig = false; }
 
    return goodConfig;
 }
@@ -245,15 +225,15 @@ const RooArgList* ToyMCSampler::EvaluateAllTestStatistics(RooAbsData& data, cons
 
 SamplingDistribution* ToyMCSampler::GetSamplingDistribution(RooArgSet& paramPointIn) {
    if(fTestStatistics.size() > 1) {
-      oocoutW(nullptr, InputArguments) << "Multiple test statistics defined, but only one distribution will be returned." << endl;
+      oocoutW(nullptr, InputArguments) << "Multiple test statistics defined, but only one distribution will be returned." << std::endl;
       for( unsigned int i=0; i < fTestStatistics.size(); i++ ) {
-         oocoutW(nullptr, InputArguments) << " \t test statistic: " << fTestStatistics[i] << endl;
+         oocoutW(nullptr, InputArguments) << " \t test statistic: " << fTestStatistics[i] << std::endl;
       }
    }
 
    std::unique_ptr<RooDataSet> r{GetSamplingDistributions(paramPointIn)};
    if(r == nullptr || r->numEntries() == 0) {
-      oocoutW(nullptr, Generation) << "no sampling distribution generated" << endl;
+      oocoutW(nullptr, Generation) << "no sampling distribution generated" << std::endl;
       return nullptr;
    }
 
@@ -265,57 +245,12 @@ SamplingDistribution* ToyMCSampler::GetSamplingDistribution(RooArgSet& paramPoin
 
 RooDataSet* ToyMCSampler::GetSamplingDistributions(RooArgSet& paramPointIn)
 {
-
    // ======= S I N G L E   R U N ? =======
-   if(!fProofConfig)
-      return GetSamplingDistributionsSingleWorker(paramPointIn);
-
-   // ======= P A R A L L E L   R U N =======
-   if (!CheckConfig()){
-      oocoutE(nullptr, InputArguments)
-         << "Bad COnfiguration in ToyMCSampler "
-         << endl;
-      return nullptr;
-   }
-
-   // turn adaptive sampling off if given
-   if(fToysInTails) {
-      fToysInTails = 0;
-      oocoutW(nullptr, InputArguments)
-         << "Adaptive sampling in ToyMCSampler is not supported for parallel runs."
-         << endl;
-   }
-
-   // adjust number of toys on the slaves to keep the total number of toys constant
-   Int_t totToys = fNToys;
-   fNToys = (int)ceil((double)fNToys / (double)fProofConfig->GetNExperiments()); // round up
-
-   // create the study instance for parallel processing
-   ToyMCStudy toymcstudy{};
-   toymcstudy.SetToyMCSampler(*this);
-   toymcstudy.SetParamPoint(paramPointIn);
-   toymcstudy.SetRandomSeed(RooRandom::randomGenerator()->Integer(TMath::Limits<unsigned int>::Max() ) );
-
-   // temporary workspace for proof to avoid messing with TRef
-   RooWorkspace w(fProofConfig->GetWorkspace());
-   RooStudyManager studymanager(w, toymcstudy);
-   studymanager.runProof(fProofConfig->GetNExperiments(), fProofConfig->GetHost(), fProofConfig->GetShowGui());
-
-   RooDataSet* output = toymcstudy.merge();
-
-   // reset the number of toys
-   fNToys = totToys;
-
-   return output;
+   return GetSamplingDistributionsSingleWorker(paramPointIn);
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-/// This is the main function for serial runs. It is called automatically
-/// from inside GetSamplingDistribution when no ProofConfig is given.
-/// You should not call this function yourself. This function should
-/// be used by ToyMCStudy on the workers (ie. when you explicitly want
-/// a serial run although ProofConfig is present).
-///
+/// This is the main function for serial runs.
 
 RooDataSet* ToyMCSampler::GetSamplingDistributionsSingleWorker(RooArgSet& paramPointIn)
 {
@@ -328,7 +263,7 @@ RooDataSet* ToyMCSampler::GetSamplingDistributionsSingleWorker(RooArgSet& paramP
    if (!CheckConfig()){
       oocoutE(nullptr, InputArguments)
          << "Bad COnfiguration in ToyMCSampler "
-         << endl;
+         << std::endl;
       return nullptr;
    }
 
@@ -353,7 +288,7 @@ RooDataSet* ToyMCSampler::GetSamplingDistributionsSingleWorker(RooArgSet& paramP
       if ( i% 500 == 0 && i>0 ) {
          oocoutP(nullptr,Generation) << "generated toys: " << i << " / " << fNToys;
          if (fToysInTails) ooccoutP(nullptr,Generation) << " (tails: " << toysInTails << " / " << fToysInTails << ")" << std::endl;
-         else ooccoutP(nullptr,Generation) << endl;
+         else ooccoutP(nullptr,Generation) << std::endl;
       }
 
       // TODO: change this treatment to keep track of all values so that the threshold
@@ -388,7 +323,7 @@ RooDataSet* ToyMCSampler::GetSamplingDistributionsSingleWorker(RooArgSet& paramP
 
       // check for nan
       if(valueFirst != valueFirst) {
-         oocoutW(nullptr, Generation) << "skip: " << valueFirst << ", " << weight << endl;
+         oocoutW(nullptr, Generation) << "skip: " << valueFirst << ", " << weight << std::endl;
          continue;
       }
 
@@ -413,7 +348,7 @@ void ToyMCSampler::GenerateGlobalObservables(RooAbsPdf& pdf) const {
 
 
    if(!fGlobalObservables  ||  fGlobalObservables->empty()) {
-      ooccoutE(nullptr,InputArguments) << "Global Observables not set." << endl;
+      ooccoutE(nullptr,InputArguments) << "Global Observables not set." << std::endl;
       return;
    }
 
@@ -478,7 +413,7 @@ void ToyMCSampler::GenerateGlobalObservables(RooAbsPdf& pdf) const {
 RooAbsData* ToyMCSampler::GenerateToyData(RooArgSet& paramPoint, double& weight, RooAbsPdf& pdf) const {
 
    if(!fObservables) {
-      ooccoutE(nullptr,InputArguments) << "Observables not set." << endl;
+      ooccoutE(nullptr,InputArguments) << "Observables not set." << std::endl;
       return nullptr;
    }
 
@@ -491,7 +426,7 @@ RooAbsData* ToyMCSampler::GenerateToyData(RooArgSet& paramPoint, double& weight,
    if(!fNuisanceParametersSampler && fPriorNuisance && fNuisancePars) {
       fNuisanceParametersSampler = new NuisanceParametersSampler(fPriorNuisance, fNuisancePars, fNToys, fExpectedNuisancePar);
       if ((fUseMultiGen || fgAlwaysUseMultiGen) &&  fNuisanceParametersSampler )
-         oocoutI(nullptr,InputArguments) << "Cannot use multigen when nuisance parameters vary for every toy" << endl;
+         oocoutI(nullptr,InputArguments) << "Cannot use multigen when nuisance parameters vary for every toy" << std::endl;
    }
 
    // generate global observables
@@ -556,7 +491,12 @@ std::unique_ptr<RooAbsData> ToyMCSampler::Generate(RooAbsPdf &pdf, RooArgSet &ob
   bool useMultiGen = (fUseMultiGen || fgAlwaysUseMultiGen) && !fNuisanceParametersSampler;
 
   if (events == 0) {
-    if (pdf.canBeExtended() && pdf.expectedEvents(observables) > 0) {
+    if (!pdf.canBeExtended() || pdf.expectedEvents(observables) <= 0) {
+      std::stringstream ss;
+      ss << "ToyMCSampler: Error : pdf is not extended and number of events per toy is zero";
+      oocoutE(nullptr,InputArguments) << ss.str() << std::endl;
+      throw std::runtime_error(ss.str());
+    }
       if(fGenerateBinned) {
         if(protoData) data = std::unique_ptr<RooDataSet>{pdf.generate(observables, AllBinned(), Extended(), ProtoData(*protoData, true, true))};
         else          data = std::unique_ptr<RooDataSet>{pdf.generate(observables, AllBinned(), Extended())};
@@ -578,12 +518,9 @@ std::unique_ptr<RooAbsData> ToyMCSampler::Generate(RooAbsPdf &pdf, RooArgSet &ob
 
         }
       }
-    } else {
-      oocoutE(nullptr,InputArguments)
-                << "ToyMCSampler: Error : pdf is not extended and number of events per toy is zero"
-                << endl;
-    }
-  } else {
+
+      return data;
+  }
     if (fGenerateBinned) {
       if(protoData) data = std::unique_ptr<RooDataSet>{pdf.generate(observables, events, AllBinned(), ProtoData(*protoData, true, true))};
       else          data = std::unique_ptr<RooDataSet>{pdf.generate(observables, events, AllBinned())};
@@ -604,7 +541,6 @@ std::unique_ptr<RooAbsData> ToyMCSampler::Generate(RooAbsPdf &pdf, RooArgSet &ob
         }
       }
     }
-  }
 
   return data;
 }
