@@ -4,7 +4,9 @@
 #include <memory>
 #include <string>
 
+#ifdef SOFIE_SUPPORT_ROOT_BINARY
 #include "TFile.h"
+#endif
 
 #include "TMVA/RModel.hxx"
 #include "TMVA/SOFIE_common.hxx"
@@ -13,6 +15,10 @@ namespace TMVA {
 namespace Experimental {
 namespace SOFIE {
 
+namespace {
+const std::string SP = "   ";
+}
+
 std::underlying_type_t<Options> operator|(Options opA, Options opB) {
     return static_cast<std::underlying_type_t<Options>>(opA) | static_cast<std::underlying_type_t<Options>>(opB);
 }
@@ -20,40 +26,7 @@ std::underlying_type_t<Options> operator|(std::underlying_type_t<Options> opA, O
     return opA | static_cast<std::underlying_type_t<Options>>(opB);
 }
 
-RModel::RModel(RModel&& other) {
-    fInputTensorInfos = std::move(other.fInputTensorInfos);
-    fReadyInputTensorInfos = std::move(other.fReadyInputTensorInfos);
-    fOutputTensorNames = other.fOutputTensorNames;
-    fInputTensorNames = other.fInputTensorNames;
-    fOperators = std::move(other.fOperators);
-    fInitializedTensors = std::move(other.fInitializedTensors);
-    fIntermediateTensorInfos = std::move(other.fIntermediateTensorInfos);
-    fName = other.fName;
-    fFileName = other.fFileName;
-    fParseTime = other.fParseTime;
-    fGC = other.fGC;
-    fNeededBlasRoutines = other.fNeededBlasRoutines;
-    fNeededStdLib = other.fNeededStdLib;
-}
-
-RModel& RModel::operator=(RModel&& other) {
-    fInputTensorInfos = std::move(other.fInputTensorInfos);
-    fReadyInputTensorInfos = std::move(other.fReadyInputTensorInfos);
-    fOutputTensorNames = other.fOutputTensorNames;
-    fInputTensorNames = other.fInputTensorNames;
-    fOperators = std::move(other.fOperators);
-    fInitializedTensors = std::move(other.fInitializedTensors);
-    fIntermediateTensorInfos = std::move(other.fIntermediateTensorInfos);
-    fName = other.fName;
-    fFileName = other.fFileName;
-    fParseTime = other.fParseTime;
-    fGC = other.fGC;
-    fNeededBlasRoutines = other.fNeededBlasRoutines;
-    fNeededStdLib = other.fNeededStdLib;
-    return *this;
-}
-
-const std::vector<size_t>& RModel::GetTensorShape(std::string name) {
+const std::vector<size_t>& RModel::GetTensorShape(std::string name) const {
     auto f = fReadyInputTensorInfos.find(name);
     if (f != fReadyInputTensorInfos.end()) {
         return f->second.shape;
@@ -79,7 +52,7 @@ const std::vector<size_t>& RModel::GetTensorShape(std::string name) {
     throw std::runtime_error("TMVA SOFIE tensor [" + name + "] for which the shape is requested is not found");
 }
 
-std::vector<Dim> RModel::GetDynamicTensorShape(std::string name) {
+std::vector<Dim> RModel::GetDynamicTensorShape(std::string name) const {
    if (auto f = fDynamicTensorInfos.find(name); f != fDynamicTensorInfos.end()) {
       return f->second.shape;
    }
@@ -91,7 +64,7 @@ std::vector<Dim> RModel::GetDynamicTensorShape(std::string name) {
    return ConvertShapeToDim(GetTensorShape(name));
 }
 
-const ETensorType& RModel::GetTensorType(std::string name) {
+const ETensorType& RModel::GetTensorType(std::string name) const {
     auto f = fReadyInputTensorInfos.find(name);
     if (f != fReadyInputTensorInfos.end()) {
         return f->second.type;
@@ -116,7 +89,7 @@ const ETensorType& RModel::GetTensorType(std::string name) {
     if (fIsSubGraph && fParentGraph)
       return fParentGraph->GetTensorType(name);
 
-    throw std::runtime_error("TMVA SOFIE tensor [" + name + "] for which the type is requested is not found");
+    throw std::runtime_error("TMVA SOFIE tensor [" + name + "] for which the type is requested is not found, model name: " + fName);
 }
 
 bool RModel::CheckIfTensorAlreadyExist(std::string tensor_name) {
@@ -149,12 +122,13 @@ void RModel::AddInputTensorInfo(std::string input_name, ETensorType type, std::v
 }
 
 void RModel::AddInputTensorName(std::string input_name) {
-    fInputTensorNames.push_back(UTILITY::Clean_name(input_name));
+    fInputTensorNames.emplace_back(UTILITY::Clean_name(input_name));
 }
 
 void RModel::AddOperator(std::unique_ptr<ROperator> op, int order_execution) {
     AddBlasRoutines(op->GetBlasRoutines());
     auto libs = op->GetStdLibs();
+    auto op_input_tensors = op->GetOpInputTensors();
     for (auto& stdlib : libs) {
         AddNeededStdLib(stdlib);
     }
@@ -163,6 +137,19 @@ void RModel::AddOperator(std::unique_ptr<ROperator> op, int order_execution) {
     } else {
         fOperators.push_back(std::move(op));
     }
+
+    // storing the last usage of tensors which are input to
+    // operators (but are not inputs to the model, i.e. they are intermediate
+    // tensors). This information is needed to keep a check on when a
+    // particular intermediate tensor can be flushed to free up memory for reuse.
+   for(size_t index = 0; index<op_input_tensors.size() &&
+         fInitializedTensors.find(UTILITY::Clean_name(std::string(op_input_tensors[index]))) == fInitializedTensors.end() &&
+         std::find(fInputTensorNames.begin(), fInputTensorNames.end(),
+                   UTILITY::Clean_name(std::string(op_input_tensors[index]))) == fInputTensorNames.end() &&
+         fDynamicTensorInfos.find(UTILITY::Clean_name(std::string(op_input_tensors[index]))) == fDynamicTensorInfos.end();
+         ++index){
+            fIntermediateTensorFrequencyLookup[op_input_tensors[index]] = order_execution;
+   }
 }
 
 void RModel::AddInitializedTensor(std::string tensor_name, ETensorType type, std::vector<std::size_t> shape, std::shared_ptr<void> data) {
@@ -189,15 +176,25 @@ bool RModel::IsInitializedTensor(const std::string& tensorName) const {
     std::string name = UTILITY::Clean_name(tensorName);
     return fInitializedTensors.find(name) != fInitializedTensors.end();
 }
+bool RModel::IsConstantTensor(const std::string& tensorName) const {
+    std::string name = UTILITY::Clean_name(tensorName);
+    auto itr = fInitializedTensors.find(name);
+    if (itr == fInitializedTensors.end()) return false;
+    return itr->second.IsConstantTensor();
+}
 
 bool RModel::IsDynamicTensor(const std::string& tensorName) const {
    std::string name = UTILITY::Clean_name(tensorName);
    return fDynamicTensorInfos.find(name) != fDynamicTensorInfos.end();
 }
-bool RModel::IsInputTensor(const std::string& tensorName) const {
+bool RModel::IsDimInputTensor(const std::string& tensorName) const {
    std::string name = UTILITY::Clean_name(tensorName);
    return fInputTensorInfos.find(name) != fInputTensorInfos.end();
 }
+bool RModel::IsReadyInputTensor(const std::string& tensorName) const {
+   std::string name = UTILITY::Clean_name(tensorName);
+   return fReadyInputTensorInfos.find(name) != fReadyInputTensorInfos.end();
+}
 
 // generic addition of a tensor
 void RModel::AddIntermediateTensor(std::string tensor_name, ETensorType type, std::vector<Dim> dim_shape) {
@@ -241,7 +238,7 @@ void RModel::AddDynamicTensor(std::string tensor_name, ETensorType type, std::ve
 void RModel::AddOutputTensorNameList(std::vector<std::string> outputtensornames) {
     fOutputTensorNames.clear();
     for(auto& it : outputtensornames) {
-        fOutputTensorNames.push_back(UTILITY::Clean_name(it));
+        fOutputTensorNames.emplace_back(UTILITY::Clean_name(it));
     }
 }
 
@@ -278,6 +275,101 @@ void RModel::SetNotWritableInitializedTensor(const std::string & tensor_name) {
       t->second.SetNotWritable();
    }
 
+std::string RModel::AllocateIntermediateMemory(std::span<const std::string_view> op_output_tensors)
+{
+   std::stringstream code;
+
+   auto declareIntermediateTensor = [this, &code](std::string const &name, int size, int location) {
+      std::string typeName = ConvertTypeToString(GetTensorType(name));
+      code << "\n // Allocating memory for intermediate tensor " << name << " with size " << size << " bytes";
+      code << "\n"
+           << typeName << "* tensor_" << name << " = reinterpret_cast<" << typeName
+           << "*>(fIntermediateMemoryPool.data() + " << location << ");\n";
+   };
+
+   for (auto &it : op_output_tensors) {
+         std::string name = std::string{it};
+         bool allocated = false;
+         if (GetTensorType(name) == ETensorType::BOOL ||
+            fInitializedTensors.find(name) != fInitializedTensors.end() ||
+            fDynamicTensorInfos.find(name) != fDynamicTensorInfos.end()) continue;
+
+         auto tensor_size = GetTypeSize(GetTensorType(name)) * ConvertShapeToLength(GetTensorShape(name));
+
+            for (auto chunk = fIntermediateMemoryInfo.available_stack.begin(); chunk != fIntermediateMemoryInfo.available_stack.end(); ) {
+
+                  // check if available memory chunks can accommodate the tensor
+                  if (chunk->second >= tensor_size) {
+                     auto new_chunk = fIntermediateMemoryInfo.total_stack[chunk->first].split(it, tensor_size);
+                     auto new_chunk_location = chunk->first+chunk->second-tensor_size;
+                     fIntermediateMemoryInfo.total_stack[new_chunk_location] = new_chunk;
+
+                     declareIntermediateTensor(name, tensor_size, new_chunk_location);
+                     chunk->second -= tensor_size;
+
+                     allocated = true;
+
+                     if (chunk->second == 0) {
+                        chunk = fIntermediateMemoryInfo.available_stack.erase(chunk);
+                     }
+
+                     break;
+                  }
+                  ++chunk;
+            }
+
+         if (!allocated) {
+               size_t chunk_idx = fIntermediateMemoryInfo.total_stack.empty()
+                                 ? 0
+                                 : fIntermediateMemoryInfo.total_stack.rbegin()->first + fIntermediateMemoryInfo.total_stack.rbegin()->second.tensor_size;
+
+               fIntermediateMemoryInfo.total_stack[chunk_idx] = {it, tensor_size};
+
+               declareIntermediateTensor(name, tensor_size, chunk_idx);
+         }
+   }
+   return code.str();
+}
+
+void RModel::CheckAndFlushIntermediateMemory(std::span<const std::string_view> op_input_tensors, const size_t& op_idx){
+   for (auto &it : op_input_tensors){
+      // last occurence of the tensor is reached => flush it from memory
+      if (fIntermediateTensorFrequencyLookup[it] == op_idx) {
+         for (auto chunk = fIntermediateMemoryInfo.total_stack.begin();
+               chunk != fIntermediateMemoryInfo.total_stack.end(); ++chunk ) {
+               if (chunk->second.tensor_name == it) {
+
+                     // check if nearby chunks in available memory can coalesce
+                     auto first_greater = fIntermediateMemoryInfo.available_stack.upper_bound(chunk->first); // smallest element greater than the flushed chunk idx
+                     auto last_smaller = (first_greater == fIntermediateMemoryInfo.available_stack.begin()) ? fIntermediateMemoryInfo.available_stack.end() : std::prev(first_greater); // largest element smaller than the flushed chunk idx
+
+                     // check if the next stack entry is actually adjacent in memory
+                     if (last_smaller->first+last_smaller->second + 1 == chunk->first){
+                        last_smaller->second += chunk->second.tensor_size;
+                        fIntermediateMemoryInfo.total_stack[last_smaller->first].merge(chunk->second);
+
+                        if (last_smaller->first + last_smaller->second + 1 == first_greater->first){
+                              fIntermediateMemoryInfo.total_stack[last_smaller->first].merge(fIntermediateMemoryInfo.total_stack[first_greater->first]);
+                              first_greater = fIntermediateMemoryInfo.available_stack.erase(first_greater);
+                        }
+                     } else{
+                        if (chunk->first + chunk->second.tensor_size + 1 == first_greater->first){
+                           fIntermediateMemoryInfo.total_stack[chunk->first].merge(fIntermediateMemoryInfo.total_stack[first_greater->first]);
+                           first_greater = fIntermediateMemoryInfo.available_stack.erase(first_greater);
+                        }
+                        fIntermediateMemoryInfo.available_stack.insert({
+                           chunk->first,
+                           chunk->second.tensor_size
+        });
+                     }
+               }
+         }
+      }
+   }
+}
+
+
+
 void RModel::Initialize(int batchSize, bool verbose) {
    std::map<std::string, size_t> inputParams;
    if (batchSize > 0) {
@@ -286,6 +378,7 @@ void RModel::Initialize(int batchSize, bool verbose) {
       inputParams["bs"] = batchSize;
    }
    Initialize(inputParams, verbose);
+   fIntermediateMemoryInfo = MemoryPoolInfo();
 }
 void RModel::Initialize(const std::map<std::string, size_t> & inputParams, bool verbose) {
 
@@ -364,14 +457,27 @@ void RModel::Initialize(const std::map<std::string, size_t> & inputParams, bool
    }
    // Go through model and initialize each operator
    int i = 0;
-   for (auto &op : fOperators) {
+
+   std::vector<size_t> temp_available_stack; // vector stores individual chunks of available memory that maybe reused
+
+   for(size_t op_idx = 0; op_idx < fOperators.size(); ++op_idx){
       if (verbose) {
-         auto& r = *op.get();
+         auto& r = *fOperators[op_idx].get();
          std::cout << "Initializing operator " << i << "  " << typeid(r).name() << std::endl;
       }
-      op->Initialize(*this);
+      fOperators[op_idx]->Initialize(*this);
+      for(auto &it:fOperators[op_idx]->GetOpOutputTensors()){
+         std::string name = std::string{it};
+         if (fIntermediateTensorFrequencyLookup.find(it) == fIntermediateTensorFrequencyLookup.end() &&
+             std::find(fOutputTensorNames.begin(), fOutputTensorNames.end(), name) == fOutputTensorNames.end() &&
+             fInitializedTensors.find(name) == fInitializedTensors.end() &&
+             fDynamicTensorInfos.find(name) == fDynamicTensorInfos.end()){
+            fIntermediateTensorFrequencyLookup[it] = op_idx;
+         }
+      }
       i++;
    }
+
    fIsInitialized = true;
 }
 
@@ -397,74 +503,120 @@ void RModel::InitializeSubGraph(std::shared_ptr<RModel>  graph) {
 
    // add parent input tensors to current graph
    for (auto & name : fInputTensorNames)
-      graph->fInputTensorNames.push_back(name);
+      graph->fInputTensorNames.emplace_back(name);
 
    // clean graph name
    graph->fName = UTILITY::Clean_name(graph->fName);
 
 }
 
-void RModel::GenerateInitializedTensorInfo() {
-    if (!fInitializedTensors.empty())
-      fGC += "// initialized tensors\n";
-    for (auto& i: fInitializedTensors) {
+// Function to generate the code for declaring and initializing constant tensors
+// This is for tensors which are not part of weight files and can be created from the Constant operator
+template <typename T>
+std::string GenerateConstantTensorCode(const std::pair<std::string, InitializedTensor> &t)
+{
+   std::stringstream strs;
+   std::string type = ConvertTypeToString(t.second.type());
+   size_t length = ConvertShapeToLength(t.second.shape());
+   // avoid using stack sizes for constant tensors to reduce compilation time
+   bool allocateOnStack = (length > 100) ? false : true;
 
-         size_t length = ConvertShapeToLength(i.second.shape());
-            // in case we are not using weight files or for tensor created from Constant operator
-         if (!fUseWeightFile || i.second.IsConstantTensor() ) {
-            //std::cout << "write tensor " << i.first << std::endl;
-            std::stringstream strs;
-            if (i.second.type() == ETensorType::FLOAT) {
-               strs << "float tensor_" << i.first << "[" << length << "] = {";
-               float const *data = i.second.data<float>();
-               for (size_t idx = 0; idx < length; idx++) {
-                  strs << std::setprecision(std::numeric_limits<float>::max_digits10) << data[idx];
-                  if (idx < length-1) strs << ", ";
-               }
-               strs << "};\n";
-            }
-            else if (i.second.type() == ETensorType::INT64) {
-               strs << "int64_t tensor_" << i.first << "[" << length << "] = {";
-               int64_t const *data = i.second.data<int64_t>();
-               for (size_t idx = 0; idx < length; idx++) {
-                  strs << data[idx];
-                  if (idx < length-1) strs << ", ";
-               }
-               strs << "};\n";
-            }
-            fGC += strs.str();
-         }
+   const T *data = t.second.data<T>();
+
+   // and check if all values are the same
+   bool sameData = false;
+   // for non stack allocation check if data are the same
+   if (!allocateOnStack && length > 1) {
+      size_t idx = 1;
+      do {
+         sameData = (data[idx] == data[idx - 1]);
+         idx++;
+      } while (sameData && idx < length);
+   }
+   if (allocateOnStack) {
+      strs << type << " tensor_" << t.first << "[" << length << "] = " << ConvertValuesToString(length, data) << ";\n";
+   } else {
+      strs << "std::vector<" << type << "> fTensor_" << t.first << " = ";
+      if (sameData)
+         strs << "std::vector<" << type << ">(" << length << ", " << ConvertValToString(data[0]) << ");\n";
+      else {
+         strs << ConvertValuesToString(length, data) << ";\n";
+      }
+      strs << "const " << type << " * tensor_" + t.first + " = fTensor_" + t.first + ".data();\n";
+   }
+   return strs.str();
+}
+
+void RModel::GenerateInitializedTensorInfo()
+{
+   if (!fInitializedTensors.empty())
+      fGC += "// initialized tensors\n";
+
+   for (auto &i : fInitializedTensors) {
+      if (!fUseWeightFile || i.second.IsConstantTensor()) {
+         if (i.second.type() == ETensorType::FLOAT)
+            fGC += GenerateConstantTensorCode<float>(i);
+         else if (i.second.type() == ETensorType::INT64)
+            fGC += GenerateConstantTensorCode<int64_t>(i);
+
+      } else {
          // case of tensors which are read from a file
-         else {
-            if (i.second.type() == ETensorType::FLOAT) {
-               fGC += "std::vector<float> fTensor_" + i.first + " = std::vector<float>(" + std::to_string(length) + ");\n";
-               fGC += "float * tensor_" + i.first + " = fTensor_" + i.first + ".data();\n";
-            }
+         size_t length = ConvertShapeToLength(i.second.shape());
+         if (i.second.type() == ETensorType::FLOAT) {
+            fGC += "std::vector<float> fTensor_" + i.first + " = std::vector<float>(" + std::to_string(length) + ");\n";
+            fGC += "float * tensor_" + i.first + " = fTensor_" + i.first + ".data();\n";
          }
-    }
+      }
+   }
+}
+
+void RModel::GenerateIntermediateMemoryPool() {
+   if (fIntermediateMemoryInfo.total_stack.empty()) return;
+   fGC += "\n//--- Allocating session memory pool to be used for allocating intermediate tensors\n";
+
+   // char memory block is allocated since char takes 1 byte, thus easier to allocate tensors
+   // of other data types
+   auto const &totalStack = fIntermediateMemoryInfo.total_stack;
+   const int memPoolSize = totalStack.rbegin()->first + totalStack.rbegin()->second.tensor_size;
+   fGC += "std::vector<char> fIntermediateMemoryPool = std::vector<char>(" + std::to_string(memPoolSize) + ");\n\n";
 }
 
 void RModel::GenerateIntermediateTensorInfo() {
    if (!fIntermediateTensorInfos.empty()) {
-      fGC += "\n//--- declare and allocate the intermediate tensors\n";
+      std::string tensor_declaration_block = "";
       for (auto &i : fIntermediateTensorInfos) {
-         size_t length = ConvertShapeToLength(i.second.shape);
-         if (i.second.type == ETensorType::FLOAT) {
-            fGC += "std::vector<float> fTensor_" + i.first + " = std::vector<float>(" + std::to_string(length) + ");\n";
-            fGC += "float * tensor_" + i.first + " = fTensor_" + i.first + ".data();\n";
-         }
-         if (i.second.type == ETensorType::DOUBLE) {
-            fGC += "std::vector<double> fTensor_" + i.first + " = std::vector<double>(" + std::to_string(length) + ");\n";
-            fGC += "double * tensor_" + i.first + " = fTensor_" + i.first + ".data();\n";
-         }
-         if (i.second.type == ETensorType::INT64) {
-            fGC += "std::vector<int64_t> fTensor_" + i.first + " = std::vector<int64_t>(" + std::to_string(length) + ");\n";
-            fGC += "int64_t * tensor_" + i.first + " = fTensor_" + i.first + ".data();\n";
-         }
          if (i.second.type == ETensorType::BOOL) {
-            fGC += "std::vector<bool> fTensor_" + i.first + " = std::vector<bool>(" + std::to_string(length) + ");\n";
-            // don't allocate pointer since boolean vector don't have the .data() member
+               tensor_declaration_block += "std::vector<bool> fTensor_" + i.first + " = std::vector<bool>(" + std::to_string(ConvertShapeToLength(i.second.shape)) + ");\n";
+               // No pointer allocation possible for BOOL, but we create a reference to the vector to make the data member layout more consistent
+               tensor_declaration_block += "std::vector<bool> & tensor_" + i.first + " = fTensor_" + i.first + ";\n";
+               continue;
          }
+         bool is_extended = (fOptimizationLevel == OptimizationLevel::kExtended);
+         bool not_in_freq_map =
+            (fIntermediateTensorFrequencyLookup.find(i.first) == fIntermediateTensorFrequencyLookup.end());
+         bool not_in_output_names =
+            (std::find(fOutputTensorNames.begin(), fOutputTensorNames.end(), i.first) == fOutputTensorNames.end());
+
+         if ((not_in_freq_map && not_in_output_names) || (!not_in_freq_map && !is_extended && not_in_output_names)) {
+            size_t length = ConvertShapeToLength(i.second.shape);
+
+            if (i.second.type == ETensorType::FLOAT) {
+               tensor_declaration_block += "std::vector<float> fTensor_" + i.first + " = std::vector<float>(" + std::to_string(length) + ");\n";
+               tensor_declaration_block += "float * tensor_" + i.first + " = fTensor_" + i.first + ".data();\n";
+            }
+            else if (i.second.type == ETensorType::DOUBLE) {
+               tensor_declaration_block += "std::vector<double> fTensor_" + i.first + " = std::vector<double>(" + std::to_string(length) + ");\n";
+               tensor_declaration_block += "double * tensor_" + i.first + " = fTensor_" + i.first + ".data();\n";
+            }
+            else if (i.second.type == ETensorType::INT64) {
+               tensor_declaration_block += "std::vector<int64_t> fTensor_" + i.first + " = std::vector<int64_t>(" + std::to_string(length) + ");\n";
+               tensor_declaration_block += "int64_t * tensor_" + i.first + " = fTensor_" + i.first + ".data();\n";
+            }
+         }
+      }
+
+      if (tensor_declaration_block.length()) {
+         fGC += "\n//--- declare and allocate the intermediate tensors\n" + tensor_declaration_block;
       }
    }
    // add also the dynamic tensors (only declarations, allocation will be done later)
@@ -485,17 +637,29 @@ void RModel::GenerateIntermediateTensorInfo() {
    }
 }
 
-void RModel::GenerateDynamicTensorInfo() {
-    fGC += "//---- allocate the intermediate dynamic tensors\n";
-    std::stringstream out;
-    for (auto & i: fDynamicTensorInfos) {
-        auto length = ConvertDynamicShapeToLength(i.second.shape);
-        out << SP <<  "if (" << length << " > 0) {\n";
-        out << SP << SP <<  "fTensor_" <<  i.first  <<  ".resize(" <<  length << ");\n";
-        out << SP << SP <<  "tensor_" << i.first << " = fTensor_" << i.first  << ".data();\n";
-        out << SP << "}\n";
-    }
-    fGC += out.str();
+// generate code for specific operator declarations  to be defined in the Session class
+void RModel::GenerateOperatorDeclarations() {
+   std::string strcode;
+   for (auto & op : fOperators) {
+      strcode += op->GenerateDeclCode();
+   }
+   if (strcode.empty()) return;
+   fGC += "\n//---- operator declarations \n";
+   fGC += strcode;
+   fGC += "\n";
+}
+
+void RModel::GenerateDynamicTensorInfo()
+{
+   std::stringstream out;
+   for (auto &i : fDynamicTensorInfos) {
+      auto length = ConvertDynamicShapeToLength(i.second.shape);
+      out << SP << "if (" << length << " > 0) {\n";
+      out << SP << SP << "fTensor_" << i.first << ".resize(" << length << ");\n";
+      out << SP << SP << "tensor_" << i.first << " = fTensor_" << i.first << ".data();\n";
+      out << SP << "}\n";
+   }
+   fGC += out.str();
 }
 
 std::string RModel::GenerateInferSignature(bool isdecl) {
@@ -506,7 +670,7 @@ std::string RModel::GenerateInferSignature(bool isdecl) {
    int i_input = 0;
    for (auto &name : fInputTensorNames) {
       // if is a dynamic tensor pass initial parameters
-      if (IsInputTensor(name)) {
+      if (IsDimInputTensor(name)) {
          auto shape = GetDynamicTensorShape(name);
          for (auto &d : shape) {
             std::string pName = d.param;
@@ -533,93 +697,84 @@ std::string RModel::GenerateInferSignature(bool isdecl) {
    return rGC;
 }
 
-void RModel::GenerateOutput() {
+namespace {
 
-   if (fVerbose)
-      std::cout << "Generating main inference code for " << fName << std::endl;
+std::string typeForOutput(ETensorType t) {
+   // The std::vector<bool> is a special type that is not wrapping continuous memory.
+   // We don't want to use it as a return type.
+   if (t == ETensorType::BOOL) t = ETensorType::UINT8;
+   return ConvertTypeToString(t);
+}
 
+}
+
+void RModel::GenerateOutput()
+{
    size_t outputSize = fOutputTensorNames.size();
    // assume output types are all the same
-   if (outputSize == 0)
-      throw std::runtime_error("TMVA-SOFIE: output size=0 are not supported");
 
-   std::string outputType;
-   ETensorType eOutputType;
-   eOutputType = GetTensorType(fOutputTensorNames[0]);
-   outputType = ConvertTypeToString(eOutputType);
+   bool sameOutputTypes = true;
+   std::string inferReturnType; // type return by infer function
+   ETensorType eFirstOutputType = GetTensorType(*fOutputTensorNames.begin());
+   fGC += "\n\n";
    if (outputSize == 1) {
-      fGC += "std::vector<" + outputType + "> ";
+      fGC += "std::vector<" + typeForOutput(eFirstOutputType) + ">";
    } else {
-      // we assume all output types are the same
-      for (size_t i = 1; i < outputSize; i++) {
-         if (GetTensorType(fOutputTensorNames[i]) != eOutputType)
-            throw std::runtime_error("TMVA-SOFIE: different output tensor types are not supported");
+      // if all output types are the same we return an std::vector - otherwise a tuple
+      for (std::string const &name : fOutputTensorNames) {
+         if (GetTensorType(name) != eFirstOutputType)
+            sameOutputTypes = false;
       }
-      fGC += "std::vector<std::vector<" + outputType + ">> ";
-   }
-
-   fGC += "infer(";
-
-   fGC += GenerateInferSignature();
-
-   fGC += "){\n";
-
-   for (size_t id = 0; id < fOperators.size(); id++) {
-      if (fVerbose) std::cout << "Generating code for operator .... " << id << std::endl;
-      fGC += (fOperators[id]->Generate(std::to_string(id)));
-   }
-
-   if (outputSize == 1) {
-      std::string tensorName = fOutputTensorNames[0];
-      if (fIntermediateTensorInfos.count(tensorName) > 0) {
-         // need to check is size is the same(don't want to return a vector with larger size)
-         // in that case better to copy
-         fGC += SP + "return fTensor_" + tensorName + ";\n";
-      } else {
-         // include also dynamic tensors since the vectors can be allocated with a size larger than their output
-         // we need a special handling for bool type allocated as vector<bool>
-         auto outputLength = ConvertDynamicShapeToLength(GetDynamicTensorShape(tensorName));
-         if (IsDynamicTensor(tensorName) && eOutputType == ETensorType::BOOL) {
-            fGC += SP + "std::vector<bool> ret (fTensor_" + tensorName + ".begin(), fTensor_" + tensorName +
-                   ".begin() + " + outputLength + ");\n";
-         } else {
-            fGC += SP + "std::vector<" + outputType + "> ret (tensor_" + tensorName + ", tensor_" + tensorName + " + " +
-                  outputLength + ");\n";
-         }
-         fGC += SP + "return ret;\n";
-      }
-   } else {
-      // here we assume all outputs have same type
-      fGC += SP + "std::vector<std::vector<" + outputType + ">> ret({";
-      for (size_t i = 0; i < outputSize; i++) {
-         std::string tensorName = fOutputTensorNames[i];
-         if (!tensorName.empty()) {
-            if (fIntermediateTensorInfos.count(tensorName) > 0) {
-               fGC += "fTensor_" + tensorName;
-            } else {
-               auto outputLength = ConvertDynamicShapeToLength(GetDynamicTensorShape(tensorName));
-               if (IsDynamicTensor(tensorName) && eOutputType == ETensorType::BOOL) {
-                  fGC += "std::vector<bool>(fTensor_" + tensorName + ".begin(), fTensor_" + tensorName + ".begin() + " +
-                        outputLength + ");\n";
-               } else {
-                  fGC += "std::vector<" + outputType + ">(tensor_" + tensorName + ", tensor_" + tensorName + " + " +
-                        outputLength + ")";
-               }
-            }
+      if (sameOutputTypes)
+         fGC += "std::vector<std::vector<" + typeForOutput(eFirstOutputType) + ">>";
+      else {
+         inferReturnType = "std::tuple<";
+         for (size_t i = 0; i < outputSize; i++) {
+            inferReturnType += "std::vector<" + typeForOutput(GetTensorType(fOutputTensorNames[i])) + ">";
             if (i < outputSize - 1)
-               fGC += ",";
-         } else {
-            fGC += "{}";
+               inferReturnType += ",";
          }
+         inferReturnType += ">";
+         fGC += inferReturnType;
       }
-      fGC += "});\n";
-      fGC += SP + "return ret;\n";
    }
-   fGC += "}\n";  // end of infer function scope
+
+   fGC += " infer(" + GenerateInferSignature() + "){\n";
+
+   std::string doInferArgs = GenerateInferSignature(false);
+   if (!doInferArgs.empty())
+      doInferArgs += ",";
+   for (std::string const &name : fOutputTensorNames) {
+      fGC += SP + "std::vector<" + typeForOutput(GetTensorType(name)) + " > output_tensor_" + name + ";\n";
+      doInferArgs += " output_tensor_" + name + ",";
+   }
+   if (!doInferArgs.empty())
+      doInferArgs.back() = ' ';
+
+   fGC += SP + "doInfer(" + doInferArgs + ");\n";
+
+   fGC += SP + "return {";
+   for (size_t i = 0; i < fOutputTensorNames.size(); i++) {
+      fGC += "output_tensor_" + fOutputTensorNames[i];
+      if (i < fOutputTensorNames.size() - 1)
+         fGC += ",";
+   }
+   fGC += "};\n";
+   fGC += "}\n"; // end of infer function scope
 }
 
 void RModel::GenerateSessionCode()
 {
+   // Determine the signature of the actual inference function
+   std::string doInferSignature = GenerateInferSignature();
+   if (!doInferSignature.empty())
+      doInferSignature += ", ";
+   for (auto const &name : fOutputTensorNames) {
+      doInferSignature += " std::vector<" + typeForOutput(GetTensorType(name)) + "> &output_tensor_" + name + ",";
+   }
+   doInferSignature.back() = ' ';
+
+   doInferSignature = "void doInfer(" + doInferSignature + ")";
 
    // define the Session struct (for GNN this is generated in RModel_GNN)
    if (fUseSession && !fIsGNNComponent) {
@@ -629,8 +784,36 @@ void RModel::GenerateSessionCode()
          fGC += "struct Session_" + fName + " {\n";
    }
 
+   // generate code for declaring the initialized tensors
    GenerateInitializedTensorInfo();
+
+   if (fOptimizationLevel == OptimizationLevel::kExtended) {
+      // evaluate total intermediate memory and position intermediate tensor addresses
+      std::string intermediate_memory_alloc_string = "";
+      intermediate_memory_alloc_string += "\n// --- Positioning intermediate tensor memory --";
+      for (size_t op_idx = 0; op_idx < fOperators.size(); ++op_idx) {
+         intermediate_memory_alloc_string += AllocateIntermediateMemory(fOperators[op_idx]->GetOpOutputTensors());
+         CheckAndFlushIntermediateMemory(fOperators[op_idx]->GetOpInputTensors(), op_idx);
+      }
+
+      // to check remaining unused fragments after memory allocation (lesser the better)
+      // for (const auto &it: fIntermediateMemoryInfo.available_stack){
+      //    std::cout<<"chunk_idx: "<<it.first<<", chunk_size: "<<it.second<<"\n";
+      // }
+
+      // generate the memory pool to be used by intermediate tensors
+      GenerateIntermediateMemoryPool();
+
+      // position intermediate tensors
+      fGC += intermediate_memory_alloc_string;
+   }
+
+   // generate the declaring the intermediate tensors
    GenerateIntermediateTensorInfo();
+   // generate code for declarations of some specific operators
+   GenerateOperatorDeclarations();
+
+
 
    // add subgraph session
    if (!fSubGraphs.empty()) fGC += "//   subgraph sessions\n";
@@ -638,6 +821,7 @@ void RModel::GenerateSessionCode()
       fGC += "Session_" + graph->fName + "  fSession_" + graph->fName + ";\n";
    }
 
+   // Generate code for Session constructor
    if (fUseSession) {
       std::string sessionName = "Session";
       if (fIsSubGraph)
@@ -692,11 +876,41 @@ void RModel::GenerateSessionCode()
       fGC += "}\n\n";
    }
 
+   fGC += doInferSignature + "{\n";
+   fGC += "\n";
+
+   // generate the inference code
+   if (fVerbose)
+      std::cout << "Generating main inference code for " << fName << std::endl;
+
+   if (fOutputTensorNames.size() == 0)
+      throw std::runtime_error("TMVA-SOFIE: output size=0 are not supported");
+
+   for (size_t op_idx = 0; op_idx < fOperators.size(); ++op_idx) {
+      if (fVerbose)
+         std::cout << "Generating code for operator .... " << op_idx << std::endl;
+      fGC += (fOperators[op_idx]->Generate(std::to_string(op_idx)));
+   }
+
+   fGC += SP + "using TMVA::Experimental::SOFIE::UTILITY::FillOutput;\n\n";
+
+   for (std::string const &name : fOutputTensorNames) {
+      // need to check is size is the same (don't want to return a vector with
+      // larger size) in that case better to copy
+      bool isIntermediate = fIntermediateTensorInfos.count(name) > 0;
+      std::string n = isIntermediate ? std::to_string(ConvertShapeToLength(GetTensorShape(name)))
+                                     : ConvertDynamicShapeToLength(GetDynamicTensorShape(name));
+      fGC += SP + "FillOutput(tensor_" + name + ", output_tensor_" + name + ", " + n + ");\n";
+   }
+
+   fGC += "}\n\n";
+
+   // generate the inference overload that returns an output struct
    GenerateOutput();
 
    // end of session
    if (fUseSession && !fIsGNNComponent) {
-      fGC += "};   // end of Session\n";
+      fGC += "};   // end of Session\n\n";
    }
 }
 
@@ -778,7 +992,7 @@ void RModel::ReadInitializedTensorsFromFile(long pos) {
 
         // loop on tensors and parse the file
         for (auto& i: fInitializedTensors) {
-            // skip Constant and shape tensors
+            // skip Constant and shape tensors (not written in a file)
             if (!i.second.IsWeightTensor()) continue;
             std::string tensor_name = "tensor_" + i.first;
             if (i.second.type() == ETensorType::FLOAT) {
@@ -810,6 +1024,7 @@ void RModel::ReadInitializedTensorsFromFile(long pos) {
 
     // generate the code to read initialized tensors from a ROOT data file
     if(fWeightFile == WeightFileType::RootBinary) {
+#ifdef SOFIE_SUPPORT_ROOT_BINARY
         fGC += "  {\n";
         fGC += "   std::unique_ptr<TFile> rootFile(TFile::Open(filename.c_str(), \"READ\"));\n";
         fGC += "   if (!rootFile->IsOpen()) {\n";
@@ -841,6 +1056,9 @@ void RModel::ReadInitializedTensorsFromFile(long pos) {
             fGC += "  }\n";
         }
         fGC += "  }\n";
+#else
+        throw std::runtime_error("SOFIE was not built with ROOT file support.");
+#endif // SOFIE_SUPPORT_ROOT_BINARY
     }
 }
 
@@ -866,6 +1084,7 @@ long RModel::WriteInitializedTensorsToFile(std::string filename) {
 
     // Write the initialized tensors to the file
     if (fWeightFile == WeightFileType::RootBinary) {
+#ifdef SOFIE_SUPPORT_ROOT_BINARY
         if(fIsGNNComponent || fIsGNN) {
             throw std::runtime_error("SOFIE-GNN yet not supports writing to a ROOT file.");
         }
@@ -909,6 +1128,9 @@ long RModel::WriteInitializedTensorsToFile(std::string filename) {
         // this needs to be changed, similar to the text file
         return -1;
 
+#else
+        throw std::runtime_error("SOFIE was not built with ROOT file support.");
+#endif // SOFIE_SUPPORT_ROOT_BINARY
     } else if (fWeightFile == WeightFileType::Text) {
         std::ofstream f;
         if(fIsGNNComponent) {
@@ -1103,13 +1325,13 @@ void RModel::OutputGenerated(std::string filename, bool append) {
 void RModel::Streamer(TBuffer &R__b) {
     if (R__b.IsReading()) {
         RModel::Class()->ReadBuffer(R__b, this);
-        for(auto i=RModel::fInitializedTensors.begin(); i!=RModel::fInitializedTensors.end(); ++i) {
-            i->second.CastPersistentToShared();
+        for (auto & i : fInitializedTensors) {
+            i.second.CastPersistentToShared();
         }
     }
     else {
-        for(auto i=RModel::fInitializedTensors.begin(); i!=RModel::fInitializedTensors.end(); ++i) {
-            i->second.CastSharedToPersistent();
+        for (auto & i : fInitializedTensors) {
+            i.second.CastSharedToPersistent();
         }
         RModel::Class()->WriteBuffer(R__b, this);
     }
