@@ -5,7 +5,7 @@
  * Project: TMVA - a Root-integrated toolkit for multivariate data analysis       *
  * Package: TMVA                                                                  *
  * Class  : RuleEnsemble                                                          *
- * Web    : http://tmva.sourceforge.net                                           *
+ *                                             *
  *                                                                                *
  * Description:                                                                   *
  *      A class generating an ensemble of rules                                   *
@@ -23,7 +23,7 @@
  *                                                                                *
  * Redistribution and use in source and binary forms, with or without             *
  * modification, are permitted according to the terms listed in LICENSE           *
- * (http://tmva.sourceforge.net/LICENSE)                                          *
+ * (see tmva/doc/LICENSE)                                          *
  **********************************************************************************/
 
 /*! \class TMVA::RuleEnsemble
@@ -277,7 +277,6 @@ void TMVA::RuleEnsemble::RemoveSimilarRules()
    TMVA::Rule *first, *second;
    std::vector< Char_t > removeMe( nrulesIn,false );  // <--- stores boolean
 
-   Int_t nrem = 0;
    Int_t remind=-1;
    Double_t r;
 
@@ -299,7 +298,6 @@ void TMVA::RuleEnsemble::RemoveSimilarRules()
                if (remind>-1) {
                   if (!removeMe[remind]) {
                      removeMe[remind] = true;
-                     nrem++;
                   }
                }
             }
@@ -371,7 +369,6 @@ void TMVA::RuleEnsemble::CalcRuleSupport()
    Log() << kVERBOSE << "Evaluating Rule support" << Endl;
    Double_t s,t,stot,ssb;
    Double_t ssig, sbkg, ssum;
-   Int_t indrule=0;
    stot = 0;
    // reset to default values
    SetAverageRuleSigma(0.4);
@@ -403,7 +400,6 @@ void TMVA::RuleEnsemble::CalcRuleSupport()
          (*itrRule)->SetNorm(t);
          (*itrRule)->SetSSB( ssb );
          (*itrRule)->SetSSBNeve(Double_t(ssig+sbkg));
-         indrule++;
       }
       fAverageSupport   = stot/nrules;
       fAverageRuleSigma = TMath::Sqrt(fAverageSupport*(1.0-fAverageSupport));
@@ -678,8 +674,8 @@ void TMVA::RuleEnsemble::MakeLinearTerms()
       {
             if (fLinPDFB[v]) delete fLinPDFB[v];
             if (fLinPDFS[v]) delete fLinPDFS[v];
-            fLinPDFB[v] = new TH1F(Form("bkgvar%d",v),"bkg temphist",40,fLinDM[v],fLinDP[v]);
-            fLinPDFS[v] = new TH1F(Form("sigvar%d",v),"sig temphist",40,fLinDM[v],fLinDP[v]);
+            fLinPDFB[v] = new TH1F(TString::Format("bkgvar%d",v),"bkg temphist",40,fLinDM[v],fLinDP[v]);
+            fLinPDFS[v] = new TH1F(TString::Format("sigvar%d",v),"sig temphist",40,fLinDM[v],fLinDP[v]);
             fLinPDFB[v]->Sumw2();
             fLinPDFS[v]->Sumw2();
       }
@@ -1029,7 +1025,7 @@ void TMVA::RuleEnsemble::Print() const
          //    if (pind==0) impref =
          //         Log() << kmtype << "Rule #" <<
          //         Log() << kmtype << *fRules[ind] << Endl;
-         fRules[ind]->PrintLogger(Form("Rule %4d : ",pind+1));
+         fRules[ind]->PrintLogger(TString::Format("Rule %4d : ",pind+1));
          pind++;
          if (pind==printN) {
             if (nrules==printN) {
