@@ -103,7 +103,7 @@ int main()
       std::cerr << "ERROR - test2 failed " << std::endl;
       return -1;
    }
-   std::cout << ">>>>>>   Test2 :    OK !!!!" << std::endl;;
+   std::cout << ">>>>>>   Test2 :    OK !!!!" << std::endl;
     return 0;
 }
 
