@@ -1,10 +1,7 @@
 /// \file RNTupleDS.cxx
-/// \ingroup NTuple ROOT7
 /// \author Jakob Blomer <jblomer@cern.ch>
 /// \author Enrico Guiraud <enrico.guiraud@cern.ch>
 /// \date 2018-10-04
-/// \warning This is part of the ROOT 7 prototype! It will change without notice. It might trigger earthquakes. Feedback
-/// is welcome!
 
 /*************************************************************************
  * Copyright (C) 1995-2020, Rene Brun and Fons Rademakers.               *
@@ -15,7 +12,9 @@
  *************************************************************************/
 
 #include <ROOT/RDF/RColumnReaderBase.hxx>
+#include <ROOT/RDataFrame.hxx>
 #include <ROOT/RField.hxx>
+#include <ROOT/RFieldUtils.hxx>
 #include <ROOT/RPageStorageFile.hxx>
 #include <ROOT/RNTupleDescriptor.hxx>
 #include <ROOT/RNTupleDS.hxx>
@@ -36,7 +35,7 @@
 
 // clang-format off
 /**
-* \class ROOT::Experimental::RNTupleDS
+* \class ROOT::RDF::RNTupleDS
 * \ingroup dataframe
 * \brief The RDataSource implementation for RNTuple. It lets RDataFrame read RNTuple data.
 *
@@ -48,10 +47,7 @@
 **/
 // clang-format on
 
-namespace ROOT {
-namespace Experimental {
-namespace Internal {
-
+namespace ROOT::Internal::RDF {
 /// An artificial field that transforms an RNTuple column that contains the offset of collections into
 /// collection sizes. It is used to provide the "number of" RDF columns for collections, e.g.
 /// `R_rdf_sizeof_jets` for a collection named `jets`.
@@ -59,53 +55,54 @@ namespace Internal {
 /// This field owns the collection offset field but instead of exposing the collection offsets it exposes
 /// the collection sizes (offset(N+1) - offset(N)).  For the time being, we offer this functionality only in RDataFrame.
 /// TODO(jblomer): consider providing a general set of useful virtual fields as part of RNTuple.
-class RRDFCardinalityField final : public ROOT::Experimental::RFieldBase {
+class RRDFCardinalityField final : public ROOT::RFieldBase {
 protected:
-   std::unique_ptr<ROOT::Experimental::RFieldBase> CloneImpl(std::string_view /* newName */) const final
+   std::unique_ptr<ROOT::RFieldBase> CloneImpl(std::string_view /* newName */) const final
    {
       return std::make_unique<RRDFCardinalityField>();
    }
    void ConstructValue(void *where) const final { *static_cast<std::size_t *>(where) = 0; }
 
 public:
-   static std::string TypeName() { return "std::size_t"; }
-   RRDFCardinalityField()
-      : ROOT::Experimental::RFieldBase("", TypeName(), ENTupleStructure::kLeaf, false /* isSimple */)
-   {
-   }
+   RRDFCardinalityField() : ROOT::RFieldBase("", "std::size_t", ROOT::ENTupleStructure::kLeaf, false /* isSimple */) {}
    RRDFCardinalityField(RRDFCardinalityField &&other) = default;
    RRDFCardinalityField &operator=(RRDFCardinalityField &&other) = default;
-   ~RRDFCardinalityField() = default;
+   ~RRDFCardinalityField() override = default;
 
    const RColumnRepresentations &GetColumnRepresentations() const final
    {
-      static RColumnRepresentations representations(
-         {{EColumnType::kSplitIndex64}, {EColumnType::kIndex64}, {EColumnType::kSplitIndex32}, {EColumnType::kIndex32}},
-         {});
+      static RColumnRepresentations representations({{ENTupleColumnType::kSplitIndex64},
+                                                     {ENTupleColumnType::kIndex64},
+                                                     {ENTupleColumnType::kSplitIndex32},
+                                                     {ENTupleColumnType::kIndex32}},
+                                                    {});
       return representations;
    }
    // Field is only used for reading
    void GenerateColumns() final { assert(false && "Cardinality fields must only be used for reading"); }
-   void GenerateColumns(const RNTupleDescriptor &desc) final { GenerateColumnsImpl<ClusterSize_t>(desc); }
+   void GenerateColumns(const ROOT::RNTupleDescriptor &desc) final
+   {
+      GenerateColumnsImpl<ROOT::Internal::RColumnIndex>(desc);
+   }
 
    size_t GetValueSize() const final { return sizeof(std::size_t); }
    size_t GetAlignment() const final { return alignof(std::size_t); }
 
    /// Get the number of elements of the collection identified by globalIndex
-   void ReadGlobalImpl(ROOT::Experimental::NTupleSize_t globalIndex, void *to) final
+   void ReadGlobalImpl(ROOT::NTupleSize_t globalIndex, void *to) final
    {
-      RClusterIndex collectionStart;
-      ClusterSize_t size;
+      RNTupleLocalIndex collectionStart;
+      ROOT::NTupleSize_t size;
       fPrincipalColumn->GetCollectionInfo(globalIndex, &collectionStart, &size);
       *static_cast<std::size_t *>(to) = size;
    }
 
    /// Get the number of elements of the collection identified by clusterIndex
-   void ReadInClusterImpl(ROOT::Experimental::RClusterIndex clusterIndex, void *to) final
+   void ReadInClusterImpl(ROOT::RNTupleLocalIndex localIndex, void *to) final
    {
-      RClusterIndex collectionStart;
-      ClusterSize_t size;
-      fPrincipalColumn->GetCollectionInfo(clusterIndex, &collectionStart, &size);
+      RNTupleLocalIndex collectionStart;
+      ROOT::NTupleSize_t size;
+      fPrincipalColumn->GetCollectionInfo(localIndex, &collectionStart, &size);
       *static_cast<std::size_t *>(to) = size;
    }
 };
@@ -116,25 +113,28 @@ public:
  * This is the implementation of `R_rdf_sizeof_column` in case `column` contains
  * fixed-size arrays on disk.
  */
-class RArraySizeField final : public ROOT::Experimental::RFieldBase {
+class RArraySizeField final : public ROOT::RFieldBase {
 private:
    std::size_t fArrayLength;
 
-   std::unique_ptr<ROOT::Experimental::RFieldBase> CloneImpl(std::string_view) const final
+   std::unique_ptr<ROOT::RFieldBase> CloneImpl(std::string_view) const final
    {
       return std::make_unique<RArraySizeField>(fArrayLength);
    }
    void GenerateColumns() final { assert(false && "RArraySizeField fields must only be used for reading"); }
-   void GenerateColumns(const ROOT::Experimental::RNTupleDescriptor &) final {}
-   void ReadGlobalImpl(NTupleSize_t /*globalIndex*/, void *to) final { *static_cast<std::size_t *>(to) = fArrayLength; }
-   void ReadInClusterImpl(RClusterIndex /*clusterIndex*/, void *to) final
+   void GenerateColumns(const ROOT::RNTupleDescriptor &) final {}
+   void ReadGlobalImpl(ROOT::NTupleSize_t /*globalIndex*/, void *to) final
+   {
+      *static_cast<std::size_t *>(to) = fArrayLength;
+   }
+   void ReadInClusterImpl(RNTupleLocalIndex /*localIndex*/, void *to) final
    {
       *static_cast<std::size_t *>(to) = fArrayLength;
    }
 
 public:
    RArraySizeField(std::size_t arrayLength)
-      : ROOT::Experimental::RFieldBase("", "std::size_t", ENTupleStructure::kLeaf, false /* isSimple */),
+      : ROOT::RFieldBase("", "std::size_t", ROOT::ENTupleStructure::kLeaf, false /* isSimple */),
         fArrayLength(arrayLength)
    {
    }
@@ -151,8 +151,8 @@ public:
 
 /// Every RDF column is represented by exactly one RNTuple field
 class RNTupleColumnReader : public ROOT::Detail::RDF::RColumnReaderBase {
-   using RFieldBase = ROOT::Experimental::RFieldBase;
-   using RPageSource = ROOT::Experimental::Internal::RPageSource;
+   using RFieldBase = ROOT::RFieldBase;
+   using RPageSource = ROOT::Internal::RPageSource;
 
    RNTupleDS *fDataSource;                     ///< The data source that owns this column reader
    RFieldBase *fProtoField;                    ///< The prototype field from which fField is cloned
@@ -167,7 +167,7 @@ class RNTupleColumnReader : public ROOT::Detail::RDF::RColumnReaderBase {
 
 public:
    RNTupleColumnReader(RNTupleDS *ds, RFieldBase *protoField) : fDataSource(ds), fProtoField(protoField) {}
-   ~RNTupleColumnReader() = default;
+   ~RNTupleColumnReader() override = default;
 
    /// Connect the field and its subfields to the page source
    void Connect(RPageSource &source, Long64_t entryOffset)
@@ -189,7 +189,15 @@ public:
          }
       }
 
-      ROOT::Experimental::Internal::CallConnectPageSourceOnField(*fField, source);
+      try {
+         ROOT::Internal::CallConnectPageSourceOnField(*fField, source);
+      } catch (const ROOT::RException &err) {
+         auto onDiskType = source.GetSharedDescriptorGuard()->GetFieldDescriptor(fField->GetOnDiskId()).GetTypeName();
+         std::string msg = "RNTupleDS: invalid type \"" + fField->GetTypeName() + "\" for column \"" +
+                           fDataSource->fFieldId2QualifiedName[fField->GetOnDiskId()] + "\" with on-disk type \"" +
+                           onDiskType + "\"";
+         throw std::runtime_error(msg);
+      }
 
       if (fValuePtr) {
          // When the reader reconnects to a new file, the fValuePtr is already set
@@ -220,13 +228,13 @@ public:
       return fValue->GetPtr<void>().get();
    }
 };
+} // namespace ROOT::Internal::RDF
 
-} // namespace Internal
+ROOT::RDF::RNTupleDS::~RNTupleDS() = default;
 
-RNTupleDS::~RNTupleDS() = default;
-
-void RNTupleDS::AddField(const RNTupleDescriptor &desc, std::string_view colName, DescriptorId_t fieldId,
-                         std::vector<RNTupleDS::RFieldInfo> fieldInfos)
+void ROOT::RDF::RNTupleDS::AddField(const ROOT::RNTupleDescriptor &desc, std::string_view colName,
+                                    ROOT::DescriptorId_t fieldId, std::vector<RNTupleDS::RFieldInfo> fieldInfos,
+                                    bool convertToRVec)
 {
    // As an example for the mapping of RNTuple fields to RDF columns, let's consider an RNTuple
    // using the following types and with a top-level field named "event" of type Event:
@@ -260,34 +268,23 @@ void RNTupleDS::AddField(const RNTupleDescriptor &desc, std::string_view colName
 
    const auto &fieldDesc = desc.GetFieldDescriptor(fieldId);
    const auto &nRepetitions = fieldDesc.GetNRepetitions();
-   if ((fieldDesc.GetStructure() == ENTupleStructure::kCollection) || (nRepetitions > 0)) {
+   if ((fieldDesc.GetStructure() == ROOT::ENTupleStructure::kCollection) || (nRepetitions > 0)) {
       // The field is a collection or a fixed-size array.
       // We open a new collection scope with fieldID being the inner most collection. E.g. for "event.tracks.hits",
       // fieldInfos would already contain the fieldID of "event.tracks"
       fieldInfos.emplace_back(fieldId, nRepetitions);
    }
 
-   if (fieldDesc.GetStructure() == ENTupleStructure::kCollection) {
+   if (fieldDesc.GetStructure() == ROOT::ENTupleStructure::kCollection) {
       // Inner fields of collections are provided as projected collections of only that inner field,
       // E.g. we provide a projected collection RVec<RVec<float>> for "event.tracks.hits.x" in the example
       // above.
+      bool representableAsRVec =
+         convertToRVec && (fieldDesc.GetTypeName().substr(0, 19) == "ROOT::VecOps::RVec<" ||
+                           fieldDesc.GetTypeName().substr(0, 12) == "std::vector<" || fieldDesc.GetTypeName() == "");
+      const auto &f = *desc.GetFieldIterable(fieldDesc.GetId()).begin();
+      AddField(desc, colName, f.GetId(), fieldInfos, representableAsRVec);
 
-      if (fieldDesc.GetTypeName().empty()) {
-         // Anonymous collection with one or several sub fields
-         auto cardinalityField = std::make_unique<ROOT::Experimental::Internal::RRDFCardinalityField>();
-         cardinalityField->SetOnDiskId(fieldId);
-         fColumnNames.emplace_back("R_rdf_sizeof_" + std::string(colName));
-         fColumnTypes.emplace_back(cardinalityField->GetTypeName());
-         fProtoFields.emplace_back(std::move(cardinalityField));
-
-         for (const auto &f : desc.GetFieldIterable(fieldDesc.GetId())) {
-            AddField(desc, std::string(colName) + "." + f.GetFieldName(), f.GetId(), fieldInfos);
-         }
-      } else {
-         // ROOT::RVec with exactly one sub field
-         const auto &f = *desc.GetFieldIterable(fieldDesc.GetId()).begin();
-         AddField(desc, colName, f.GetId(), fieldInfos);
-      }
       // Note that at the end of the recursion, we handled the inner sub collections as well as the
       // collection as whole, so we are done.
       return;
@@ -297,17 +294,18 @@ void RNTupleDS::AddField(const RNTupleDescriptor &desc, std::string_view colName
       const auto &f = *desc.GetFieldIterable(fieldDesc.GetId()).begin();
       AddField(desc, colName, f.GetId(), fieldInfos);
       return;
-   } else if (fieldDesc.GetStructure() == ENTupleStructure::kRecord) {
+   } else if (fieldDesc.GetStructure() == ROOT::ENTupleStructure::kRecord) {
       // Inner fields of records are provided as individual RDF columns, e.g. "event.id"
       for (const auto &f : desc.GetFieldIterable(fieldDesc.GetId())) {
          auto innerName = colName.empty() ? f.GetFieldName() : (std::string(colName) + "." + f.GetFieldName());
+         // Inner fields of collections of records are always exposed as ROOT::RVec
          AddField(desc, innerName, f.GetId(), fieldInfos);
       }
    }
 
    // The fieldID could be the root field or the class of fieldId might not be loaded.
    // In these cases, only the inner fields are exposed as RDF columns.
-   auto fieldOrException = RFieldBase::Create(fieldDesc.GetFieldName(), fieldDesc.GetTypeName());
+   auto fieldOrException = ROOT::RFieldBase::Create(fieldDesc.GetFieldName(), fieldDesc.GetTypeName());
    if (!fieldOrException)
       return;
    auto valueField = fieldOrException.Unwrap();
@@ -315,14 +313,14 @@ void RNTupleDS::AddField(const RNTupleDescriptor &desc, std::string_view colName
    for (auto &f : *valueField) {
       f.SetOnDiskId(desc.FindFieldId(f.GetFieldName(), f.GetParent()->GetOnDiskId()));
    }
-   std::unique_ptr<RFieldBase> cardinalityField;
+   std::unique_ptr<ROOT::RFieldBase> cardinalityField;
    // Collections get the additional "number of" RDF column (e.g. "R_rdf_sizeof_tracks")
    if (!fieldInfos.empty()) {
       const auto &info = fieldInfos.back();
       if (info.fNRepetitions > 0) {
-         cardinalityField = std::make_unique<ROOT::Experimental::Internal::RArraySizeField>(info.fNRepetitions);
+         cardinalityField = std::make_unique<ROOT::Internal::RDF::RArraySizeField>(info.fNRepetitions);
       } else {
-         cardinalityField = std::make_unique<ROOT::Experimental::Internal::RRDFCardinalityField>();
+         cardinalityField = std::make_unique<ROOT::Internal::RDF::RRDFCardinalityField>();
       }
       cardinalityField->SetOnDiskId(info.fFieldId);
    }
@@ -332,11 +330,16 @@ void RNTupleDS::AddField(const RNTupleDescriptor &desc, std::string_view colName
 
       if (fieldInfo.fNRepetitions > 0) {
          // Fixed-size array, read it as ROOT::RVec in memory
-         valueField =
-            std::make_unique<ROOT::Experimental::RArrayAsRVecField>("", std::move(valueField), fieldInfo.fNRepetitions);
+         valueField = std::make_unique<ROOT::RArrayAsRVecField>("", std::move(valueField), fieldInfo.fNRepetitions);
       } else {
-         // Actual ROOT::RVec
-         valueField = std::make_unique<ROOT::Experimental::RRVecField>("", std::move(valueField));
+         // Actual collection. A std::vector or ROOT::RVec gets added as a ROOT::RVec. All other collection types keep
+         // their original type.
+         if (convertToRVec) {
+            valueField = std::make_unique<ROOT::RRVecField>("", std::move(valueField));
+         } else {
+            auto outerFieldType = desc.GetFieldDescriptor(fieldInfo.fFieldId).GetTypeName();
+            valueField = ROOT::RFieldBase::Create("", outerFieldType).Unwrap();
+         }
       }
 
       valueField->SetOnDiskId(fieldInfo.fFieldId);
@@ -346,11 +349,11 @@ void RNTupleDS::AddField(const RNTupleDescriptor &desc, std::string_view colName
       if (i != fieldInfos.rbegin()) {
          if (fieldInfo.fNRepetitions > 0) {
             // This collection level refers to a fixed-size array
-            cardinalityField = std::make_unique<ROOT::Experimental::RArrayAsRVecField>("", std::move(cardinalityField),
-                                                                                       fieldInfo.fNRepetitions);
+            cardinalityField =
+               std::make_unique<ROOT::RArrayAsRVecField>("", std::move(cardinalityField), fieldInfo.fNRepetitions);
          } else {
             // This collection level refers to an RVec
-            cardinalityField = std::make_unique<ROOT::Experimental::RRVecField>("", std::move(cardinalityField));
+            cardinalityField = std::make_unique<ROOT::RRVecField>("", std::move(cardinalityField));
          }
 
          cardinalityField->SetOnDiskId(fieldInfo.fFieldId);
@@ -369,54 +372,48 @@ void RNTupleDS::AddField(const RNTupleDescriptor &desc, std::string_view colName
    fProtoFields.emplace_back(std::move(valueField));
 }
 
-RNTupleDS::RNTupleDS(std::unique_ptr<Internal::RPageSource> pageSource)
+ROOT::RDF::RNTupleDS::RNTupleDS(std::unique_ptr<ROOT::Internal::RPageSource> pageSource)
 {
    pageSource->Attach();
    fPrincipalDescriptor = pageSource->GetSharedDescriptorGuard()->Clone();
    fStagingArea.emplace_back(std::move(pageSource));
 
-   AddField(*fPrincipalDescriptor, "", fPrincipalDescriptor->GetFieldZeroId(),
-            std::vector<ROOT::Experimental::RNTupleDS::RFieldInfo>());
+   AddField(fPrincipalDescriptor, "", fPrincipalDescriptor.GetFieldZeroId(),
+            std::vector<ROOT::RDF::RNTupleDS::RFieldInfo>());
 }
 
 namespace {
 
-const ROOT::Experimental::RNTupleReadOptions &GetOpts()
+const ROOT::RNTupleReadOptions &GetOpts()
 {
    // The setting is for now a global one, must be decided before running the
    // program by setting the appropriate environment variable. Make sure that
    // option configuration is thread-safe and happens only once.
-   static ROOT::Experimental::RNTupleReadOptions opts;
+   static ROOT::RNTupleReadOptions opts;
    static std::once_flag flag;
    std::call_once(flag, []() {
       if (auto env = gSystem->Getenv("ROOT_RNTUPLE_CLUSTERBUNCHSIZE"); env != nullptr && strlen(env) > 0) {
          std::string envStr{env};
          auto envNum{std::stoul(envStr)};
          envNum = envNum == 0 ? 1 : envNum;
-         opts.SetClusterBunchSize(envNum);
+         ROOT::Internal::RNTupleReadOptionsManip::SetClusterBunchSize(opts, envNum);
       }
    });
    return opts;
 }
 
-std::unique_ptr<ROOT::Experimental::Internal::RPageSource>
-CreatePageSource(std::string_view ntupleName, std::string_view fileName)
+std::unique_ptr<ROOT::Internal::RPageSource> CreatePageSource(std::string_view ntupleName, std::string_view fileName)
 {
-   return ROOT::Experimental::Internal::RPageSource::Create(ntupleName, fileName, GetOpts());
+   return ROOT::Internal::RPageSource::Create(ntupleName, fileName, GetOpts());
 }
 } // namespace
 
-RNTupleDS::RNTupleDS(std::string_view ntupleName, std::string_view fileName)
+ROOT::RDF::RNTupleDS::RNTupleDS(std::string_view ntupleName, std::string_view fileName)
    : RNTupleDS(CreatePageSource(ntupleName, fileName))
 {
 }
 
-RNTupleDS::RNTupleDS(RNTuple *ntuple)
-   : RNTupleDS(ROOT::Experimental::Internal::RPageSourceFile::CreateFromAnchor(*ntuple))
-{
-}
-
-RNTupleDS::RNTupleDS(std::string_view ntupleName, const std::vector<std::string> &fileNames)
+ROOT::RDF::RNTupleDS::RNTupleDS(std::string_view ntupleName, const std::vector<std::string> &fileNames)
    : RNTupleDS(CreatePageSource(ntupleName, fileNames[0]))
 {
    fNTupleName = ntupleName;
@@ -424,34 +421,61 @@ RNTupleDS::RNTupleDS(std::string_view ntupleName, const std::vector<std::string>
    fStagingArea.resize(fFileNames.size());
 }
 
-RDF::RDataSource::Record_t RNTupleDS::GetColumnReadersImpl(std::string_view /* name */, const std::type_info & /* ti */)
+ROOT::RDF::RDataSource::Record_t
+ROOT::RDF::RNTupleDS::GetColumnReadersImpl(std::string_view /* name */, const std::type_info & /* ti */)
 {
    // This datasource uses the newer GetColumnReaders() API
    return {};
 }
 
 std::unique_ptr<ROOT::Detail::RDF::RColumnReaderBase>
-RNTupleDS::GetColumnReaders(unsigned int slot, std::string_view name, const std::type_info & /*tid*/)
+ROOT::RDF::RNTupleDS::GetColumnReaders(unsigned int slot, std::string_view name, const std::type_info &tid)
 {
    // At this point we can assume that `name` will be found in fColumnNames
-   // TODO(jblomer): check incoming type
    const auto index = std::distance(fColumnNames.begin(), std::find(fColumnNames.begin(), fColumnNames.end(), name));
-   auto field = fProtoFields[index].get();
+   const auto requestedType = ROOT::Internal::GetRenormalizedTypeName(ROOT::Internal::RDF::TypeID2TypeName(tid));
+
+   ROOT::RFieldBase *field;
+   // If the field corresponding to the provided name is not a cardinality column and the requested type is different
+   // from the proto field that was created when the data source was constructed, we first have to create an
+   // alternative proto field for the column reader. Otherwise, we can directly use the existing proto field.
+   if (name.substr(0, 13) != "R_rdf_sizeof_" && requestedType != fColumnTypes[index]) {
+      auto &altProtoFields = fAlternativeProtoFields[index];
+      auto altProtoField = std::find_if(altProtoFields.begin(), altProtoFields.end(),
+                                        [&requestedType](const std::unique_ptr<ROOT::RFieldBase> &fld) {
+                                           return fld->GetTypeName() == requestedType;
+                                        });
+      if (altProtoField != altProtoFields.end()) {
+         field = altProtoField->get();
+      } else {
+         auto newAltProtoFieldOrException = ROOT::RFieldBase::Create(std::string(name), requestedType);
+         if (!newAltProtoFieldOrException) {
+            throw std::runtime_error("RNTupleDS: Could not create field with type \"" + requestedType +
+                                     "\" for column \"" + std::string(name));
+         }
+         auto newAltProtoField = newAltProtoFieldOrException.Unwrap();
+         newAltProtoField->SetOnDiskId(fProtoFields[index]->GetOnDiskId());
+         field = newAltProtoField.get();
+         altProtoFields.emplace_back(std::move(newAltProtoField));
+      }
+   } else {
+      field = fProtoFields[index].get();
+   }
 
    // Map the field's and subfields' IDs to qualified names so that we can later connect the fields to
    // other page sources from the chain
-   fFieldId2QualifiedName[field->GetOnDiskId()] = fPrincipalDescriptor->GetQualifiedFieldName(field->GetOnDiskId());
+   fFieldId2QualifiedName[field->GetOnDiskId()] = fPrincipalDescriptor.GetQualifiedFieldName(field->GetOnDiskId());
    for (const auto &s : *field) {
-      fFieldId2QualifiedName[s.GetOnDiskId()] = fPrincipalDescriptor->GetQualifiedFieldName(s.GetOnDiskId());
+      fFieldId2QualifiedName[s.GetOnDiskId()] = fPrincipalDescriptor.GetQualifiedFieldName(s.GetOnDiskId());
    }
 
-   auto reader = std::make_unique<Internal::RNTupleColumnReader>(this, field);
+   auto reader = std::make_unique<ROOT::Internal::RDF::RNTupleColumnReader>(this, field);
    fActiveColumnReaders[slot].emplace_back(reader.get());
 
    return reader;
 }
 
-void RNTupleDS::ExecStaging()
+void ROOT::RDF::RNTupleDS::ExecStaging()
 {
    while (true) {
       std::unique_lock lock(fMutexStaging);
@@ -469,7 +493,7 @@ void RNTupleDS::ExecStaging()
    }
 }
 
-void RNTupleDS::StageNextSources()
+void ROOT::RDF::RNTupleDS::StageNextSources()
 {
    const auto nFiles = fFileNames.empty() ? 1 : fFileNames.size();
    for (auto i = fNextFileIndex; (i < nFiles) && ((i - fNextFileIndex) < fNSlots); ++i) {
@@ -486,7 +510,7 @@ void RNTupleDS::StageNextSources()
    }
 }
 
-void RNTupleDS::PrepareNextRanges()
+void ROOT::RDF::RNTupleDS::PrepareNextRanges()
 {
    assert(fNextRanges.empty());
    auto nFiles = fFileNames.empty() ? 1 : fFileNames.size();
@@ -524,7 +548,7 @@ void RNTupleDS::PrepareNextRanges()
    // Again, we need to skip empty files.
    unsigned int nSlotsPerFile = fNSlots / nRemainingFiles;
    for (std::size_t i = 0; (fNextRanges.size() < fNSlots) && (fNextFileIndex < nFiles); ++i) {
-      std::unique_ptr<Internal::RPageSource> source;
+      std::unique_ptr<ROOT::Internal::RPageSource> source;
       std::swap(fStagingArea[fNextFileIndex], source);
       if (!source) {
          // Empty files trigger this condition
@@ -581,7 +605,7 @@ void RNTupleDS::PrepareNextRanges()
    } // loop over tail of remaining files
 }
 
-std::vector<std::pair<ULong64_t, ULong64_t>> RNTupleDS::GetEntryRanges()
+std::vector<std::pair<ULong64_t, ULong64_t>> ROOT::RDF::RNTupleDS::GetEntryRanges()
 {
    std::vector<std::pair<ULong64_t, ULong64_t>> ranges;
 
@@ -659,7 +683,7 @@ std::vector<std::pair<ULong64_t, ULong64_t>> RNTupleDS::GetEntryRanges()
    return ranges;
 }
 
-void RNTupleDS::InitSlot(unsigned int slot, ULong64_t firstEntry)
+void ROOT::RDF::RNTupleDS::InitSlot(unsigned int slot, ULong64_t firstEntry)
 {
    if (fNSlots == 1)
       return;
@@ -670,7 +694,7 @@ void RNTupleDS::InitSlot(unsigned int slot, ULong64_t firstEntry)
    }
 }
 
-void RNTupleDS::FinalizeSlot(unsigned int slot)
+void ROOT::RDF::RNTupleDS::FinalizeSlot(unsigned int slot)
 {
    if (fNSlots == 1)
       return;
@@ -680,18 +704,25 @@ void RNTupleDS::FinalizeSlot(unsigned int slot)
    }
 }
 
-std::string RNTupleDS::GetTypeName(std::string_view colName) const
+std::string ROOT::RDF::RNTupleDS::GetTypeName(std::string_view colName) const
 {
-   const auto index = std::distance(fColumnNames.begin(), std::find(fColumnNames.begin(), fColumnNames.end(), colName));
+   auto colNamePos = std::find(fColumnNames.begin(), fColumnNames.end(), colName);
+
+   if (colNamePos == fColumnNames.end()) {
+      auto msg = std::string("RNTupleDS: There is no column with name \"") + std::string(colName) + "\"";
+      throw std::runtime_error(msg);
+   }
+
+   const auto index = std::distance(fColumnNames.begin(), colNamePos);
    return fColumnTypes[index];
 }
 
-bool RNTupleDS::HasColumn(std::string_view colName) const
+bool ROOT::RDF::RNTupleDS::HasColumn(std::string_view colName) const
 {
    return std::find(fColumnNames.begin(), fColumnNames.end(), colName) != fColumnNames.end();
 }
 
-void RNTupleDS::Initialize()
+void ROOT::RDF::RNTupleDS::Initialize()
 {
    fSeenEntries = 0;
    fNextFileIndex = 0;
@@ -713,7 +744,7 @@ void RNTupleDS::Initialize()
    }
 }
 
-void RNTupleDS::Finalize()
+void ROOT::RDF::RNTupleDS::Finalize()
 {
    for (unsigned int i = 0; i < fNSlots; ++i) {
       for (auto r : fActiveColumnReaders[i]) {
@@ -736,28 +767,20 @@ void RNTupleDS::Finalize()
    }
 }
 
-void RNTupleDS::SetNSlots(unsigned int nSlots)
+void ROOT::RDF::RNTupleDS::SetNSlots(unsigned int nSlots)
 {
    assert(fNSlots == 0);
    assert(nSlots > 0);
    fNSlots = nSlots;
    fActiveColumnReaders.resize(fNSlots);
 }
-} // namespace Experimental
-} // namespace ROOT
 
-ROOT::RDataFrame ROOT::RDF::Experimental::FromRNTuple(std::string_view ntupleName, std::string_view fileName)
+ROOT::RDataFrame ROOT::RDF::FromRNTuple(std::string_view ntupleName, std::string_view fileName)
 {
-   return ROOT::RDataFrame(std::make_unique<ROOT::Experimental::RNTupleDS>(ntupleName, fileName));
+   return ROOT::RDataFrame(std::make_unique<ROOT::RDF::RNTupleDS>(ntupleName, fileName));
 }
 
-ROOT::RDataFrame
-ROOT::RDF::Experimental::FromRNTuple(std::string_view ntupleName, const std::vector<std::string> &fileNames)
+ROOT::RDataFrame ROOT::RDF::FromRNTuple(std::string_view ntupleName, const std::vector<std::string> &fileNames)
 {
-   return ROOT::RDataFrame(std::make_unique<ROOT::Experimental::RNTupleDS>(ntupleName, fileNames));
-}
-
-ROOT::RDataFrame ROOT::RDF::Experimental::FromRNTuple(ROOT::RNTuple *ntuple)
-{
-   return ROOT::RDataFrame(std::make_unique<ROOT::Experimental::RNTupleDS>(ntuple));
+   return ROOT::RDataFrame(std::make_unique<ROOT::RDF::RNTupleDS>(ntupleName, fileNames));
 }
