@@ -412,7 +412,7 @@ TEST(RDFVary, VaryDisplay) // TEST instead of TEST_P because Display is single-t
                   {}, 2)
                .Display<int>({"x"});
    // Display ignores variations, only displays the nominal values
-   EXPECT_EQ(d->AsString(), "+-----+---+\n| Row | x | \n+-----+---+\n| 0   | 0 | \n|     |   | \n+-----+---+\n");
+   EXPECT_EQ(d->AsString(), "+-----+---+\n| Row | x | \n+-----+---+\n| 0   | 0 | \n+-----+---+\n");
    // cannot vary a Display
    EXPECT_THROW(
       try { VariationsFor(d); } catch (const std::logic_error &err) {
@@ -1068,7 +1068,7 @@ struct MyCounter : public ROOT::Detail::RDF::RActionImpl<MyCounter> {
 
    std::string GetActionName() const { return "MyCounter"; }
 
-   MyCounter MakeNew(void *newResult)
+   MyCounter MakeNew(void *newResult, std::string_view /*variation*/ = "nominal")
    {
       auto &result = *static_cast<std::shared_ptr<int> *>(newResult);
       return MyCounter(result, fPerThreadResults.size());
@@ -1453,21 +1453,17 @@ TEST_P(RDFVary, VaryReduce)
    EXPECT_EQ(hs["x:1"], 55);
 }
 
-// Varying Reports is not implemented yet, tracked by https://github.com/root-project/root/issues/10551
 TEST_P(RDFVary, VaryReport)
 {
-   auto h = ROOT::RDataFrame(10)
-               .Define("x", [](ULong64_t e) { return int(e); }, {"rdfentry_"})
-               .Filter([](int x) { return x > 5; }, {"x"}, "before")
-               .Vary(
-                  "x",
-                  [](int x) {
-                     return ROOT::RVecI{x - 1, x + 1};
-                  },
-                  {"x"}, 2)
-               .Filter([](int x) { return x > 7; }, {"x"}, "after")
-               .Report();
-   auto &report = *h;
+   auto rep = ROOT::RDataFrame(10)
+                 .Define("x", [](ULong64_t e) { return int(e); }, {"rdfentry_"})
+                 .Filter([](int x) { return x > 5; }, {"x"}, "before")
+                 .Vary("x", [](int x) { return ROOT::RVecI{x - 1, x + 1}; }, {"x"}, {"down", "up"})
+                 .Filter([](int x) { return x > 7; }, {"x"}, "after")
+                 .Report();
+
+   auto reps = VariationsFor(rep);
+   auto &&report = reps["nominal"];
 
    EXPECT_EQ(report["before"].GetAll(), 10);
    EXPECT_FLOAT_EQ(report["before"].GetEff(), 40.);
@@ -1475,14 +1471,24 @@ TEST_P(RDFVary, VaryReport)
    EXPECT_EQ(report["after"].GetAll(), 4);
    EXPECT_FLOAT_EQ(report["after"].GetEff(), 50.);
    EXPECT_EQ(report["after"].GetPass(), 2);
-   EXPECT_THROW(
-      try { VariationsFor(h); } catch (const std::logic_error &err) {
-         const auto msg = "The MakeNew method is not implemented for this action helper (Report). "
-                          "Cannot Vary its result.";
-         EXPECT_STREQ(err.what(), msg);
-         throw;
-      },
-      std::logic_error);
+
+   auto &&report_up = reps["x:up"];
+
+   EXPECT_EQ(report_up["before"].GetAll(), 10);
+   EXPECT_FLOAT_EQ(report_up["before"].GetEff(), 40.);
+   EXPECT_EQ(report_up["before"].GetPass(), 4);
+   EXPECT_EQ(report_up["after"].GetAll(), 4);
+   EXPECT_FLOAT_EQ(report_up["after"].GetEff(), 75.);
+   EXPECT_EQ(report_up["after"].GetPass(), 3);
+
+   auto &&report_down = reps["x:down"];
+
+   EXPECT_EQ(report_down["before"].GetAll(), 10);
+   EXPECT_FLOAT_EQ(report_down["before"].GetEff(), 40.);
+   EXPECT_EQ(report_down["before"].GetPass(), 4);
+   EXPECT_EQ(report_down["after"].GetAll(), 4);
+   EXPECT_FLOAT_EQ(report_down["after"].GetEff(), 25.);
+   EXPECT_EQ(report_down["after"].GetPass(), 1);
 }
 
 TEST_P(RDFVary, VaryStdDev)
@@ -1614,6 +1620,77 @@ TEST_P(RDFVary, ManyVariationsManyColumns)
    }
 }
 
+// Regression test for https://github.com/root-project/root/issues/17486
+TEST_P(RDFVary, CompatibleColumnTypes)
+{
+   struct DataRAII {
+      const char *fFileName{"rdf_vary_compatible_column_types.root"};
+      const char *fTreeName{"tree"};
+      DataRAII()
+      {
+         TFile f{fFileName, "recreate"};
+         TTree t{fTreeName, fTreeName};
+         Float_t v[3] = {1.f, 2.f, 3.f};
+         t.Branch("v", &v, "v[3]/F");
+         t.Branch("w", &v, "w[3]/F");
+         t.Fill();
+         f.Write();
+      }
+      ~DataRAII() { std::remove(fFileName); }
+   } dataset;
+
+   ROOT::RDataFrame df_start{dataset.fTreeName, dataset.fFileName};
+   ROOT::RDF::RNode df{df_start};
+
+   // The JITted transformation triggers a change in the column type name
+   // due to the desugaring of the Float_t typedef
+   df = df.Redefine("v", "v");
+
+   // Previously Vary would throw when doing a string comparison check of the
+   // types of the columns to be varied
+   EXPECT_NO_THROW({
+      df = df.Vary(
+         {"v", "w"},
+         [](const ROOT::RVecF &v, const ROOT::RVecF &w) {
+            return ROOT::RVec<ROOT::RVec<ROOT::RVecF>>{{v - 1, v + 1}, {w - 1, w + 1}};
+         },
+         {"v", "w"}, {"down", "up"}, "variation");
+   });
+}
+
+TEST_P(RDFVary, IncompatibleColumnTypes)
+{
+   struct DataRAII {
+      const char *fFileName{"rdf_vary_incompatible_column_types.root"};
+      const char *fTreeName{"tree"};
+      DataRAII()
+      {
+         TFile f{fFileName, "recreate"};
+         TTree t{fTreeName, fTreeName};
+         Float_t v[3] = {1.f, 2.f, 3.f};
+         Int_t w[3] = {1, 2, 3};
+         t.Branch("v", &v, "v[3]/F");
+         t.Branch("w", &w, "w[3]/I");
+         t.Fill();
+         f.Write();
+      }
+      ~DataRAII() { std::remove(fFileName); }
+   } dataset;
+
+   ROOT::RDataFrame df{dataset.fTreeName, dataset.fFileName};
+
+   EXPECT_THROW(
+      {
+         df.Vary(
+            {"v", "w"},
+            [](const ROOT::RVecF &v, const ROOT::RVecI &w) {
+               return ROOT::RVec<ROOT::RVec<ROOT::RVecF>>{{v - 1, v + 1}, {w - 1, w + 1}};
+            },
+            {"v", "w"}, {"down", "up"}, "variation");
+      },
+      std::runtime_error);
+}
+
 struct HelperWithCallback : ROOT::Detail::RDF::RActionImpl<HelperWithCallback> {
    using Result_t = int;
    std::shared_ptr<Result_t> fResult = std::make_shared<Result_t>(0);
@@ -1630,7 +1707,7 @@ struct HelperWithCallback : ROOT::Detail::RDF::RActionImpl<HelperWithCallback> {
       return callback;
    }
 
-   HelperWithCallback MakeNew(void *newResult)
+   HelperWithCallback MakeNew(void *newResult, std::string_view /*variation*/ = "nominal")
    {
       auto newHelper = HelperWithCallback();
       newHelper.fResult = *static_cast<std::shared_ptr<Result_t> *>(newResult);
