@@ -175,7 +175,7 @@ TTreeCacheUnzip::TTreeCacheUnzip() : TTreeCache(),
 ////////////////////////////////////////////////////////////////////////////////
 /// Constructor.
 
-TTreeCacheUnzip::TTreeCacheUnzip(TTree *tree, Int_t buffersize) : TTreeCache(tree,buffersize),
+TTreeCacheUnzip::TTreeCacheUnzip(TTree *tree, Int_t bufsize) : TTreeCache(tree,bufsize),
    fAsyncReading(false),
    fEmpty(true),
    fCycle(0),
