@@ -30,8 +30,8 @@
  access the information in the dataset.
 
  Example code can be found in
-  - tutorials/tree/hsimpleReader.C
-  - tutorials/tree/h1analysisTreeReader.C
+  - tutorials/io/tree/hsimpleReader.C
+  - tutorials/io/tree/h1analysisTreeReader.C
   - <a href="https://github.com/root-project/roottest/tree/master/root/tree/reader">This example</a>
 
  You can generate a skeleton of `TTreeReaderValue<T>` and `TTreeReaderArray<T>` declarations
@@ -183,7 +183,7 @@ ClassImp(TTreeReader);
 using namespace ROOT::Internal;
 
 // Provide some storage for the poor little symbol.
-constexpr const char * const TTreeReader::fgEntryStatusText[TTreeReader::kEntryUnknownError + 1];
+constexpr const char *const TTreeReader::fgEntryStatusText[TTreeReader::kEntryUnknownError + 1];
 
 ////////////////////////////////////////////////////////////////////////////////
 /// Default constructor.  Call SetTree to connect to a TTree.
@@ -201,7 +201,7 @@ TTreeReader::TTreeReader() : fNotify(this), fFriendProxies() {}
 ///                  per chain.SetEntryList(&entryList).
 
 TTreeReader::TTreeReader(TTree *tree, TEntryList *entryList /*= nullptr*/, bool warnAboutLongerFriends,
-                         const std::vector<std::string> &suppressErrorsForMissingBranches)
+                         const std::set<std::string> &suppressErrorsForMissingBranches)
    : fTree(tree),
      fEntryList(entryList),
      fNotify(this),
@@ -234,7 +234,8 @@ TTreeReader::TTreeReader(TTree *tree, TEntryList *entryList /*= nullptr*/, bool
 TTreeReader::TTreeReader(const char *keyname, TDirectory *dir, TEntryList *entryList /*= nullptr*/)
    : fEntryList(entryList), fNotify(this), fFriendProxies()
 {
-   if (!dir) dir = gDirectory;
+   if (!dir)
+      dir = gDirectory;
    dir->GetObject(keyname, fTree);
    if (!fTree) {
       std::string msg = "No TTree called ";
@@ -250,8 +251,8 @@ TTreeReader::TTreeReader(const char *keyname, TDirectory *dir, TEntryList *entry
 
 TTreeReader::~TTreeReader()
 {
-   for (std::deque<ROOT::Internal::TTreeReaderValueBase*>::const_iterator
-           i = fValues.begin(), e = fValues.end(); i != e; ++i) {
+   for (std::deque<ROOT::Internal::TTreeReaderValueBase *>::const_iterator i = fValues.begin(), e = fValues.end();
+        i != e; ++i) {
       (*i)->MarkTreeReaderUnavailable();
    }
    if (fTree && fNotify.IsLinked())
@@ -335,10 +336,10 @@ bool TTreeReader::Notify()
          // This means that "local" should be set!
          // There are two entities switching trees which is bad.
          Warning("SetEntryBase()",
-                  "The current tree in the TChain %s has changed (e.g. by TTree::Process) "
-                  "even though TTreeReader::SetEntry() was called, which switched the tree "
-                  "again. Did you mean to call TTreeReader::SetLocalEntry()?",
-                  fTree->GetName());
+                 "The current tree in the TChain %s has changed (e.g. by TTree::Process) "
+                 "even though TTreeReader::SetEntry() was called, which switched the tree "
+                 "again. Did you mean to call TTreeReader::SetLocalEntry()?",
+                 fTree->GetName());
       }
       fLoadTreeStatus = kInternalLoadTree;
    } else {
@@ -360,7 +361,7 @@ bool TTreeReader::Notify()
    }
 
    if (fProxiesSet) {
-      for (auto value: fValues) {
+      for (auto value : fValues) {
          value->NotifyNewTree(fTree->GetTree());
       }
    }
@@ -375,6 +376,8 @@ bool TTreeReader::Notify()
 
 bool TTreeReader::SetProxies()
 {
+   fMissingProxies.clear();
+   fProxiesSet = false; // In the loop below, we cannot recreate proxies if this is true
 
    for (size_t i = 0; i < fValues.size(); ++i) {
       ROOT::Internal::TTreeReaderValueBase *reader = fValues[i];
@@ -383,9 +386,8 @@ bool TTreeReader::SetProxies()
       // where the first tree of the chain does not contain that branch. In such
       // case, we need to postpone the creation of the corresponding proxy until
       // we find the branch in a following tree of the chain.
-      const bool suppressErrorsForThisBranch =
-         (std::find(fSuppressErrorsForMissingBranches.cbegin(), fSuppressErrorsForMissingBranches.cend(),
-                    reader->fBranchName.View()) != fSuppressErrorsForMissingBranches.cend());
+      const bool suppressErrorsForThisBranch = (fSuppressErrorsForMissingBranches.find(reader->fBranchName.Data()) !=
+                                                fSuppressErrorsForMissingBranches.cend());
       // Because of the situation described above, we may have some proxies
       // already created and some not, if their branch was not available so far.
       // Make sure we do not recreate the proxy unnecessarily, unless the
@@ -399,13 +401,9 @@ bool TTreeReader::SetProxies()
       if (!reader->GetProxy()) {
          if (suppressErrorsForThisBranch ||
              (reader->GetSetupStatus() == ROOT::Internal::TTreeReaderValueBase::ESetupStatus::kSetupMissingBranch))
-            fMissingProxies.push_back(reader->fBranchName.Data());
+            fMissingProxies.insert(reader->fBranchName.Data());
          else
             return false;
-      } else {
-         // Erase the branch name from the missing proxies if it was present
-         fMissingProxies.erase(std::remove(fMissingProxies.begin(), fMissingProxies.end(), reader->fBranchName.Data()),
-                               fMissingProxies.end());
       }
    }
    // If at least one proxy was there and no error occurred, we assume the proxies to be set.
@@ -559,8 +557,7 @@ TTreeReader::EEntryStatus TTreeReader::SetEntriesRange(Long64_t beginEntry, Long
       // thus adding all the branches to the cache and triggering the learning phase.
       EEntryStatus es = SetEntry(beginEntry - 1);
       if (es != kEntryValid) {
-         Error("SetEntriesRange()", "Error setting first entry %lld: %s",
-               beginEntry, fgEntryStatusText[(int)es]);
+         Error("SetEntriesRange()", "Error setting first entry %lld: %s", beginEntry, fgEntryStatusText[(int)es]);
          return es;
       }
    }
@@ -568,16 +565,25 @@ TTreeReader::EEntryStatus TTreeReader::SetEntriesRange(Long64_t beginEntry, Long
    return kEntryValid;
 }
 
-void TTreeReader::Restart() {
+void TTreeReader::Restart()
+{
    fDirector->SetReadEntry(-1);
    fProxiesSet = false; // we might get more value readers, meaning new proxies.
    fEntry = -1;
-   if (const auto curFile = fTree->GetCurrentFile()) {
-      if (auto tc = fTree->GetTree()->GetReadCache(curFile, true)) {
-         tc->DropBranch("*", true);
-         tc->ResetCache();
-      }
-   }
+   // Find if there is an active TTreeCache and reset it if so
+   if (!fTree)
+      return;
+   const auto curFile = fTree->GetCurrentFile();
+   if (!curFile)
+      return;
+   auto curTree = fTree->GetTree();
+   if (!curTree)
+      return;
+   auto tc = curTree->GetReadCache(curFile, true);
+   if (!tc)
+      return;
+   tc->DropBranch("*", true);
+   tc->ResetCache();
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -585,8 +591,8 @@ void TTreeReader::Restart() {
 /// of the TTree / TChain, independent of a range set by SetEntriesRange()
 /// by calling TTree/TChain::%GetEntriesFast.
 
-
-Long64_t TTreeReader::GetEntries() const {
+Long64_t TTreeReader::GetEntries() const
+{
    if (fEntryList)
       return fEntryList->GetN();
    if (!fTree)
@@ -594,7 +600,6 @@ Long64_t TTreeReader::GetEntries() const {
    return fTree->GetEntriesFast();
 }
 
-
 ////////////////////////////////////////////////////////////////////////////////
 /// Returns the number of entries of the TEntryList if one is provided, else
 /// of the TTree / TChain, independent of a range set by SetEntriesRange().
@@ -603,7 +608,8 @@ Long64_t TTreeReader::GetEntries() const {
 ///   this TChain should be opened to determine the exact number of entries
 /// of the TChain. If `!IsChain()`, `force` is ignored.
 
-Long64_t TTreeReader::GetEntries(bool force)  {
+Long64_t TTreeReader::GetEntries(bool force)
+{
    if (fEntryList)
       return fEntryList->GetN();
    if (!fTree)
@@ -619,8 +625,6 @@ Long64_t TTreeReader::GetEntries(bool force)  {
    return fTree->GetEntriesFast();
 }
 
-
-
 ////////////////////////////////////////////////////////////////////////////////
 /// Load an entry into the tree, return the status of the read.
 /// For chains, entry is the global (i.e. not tree-local) entry number, unless
@@ -663,7 +667,7 @@ TTreeReader::EEntryStatus TTreeReader::SetEntryBase(Long64_t entry, bool local)
       }
    }
 
-   TTree* treeToCallLoadOn = local ? fTree->GetTree() : fTree;
+   TTree *treeToCallLoadOn = local ? fTree->GetTree() : fTree;
 
    fSetEntryBaseCallingLoadTree = true;
    const Long64_t loadResult = treeToCallLoadOn->LoadTree(entryAfterList);
@@ -679,13 +683,12 @@ TTreeReader::EEntryStatus TTreeReader::SetEntryBase(Long64_t entry, bool local)
       if (loadResult == -3 && TestBit(kBitIsChain) && !fTree->GetTree()) {
          fDirector->Notify();
          if (fProxiesSet) {
-            for (auto value: fValues) {
+            for (auto value : fValues) {
                value->NotifyNewTree(fTree->GetTree());
             }
          }
-         Warning("SetEntryBase()",
-               "There was an issue opening the last file associated to the TChain "
-               "being processed.");
+         Warning("SetEntryBase()", "There was an issue opening the last file associated to the TChain "
+                                   "being processed.");
          fEntryStatus = kEntryChainFileError;
          return fEntryStatus;
       }
@@ -693,11 +696,21 @@ TTreeReader::EEntryStatus TTreeReader::SetEntryBase(Long64_t entry, bool local)
       if (loadResult == -2) {
          fDirector->Notify();
          if (fProxiesSet) {
-            for (auto value: fValues) {
+            for (auto value : fValues) {
                value->NotifyNewTree(fTree->GetTree());
             }
          }
-         fEntryStatus = kEntryBeyondEnd;
+         auto &&nEntries = treeToCallLoadOn->GetEntriesFast();
+         if (fBeginEntry >= nEntries && nEntries > 0) {
+            // The beginning entry specified via SetEntriesRange was beyond the total number of entries in the dataset
+            Error("SetEntryBase()",
+                  "The beginning entry specified via SetEntriesRange (%lld) is equal to or beyond the "
+                  "total number of entries in the dataset (%lld). Make sure to specify a "
+                  "beginning entry lower than the number of available entries.",
+                  fBeginEntry, nEntries);
+            fEntryStatus = kEntryNotFound;
+         } else
+            fEntryStatus = kEntryBeyondEnd;
          WarnIfFriendsHaveMoreEntries();
          return fEntryStatus;
       }
@@ -713,7 +726,7 @@ TTreeReader::EEntryStatus TTreeReader::SetEntryBase(Long64_t entry, bool local)
          // the TTree is missing from the file.
          fDirector->Notify();
          if (fProxiesSet) {
-            for (auto value: fValues) {
+            for (auto value : fValues) {
                value->NotifyNewTree(fTree->GetTree());
             }
          }
@@ -739,8 +752,7 @@ TTreeReader::EEntryStatus TTreeReader::SetEntryBase(Long64_t entry, bool local)
          return fEntryStatus;
       }
 
-      Warning("SetEntryBase()",
-              "Unexpected error '%lld' in %s::LoadTree", loadResult,
+      Warning("SetEntryBase()", "Unexpected error '%lld' in %s::LoadTree", loadResult,
               treeToCallLoadOn->IsA()->GetName());
 
       fEntryStatus = kEntryUnknownError;
@@ -803,7 +815,7 @@ TTreeReader::EEntryStatus TTreeReader::SetEntryBase(Long64_t entry, bool local)
 /// Set (or update) the which tree to read from. `tree` can be
 /// a TTree or a TChain.
 
-void TTreeReader::SetTree(TTree* tree, TEntryList* entryList /*= nullptr*/)
+void TTreeReader::SetTree(TTree *tree, TEntryList *entryList /*= nullptr*/)
 {
    if (fEntryStatus != kEntryNoTree && !TestBit(kBitIsExternalTree)) {
       // a plain TTree is automatically added to the current directory,
@@ -828,8 +840,7 @@ void TTreeReader::SetTree(TTree* tree, TEntryList* entryList /*= nullptr*/)
 
    if (!fDirector) {
       Initialize();
-   }
-   else {
+   } else {
       fDirector->SetTree(fTree);
       fDirector->SetReadEntry(-1);
    }
@@ -843,9 +854,9 @@ void TTreeReader::SetTree(TTree* tree, TEntryList* entryList /*= nullptr*/)
 /// \param dir - the `TDirectory` to load `keyname` from (or gDirectory if `nullptr`)
 /// \param entryList - the `TEntryList` to attach to the `TTreeReader`.
 
-void TTreeReader::SetTree(const char* keyname, TDirectory* dir, TEntryList* entryList /*= nullptr*/)
+void TTreeReader::SetTree(const char *keyname, TDirectory *dir, TEntryList *entryList /*= nullptr*/)
 {
-   TTree* tree = nullptr;
+   TTree *tree = nullptr;
    if (!dir)
       dir = gDirectory;
    dir->GetObject(keyname, tree);
@@ -855,11 +866,12 @@ void TTreeReader::SetTree(const char* keyname, TDirectory* dir, TEntryList* entr
 ////////////////////////////////////////////////////////////////////////////////
 /// Add a value reader for this tree.
 
-bool TTreeReader::RegisterValueReader(ROOT::Internal::TTreeReaderValueBase* reader)
+bool TTreeReader::RegisterValueReader(ROOT::Internal::TTreeReaderValueBase *reader)
 {
    if (fProxiesSet) {
       Error("RegisterValueReader",
-            "Error registering reader for %s: TTreeReaderValue/Array objects must be created before the call to Next() / SetEntry() / SetLocalEntry(), or after TTreeReader::Restart()!",
+            "Error registering reader for %s: TTreeReaderValue/Array objects must be created before the call to Next() "
+            "/ SetEntry() / SetLocalEntry(), or after TTreeReader::Restart()!",
             reader->GetBranchName());
       return false;
    }
@@ -870,12 +882,13 @@ bool TTreeReader::RegisterValueReader(ROOT::Internal::TTreeReaderValueBase* read
 ////////////////////////////////////////////////////////////////////////////////
 /// Remove a value reader for this tree.
 
-void TTreeReader::DeregisterValueReader(ROOT::Internal::TTreeReaderValueBase* reader)
+void TTreeReader::DeregisterValueReader(ROOT::Internal::TTreeReaderValueBase *reader)
 {
-   std::deque<ROOT::Internal::TTreeReaderValueBase*>::iterator iReader
-      = std::find(fValues.begin(), fValues.end(), reader);
+   std::deque<ROOT::Internal::TTreeReaderValueBase *>::iterator iReader =
+      std::find(fValues.begin(), fValues.end(), reader);
    if (iReader == fValues.end()) {
-      Error("DeregisterValueReader", "Cannot find reader of type %s for branch %s", reader->GetDerivedTypeName(), reader->fBranchName.Data());
+      Error("DeregisterValueReader", "Cannot find reader of type %s for branch %s", reader->GetDerivedTypeName(),
+            reader->fBranchName.Data());
       return;
    }
    fValues.erase(iReader);
